@@ -24,7 +24,7 @@
 
 #include <QtConcurrent>
 #include <glib.h>
-
+#include <gio/gio.h>
 #include <QDebug>
 
 using namespace Peony;
@@ -45,6 +45,27 @@ BookMarkManager::BookMarkManager(QObject *parent) : QObject(parent)
         m_book_mark = new QSettings(QSettings::UserScope, "org.ukui", "peony-qt");
         m_uris = m_book_mark->value("uris").toStringList();
         m_is_loaded = true;
+        QStringList urist = m_uris;
+        m_uris.clear();
+
+        if (m_mutex.tryLock(1000)) {
+            for (int i = 0; i < urist.count(); ++i) {
+                GFile* file = g_file_new_for_uri (urist.at(i).toUtf8());
+                char* uri = g_file_get_uri(file);
+
+                if (0 != strcmp ("favorite:///", uri) && g_file_query_exists(file, nullptr)) {
+                    m_uris << uri;
+                }
+
+                if (nullptr != uri)  g_free (uri);
+                if (nullptr != file) g_object_unref (file);
+            }
+            m_uris.removeDuplicates();
+            m_book_mark->setValue("uris", m_uris);
+            m_book_mark->sync();
+            m_mutex.unlock();
+        }
+
         //m_uris<<"computer:///";
         //qDebug()<<"====================ok============\n\n\n\n"<<m_uris;
         Q_EMIT this->urisLoaded();
@@ -65,7 +86,11 @@ void BookMarkManager::addBookMark(const QString &uri)
             g_usleep(100);
         }
         QUrl url = uri;
-        QString origin_path = "file://" + url.path();
+        QString origin_path = "favorite://" + url.path() + "?schema=" + url.scheme();
+        //desktop uri is fixed in favorite item
+        QString desktopPath = QStandardPaths::writableLocation(QStandardPaths::DesktopLocation);
+        if (url.path() == desktopPath)
+            return;
         if (m_mutex.tryLock(1000)) {
             bool successed = !m_uris.contains(origin_path);
             if (successed) {
@@ -91,23 +116,22 @@ void BookMarkManager::removeBookMark(const QString &uri)
         while (!this->isLoaded()) {
             g_usleep(100);
         }
-        QUrl url = uri;
-        QString origin_path = "file://" + url.path();
+
         if (m_mutex.tryLock(1000)) {
-            bool successed = m_uris.contains(origin_path);
+            bool successed = m_uris.contains(uri);
             if (successed) {
-                m_uris.removeOne(origin_path);
+                m_uris.removeOne(uri);
                 m_uris.removeDuplicates();
                 m_book_mark->setValue("uris", m_uris);
                 m_book_mark->sync();
-                qDebug()<<"removeBookMark"<<origin_path;
-                Q_EMIT this->bookMarkRemoved(origin_path, true);
+                qDebug()<<"removeBookMark"<<uri;
+                Q_EMIT this->bookMarkRemoved(uri, true);
             } else {
-                Q_EMIT this->bookMarkRemoved(origin_path, false);
+                Q_EMIT this->bookMarkRemoved(uri, false);
             }
             m_mutex.unlock();
         } else {
-            Q_EMIT this->bookMarkRemoved(origin_path, false);
+            Q_EMIT this->bookMarkRemoved(uri, false);
         }
     });
 }
