@@ -31,9 +31,10 @@
 #include "gerror-wrapper.h"
 
 #include "file-utils.h"
-#include "peony-search-vfs-file.h"
 #include "audio-play-manager.h"
 
+#include "vfs-plugin-manager.h"
+
 #include <QList>
 #include <QMessageBox>
 
@@ -112,7 +113,6 @@ FileEnumerator::~FileEnumerator()
 void FileEnumerator::setEnumerateDirectory(QString uri)
 {
     m_uri = uri;
-
     if (m_cancellable) {
         g_cancellable_cancel(m_cancellable);
         g_object_unref(m_cancellable);
@@ -129,12 +129,8 @@ void FileEnumerator::setEnumerateDirectory(QString uri)
 #if GLIB_CHECK_VERSION(2, 50, 0)
     m_root_file = g_file_new_for_uri(uri.toUtf8());
 #else
-    if (uri.startsWith("search:///"))
-    {
-        m_root_file = peony_search_vfs_file_new_for_uri(uri.toUtf8());
-    }
-    else
-        m_root_file = g_file_new_for_uri(uri.toUtf8());
+    auto vfsMgr = VFSPluginManager::getInstance();
+    m_root_file = vfsMgr->newVFSFile(uri);
 #endif
 
 }
@@ -159,9 +155,10 @@ void FileEnumerator::setEnumerateDirectory(GFile *file)
     }
 }
 
-bool FileEnumerator::setEnumerateWithInfoJob(bool query)
+//try not to use this function for now, some info can not get correctly
+void FileEnumerator::setEnumerateWithInfoJob(bool query)
 {
-    m_with_info_job = query;
+    m_with_info_job = query;   
 }
 
 QString FileEnumerator::getEnumerateUri()
@@ -176,8 +173,20 @@ const QList<std::shared_ptr<FileInfo>> FileEnumerator::getChildren()
     //qDebug()<<"FileEnumerator::getChildren():";
     QList<std::shared_ptr<FileInfo>> children;
     for (auto uri : *m_children_uris) {
+        //uri reencode to prevent the existence of GBK strings
+        if(uri.startsWith("file:///media/")){
+            char* fileName = g_filename_from_uri(uri.toUtf8().constData(),nullptr,nullptr);
+            if(fileName){
+                char* fileUri = g_filename_to_uri(fileName,nullptr,nullptr);
+                if(fileUri){
+                    uri = fileUri;
+                    g_free(fileUri);
+                }
+                g_free(fileName);
+            }
+        }
         auto file_info = FileInfo::fromUri(uri);
-        children<<file_info;
+        children << file_info;
     }
     return children;
 }
@@ -190,7 +199,8 @@ void FileEnumerator::cancel()
 
     m_children_uris->clear();
 
-    Q_EMIT enumerateFinished(false);
+    Q_EMIT this->cancelled();
+    //Q_EMIT enumerateFinished(false);
 }
 
 void FileEnumerator::prepare()
@@ -206,17 +216,14 @@ void FileEnumerator::prepare()
 
 GFile *FileEnumerator::enumerateTargetFile()
 {
-    //FIXME: replace BLOCKING api in ui thread.
     GFileInfo *info = g_file_query_info(m_root_file,
                                         G_FILE_ATTRIBUTE_STANDARD_TARGET_URI,
                                         G_FILE_QUERY_INFO_NONE,
                                         nullptr,
                                         nullptr);
     char *uri = nullptr;
-    uri = g_file_info_get_attribute_as_string(info,
-            G_FILE_ATTRIBUTE_STANDARD_TARGET_URI);
+    uri = g_file_info_get_attribute_as_string(info, G_FILE_ATTRIBUTE_STANDARD_TARGET_URI);
     g_object_unref(info);
-
     GFile *target = nullptr;
     if (uri) {
         //qDebug()<<"enumerateTargetFile"<<uri;
@@ -292,26 +299,27 @@ void FileEnumerator::handleError(GError *err)
     qDebug()<<"handleError"<<err->code<<err->message;
     switch (err->code) {
     case G_IO_ERROR_NOT_DIRECTORY: {
-        auto uri = g_file_get_uri(m_root_file);
-        //FIXME: replace BLOCKING api in ui thread.
-        auto targetUri = FileUtils::getTargetUri(uri);
-        if (uri) {
-            g_free(uri);
-        }
-        if (!targetUri.isEmpty()) {
-            prepared(nullptr, targetUri);
-            return;
-        }
+//        auto uri = g_file_get_uri(m_root_file);
+//        //FIXME: replace BLOCKING api in ui thread.
+//        auto targetUri = FileUtils::getTargetUri(uri);
+//        if (uri) {
+//            g_free(uri);
+//        }
+//        if (!targetUri.isEmpty()) {
+//            prepared(nullptr, targetUri);
+//            return;
+//        }
 
         bool isMountable = false;
-        //FIXME: replace BLOCKING api in ui thread.
-        GFileInfo *file_mount_info = g_file_query_info(m_root_file, G_FILE_ATTRIBUTE_MOUNTABLE_CAN_MOUNT,
-                                     G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS, nullptr, nullptr);
+        //FIXME: replace BLOCKING api in ui thread. Done
+        isMountable = FileInfo::fromGFile(m_root_file).get()->canMount();
+//        GFileInfo *file_mount_info = g_file_query_info(m_root_file, G_FILE_ATTRIBUTE_MOUNTABLE_CAN_MOUNT,
+//                                     G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS, nullptr, nullptr);
 
-        if (file_mount_info) {
-            isMountable = g_file_info_get_attribute_boolean(file_mount_info, G_FILE_ATTRIBUTE_MOUNTABLE_CAN_MOUNT);
-            g_object_unref(file_mount_info);
-        }
+//        if (file_mount_info) {
+//            isMountable = g_file_info_get_attribute_boolean(file_mount_info, G_FILE_ATTRIBUTE_MOUNTABLE_CAN_MOUNT);
+//            g_object_unref(file_mount_info);
+//        }
 
         if (isMountable) {
             g_file_mount_mountable(m_root_file,
@@ -342,15 +350,30 @@ void FileEnumerator::handleError(GError *err)
         break;
     case G_IO_ERROR_NOT_SUPPORTED:
         Peony::AudioPlayManager::getInstance()->playWarningAudio();
-        QMessageBox::critical(nullptr, tr("Error"), err->message);
+        Q_EMIT prepared(GErrorWrapper::wrapFrom(g_error_copy(err)), nullptr, true);
+        //QMessageBox::critical(nullptr, tr("Error"), err->message);
         break;
+    case G_IO_ERROR_EXISTS:
+    {
+        QString str_error = QObject::tr("file not found");
+        Q_EMIT prepared(GErrorWrapper::wrapFrom(g_error_new(G_IO_ERROR, G_IO_ERROR_EXISTS, "%s\n", str_error.toUtf8().constData())), nullptr, true);
+        break;
+    }
     case G_IO_ERROR_PERMISSION_DENIED:
+    {
         //emit error message to upper levels to process
-        Q_EMIT prepared(GErrorWrapper::wrapFrom(g_error_new(G_IO_ERROR, G_IO_ERROR_PERMISSION_DENIED, "permission denied")));
+        QString str_error = QObject::tr("permission denied");
+        Q_EMIT prepared(GErrorWrapper::wrapFrom(g_error_new(G_IO_ERROR, G_IO_ERROR_PERMISSION_DENIED, "%s\n", str_error.toUtf8().constData())), nullptr, true);
         break;
+    }
     case G_IO_ERROR_NOT_FOUND:
-        Q_EMIT prepared(GErrorWrapper::wrapFrom(g_error_new(G_IO_ERROR, G_IO_ERROR_NOT_FOUND, "file not found")));
+    {
+        QString str_error = QObject::tr("file not found");
+        Q_EMIT prepared(GErrorWrapper::wrapFrom(g_error_new(G_IO_ERROR, G_IO_ERROR_NOT_FOUND, "%s\n", str_error.toUtf8().constData())), nullptr, true);
+        //processed in file-item, comment to fix duplicated prompt
+        //QMessageBox::critical(nullptr, tr("Error"), tr("Did not find target path, do you move or deleted it?"));
         break;
+    }
     default:
         Q_EMIT prepared(GErrorWrapper::wrapFrom(g_error_copy(err)), nullptr, true);
         break;
@@ -361,16 +384,23 @@ void FileEnumerator::enumerateAsync()
 {
     m_idle->start(1000);
 
-    //auto uri = g_file_get_uri(m_root_file);
-    //auto path = g_file_get_path(m_root_file);
-    g_file_enumerate_children_async(m_root_file,
-                                    m_with_info_job? "*::*": G_FILE_ATTRIBUTE_STANDARD_NAME,
-                                    G_FILE_QUERY_INFO_NONE,
-                                    G_PRIORITY_DEFAULT,
-                                    m_cancellable,
-                                    GAsyncReadyCallback(find_children_async_ready_callback),
-                                    this);
+    // query directory info first
+    auto infoJob = new FileInfoJob(m_uri);
+    infoJob->setAutoDelete(true);
+    connect(infoJob, &FileInfoJob::queryAsyncFinished, this, [=](){
+        //auto uri = g_file_get_uri(m_root_file);
+        //auto path = g_file_get_path(m_root_file);
+        g_file_enumerate_children_async(m_root_file,
+                                        m_with_info_job? "*":
+                                        G_FILE_ATTRIBUTE_STANDARD_NAME "," G_FILE_ATTRIBUTE_STANDARD_TYPE "," G_FILE_ATTRIBUTE_STANDARD_DISPLAY_NAME,
+                                        G_FILE_QUERY_INFO_NONE,
+                                        G_PRIORITY_DEFAULT,
+                                        m_cancellable,
+                                        GAsyncReadyCallback(find_children_async_ready_callback),
+                                        this);
 
+    });
+    infoJob->queryAsync();
 }
 
 void FileEnumerator::enumerateChildren(GFileEnumerator *enumerator)
@@ -520,7 +550,7 @@ GAsyncReadyCallback FileEnumerator::find_children_async_ready_callback(GFile *fi
         if (err->code == G_IO_ERROR_NOT_MOUNTED) {
             g_object_unref(p_this->m_root_file);
             p_this->m_root_file = g_file_dup(file);
-            p_this->prepare();
+            //p_this->prepare();
             g_error_free(err);
             return nullptr;
         }
@@ -596,15 +626,23 @@ GAsyncReadyCallback FileEnumerator::enumerator_next_files_async_ready_callback(G
             g_free(path);
         } else {
             uriList<<uri;
-            *(p_this->m_cache_uris)<<uri;
+            auto urldecode = url.toDisplayString();
+            if (urldecode.startsWith("file:///media/")) {
+                *(p_this->m_cache_uris)<<urldecode;
+            } else {
+                *(p_this->m_cache_uris)<<uri;
+            }
         }
 
+        auto fileInfo = FileInfo::fromUri(uri);
+        FileInfoJob infoJob(fileInfo);
+        infoJob.queryFileType(info);
+        if(!strstr(uri,"kydroid:///") && !strstr(uri,"kmre:///"))
+            infoJob.queryFileDisplayName(info);
         if (p_this->m_with_info_job) {
-            auto fileInfo = FileInfo::fromUri(uri);
-            FileInfoJob infoJob(fileInfo);
             infoJob.refreshInfoContents(info);
-            p_this->m_cached_infos<<fileInfo;
         }
+        p_this->m_cached_infos<<fileInfo;
 
         g_free(uri);
         files_count++;
