@@ -29,70 +29,19 @@
 #include "file-operation-manager.h"
 
 #include <QProcess>
+#include <file-copy.h>
 
 using namespace Peony;
 
-static void handleDuplicate(FileNode *node) {
-    QString name = node->destBaseName();
-    QRegExp regExpNum("^\\(\\d+\\)");
-    QRegExp regExp("\\(\\d+\\)(\\.[0-9a-zA-Z]+|)$");
-    if (name.contains(regExp)) {
-        int num = 0;
-        QString numStr = "";
-
-        QString ext = regExp.cap(0);
-        if (ext.contains(regExpNum)) {
-            numStr = regExpNum.cap(0);
-        }
-
-        numStr.remove(0, 1);
-        numStr.chop(1);
-        num = numStr.toInt();
-        ++num;
-        name = name.replace(regExp, ext.replace(regExpNum, QString("(%1)").arg(num)));
-        node->setDestFileName(name);
-    } else {
-        if (name.contains(".")) {
-            auto list = name.split(".");
-            if (list.count() <= 1) {
-                node->setDestFileName(name+"(1)");
-            } else {
-                int pos = list.count() - 1;
-                if (list.last() == "gz" |
-                        list.last() == "xz" |
-                        list.last() == "Z" |
-                        list.last() == "sit" |
-                        list.last() == "bz" |
-                        list.last() == "bz2") {
-                    pos--;
-                }
-                if (pos < 0)
-                    pos = 0;
-                //list.insert(pos, "(1)");
-                auto tmp = list;
-                QStringList suffixList;
-                for (int i = 0; i < list.count() - pos; i++) {
-                    suffixList.prepend(tmp.takeLast());
-                }
-                auto suffix = suffixList.join(".");
-
-                auto basename = tmp.join(".");
-                name = basename + "(1)" + "." + suffix;
-                if (name.endsWith("."))
-                    name.chop(1);
-                node->setDestFileName(name);
-            }
-        } else {
-            name = name + "(1)";
-            node->setDestFileName(name);
-        }
-    }
+static void handleDuplicate(FileNode *node)
+{
+    node->setDestFileName(FileUtils::handleDuplicateName(node->destBaseName()));
 }
 
 FileMoveOperation::FileMoveOperation(QStringList sourceUris, QString destDirUri, QObject *parent) : FileOperation (parent)
 {
     m_source_uris = sourceUris;
-    m_dest_dir_uri = destDirUri;
+    m_dest_dir_uri = FileUtils::urlEncode(destDirUri);
     m_info = std::make_shared<FileOperationInfo>(sourceUris, destDirUri, FileOperationInfo::Move);
 }
 
@@ -102,6 +51,28 @@ FileMoveOperation::~FileMoveOperation()
         delete m_reporter;
 }
 
+void FileMoveOperation::setCopyMove(bool copyMove)
+{
+    m_copy_move = copyMove;
+}
+
+void FileMoveOperation::setAction(Qt::DropAction action)
+{
+    m_move_action = action;
+    m_info.get()->m_drop_action = action;
+    switch (action) {
+    case Qt::CopyAction: {
+        m_info.get()->m_type = FileOperationInfo::Copy;
+        m_info.get()->m_opposite_type = FileOperationInfo::Delete;
+        break;
+    }
+    default: {
+        m_info.get()->m_type = FileOperationInfo::Move;
+        break;
+    }
+    }
+}
+
 void FileMoveOperation::progress_callback(goffset current_num_bytes,
         goffset total_num_bytes,
         FileMoveOperation *p_this)
@@ -122,7 +93,7 @@ void FileMoveOperation::progress_callback(goffset current_num_bytes,
 
 ExceptionResponse FileMoveOperation::prehandle(GError *err)
 {
-    setHasError(true);
+    //setHasError(true);
     if (m_prehandle_hash.contains(err->code))
         return m_prehandle_hash.value(err->code);
 
@@ -138,7 +109,7 @@ void FileMoveOperation::move()
     for (auto srcUri : m_source_uris) {
         //FIXME: ignore the total size when using native move.
         operationPreparedOne(srcUri, 0);
-        auto node = new FileNode(srcUri, nullptr, nullptr);
+        auto node = new FileNode(FileUtils::urlEncode(srcUri), nullptr, nullptr);
         nodes<<node;
     }
     operationPrepared();
@@ -179,11 +150,17 @@ retry:
             setHasError(true);
             auto errWrapper = GErrorWrapper::wrapFrom(err);
             switch (errWrapper.get()->code()) {
-            case G_IO_ERROR_CANCELLED:
+            case G_IO_ERROR_CANCELLED: {
+                for (auto node : nodes) {
+                    delete node;
+                }
+                nodes.clear();
                 return;
+            }
             case G_IO_ERROR_NOT_SUPPORTED:
             case G_IO_ERROR_WOULD_RECURSE:
             case G_IO_ERROR_EXISTS: {
+                setHasError(false);
                 m_force_use_fallback = true;
                 for (auto node : nodes) {
                     delete node;
@@ -239,7 +216,6 @@ retry:
                 g_file_move(srcFile.get()->get(),
                             destFile.get()->get(),
                             GFileCopyFlags(G_FILE_COPY_NOFOLLOW_SYMLINKS|
-                                           G_FILE_COPY_ALL_METADATA|
                                            G_FILE_COPY_OVERWRITE),
                             getCancellable().get()->get(),
                             GFileProgressCallback(progress_callback),
@@ -253,7 +229,6 @@ retry:
                 g_file_move(srcFile.get()->get(),
                             destFile.get()->get(),
                             GFileCopyFlags(G_FILE_COPY_NOFOLLOW_SYMLINKS|
-                                           G_FILE_COPY_ALL_METADATA|
                                            G_FILE_COPY_OVERWRITE),
                             getCancellable().get()->get(),
                             GFileProgressCallback(progress_callback),
@@ -280,10 +255,15 @@ retry:
                         file->setDestFileName(name + "." + endStr);
                     }
                 }
-                if (FileUtils::isFileExsit(file->destUri())) {
+                while (FileUtils::isFileExsit(file->destUri())) {
                     handleDuplicate(file);
+                    file->resolveDestFileUri(m_dest_dir_uri);
                 }
                 auto handledDestFileUri = file->resolveDestFileUri(m_dest_dir_uri);
+                while (FileUtils::isFileExsit(handledDestFileUri))
+                {
+                    handledDestFileUri = file->resolveDestFileUri(m_dest_dir_uri);
+                }
                 auto handledDestFile = wrapGFile(g_file_new_for_uri(handledDestFileUri.toUtf8()));
                 g_file_copy(srcFile.get()->get(),
                             handledDestFile.get()->get(),
@@ -292,28 +272,19 @@ retry:
                             GFileProgressCallback(progress_callback),
                             this,
                             &handled_err);
+                setHasError(false);
                 break;
             }
             case BackupAll: {
-                file->setState(FileNode::Handled);
-                file->setErrorResponse(BackupOne);
-                auto handledDestFileUri = file->resolveDestFileUri(m_dest_dir_uri);
-                auto handledDestFile = wrapGFile(g_file_new_for_uri(handledDestFileUri.toUtf8()));
-                g_file_copy(srcFile.get()->get(),
-                            handledDestFile.get()->get(),
-                            GFileCopyFlags(m_default_copy_flag|G_FILE_COPY_BACKUP),
-                            getCancellable().get()->get(),
-                            GFileProgressCallback(progress_callback),
-                            this,
-                            &handled_err);
                 m_prehandle_hash.insert(err->code, BackupOne);
+                goto retry;
                 break;
             }
             case Retry: {
                 goto retry;
             }
             case Cancel: {
-                file->setState(FileNode::Handled);
+                file->setState(FileNode::Unhandled);
                 cancel();
                 break;
             }
@@ -347,64 +318,27 @@ retry:
         }
         //FIXME: ignore the total size when using native move.
         operationProgressedOne(file->uri(), file->destUri(), 0);
+        fileSync(file->uri(), file->destUri());
     }
     //native move has not clear operation.
     operationProgressed();
 
-    //rollback if cancelled
     //FIXME: if native move function get into error,
     //such as the target is existed, the rollback might
     //get into error too.
+
     if (isCancelled()) {
-        for (auto file : nodes) {
-            if (!file->destUri().isEmpty()) {
-                GFileWrapperPtr destFile = wrapGFile(g_file_new_for_uri(file->destUri().toUtf8().constData()));
-                GFileWrapperPtr srcFile = wrapGFile(g_file_new_for_uri(file->uri().toUtf8().constData()));
-                //try rollbacking
-                switch (file->responseType()) {
-                case Other: {
-                    //no error, move dest back to src
-                    g_file_move(destFile.get()->get(),
-                                srcFile.get()->get(),
-                                m_default_copy_flag,
-                                nullptr,
-                                nullptr,
-                                nullptr,
-                                nullptr);
-                    break;
-                }
-                case IgnoreOne: {
-                    break;
-                }
-                case OverWriteOne: {
-                    g_file_copy(destFile.get()->get(),
-                                srcFile.get()->get(),
-                                m_default_copy_flag,
-                                nullptr,
-                                nullptr,
-                                nullptr,
-                                nullptr);
-                    break;
-                }
-                case BackupOne: {
-                    g_file_copy(destFile.get()->get(),
-                                srcFile.get()->get(),
-                                m_default_copy_flag,
-                                nullptr,
-                                nullptr,
-                                nullptr,
-                                nullptr);
-                    break;
-                }
-                default:
-                    break;
-                }
-            }
+        for (auto node : nodes) {
+            rollbackNodeRecursively(node);
         }
     }
 
     //release node
+    m_info.get()->m_src_uris.clear();
+    m_info.get()->m_dest_uris.clear();
     for (auto file : nodes) {
+        m_info.get()->m_src_uris<<file->uri();
+        m_info.get()->m_dest_uris<<file->destUri();
         delete file;
     }
     nodes.clear();
@@ -412,118 +346,162 @@ retry:
 
 void FileMoveOperation::rollbackNodeRecursively(FileNode *node)
 {
-    switch (node->state()) {
-    case FileNode::Handling:
-    case FileNode::Handled: {
-        //do not clear the dest file if ignored or overwrite or backuped.
-        if (node->responseType() != Other)
-            break;
+    if (node->isFolder()) {
+        if (node->state() == FileNode::Handled) {
+            auto dir = wrapGFile(g_file_new_for_uri(node->uri().toUtf8().constData()));
+            g_file_make_directory(dir.get()->get(), nullptr, nullptr);
+        }
+        for (auto child : *node->children()) {
+            rollbackNodeRecursively(child);
+        }
 
-        if (node->isFolder()) {
-            auto children = node->children();
-            for (auto child : *children) {
-                rollbackNodeRecursively(child);
-            }
-            GFile *dest_file = g_file_new_for_uri(node->destUri().toUtf8().constData());
-            g_file_delete(dest_file, nullptr, nullptr);
-            g_object_unref(dest_file);
-        } else {
-            GFile *dest_file = g_file_new_for_uri(node->destUri().toUtf8().constData());
-            g_file_delete(dest_file, nullptr, nullptr);
-            g_object_unref(dest_file);
+        if (node->responseType() != OverWriteOne && node->responseType() != OverWriteAll && !isCancelled()) {
+            auto destDir = wrapGFile(g_file_new_for_uri(node->destUri().toUtf8().constData()));
+            g_file_delete(destDir.get()->get(), nullptr, nullptr);
         }
+
         operationRollbackedOne(node->destUri(), node->uri());
-        break;
-    }
-    case FileNode::Cleared: {
-        switch (node->responseType()) {
-        case Other: {
-            if (node->isFolder()) {
-                GFile *src_file = g_file_new_for_uri(node->uri().toUtf8().constData());
-                g_file_make_directory(src_file, nullptr, nullptr);
-                g_object_unref(src_file);
-                auto children = node->children();
-                for (auto child : *children) {
-                    rollbackNodeRecursively(child);
-                }
-                //try deleting the dest directory
-                GFile *dest_file = g_file_new_for_uri(node->destUri().toUtf8().constData());
-                g_file_delete(dest_file, nullptr, nullptr);
-                g_object_unref(dest_file);
+    } else {
+        switch (node->state()) {
+        case FileNode::Handled: {
+            auto sourceFile = wrapGFile(g_file_new_for_uri(node->uri().toUtf8().constData()));
+            auto destFile = wrapGFile(g_file_new_for_uri(node->destUri().toUtf8().constData()));
+            if (node->responseType() == OverWriteOne || node->responseType() == OverWriteAll) {
+                // note: this won't fully rollback, the file which has been overwriten will not be recovered.
+                g_file_copy(destFile.get()->get(), sourceFile.get()->get(), m_default_copy_flag, nullptr, nullptr, nullptr, nullptr);
+                break;
             } else {
-                GFile *dest_file = g_file_new_for_uri(node->destUri().toUtf8().constData());
-                GFile *src_file = g_file_new_for_uri(node->uri().toUtf8().constData());
-                //"rollback"
-                GError *err = nullptr;
-                g_file_move(dest_file,
-                            src_file,
-                            m_default_copy_flag,
-                            nullptr,
-                            nullptr,
-                            nullptr,
-                            &err);
-                if (err) {
-                    qDebug()<<node->destUri();
-                    qDebug()<<node->uri();
-                    qDebug()<<err->message;
-                    g_error_free(err);
-                }
-                g_object_unref(dest_file);
-                g_object_unref(src_file);
+                g_file_move(destFile.get()->get(), sourceFile.get()->get(), m_default_copy_flag, nullptr, nullptr, nullptr, nullptr);
             }
-            operationRollbackedOne(node->destUri(), node->uri());
             break;
         }
-        default: {
-            //copy if err handle response type is valid.
-            if (node->isFolder()) {
-                GFile *src_file = g_file_new_for_uri(node->uri().toUtf8().constData());
-                g_file_make_directory(src_file, nullptr, nullptr);
-                g_object_unref(src_file);
-                auto children = node->children();
-                for (auto child : *children) {
-                    rollbackNodeRecursively(child);
-                }
-                GFile *dest_file = g_file_new_for_uri(node->destUri().toUtf8().constData());
-                g_object_unref(dest_file);
-            } else {
-                GFile *dest_file = g_file_new_for_uri(node->destUri().toUtf8().constData());
-                GFile *src_file = g_file_new_for_uri(node->uri().toUtf8().constData());
-                //"rollback"
-                GError *err = nullptr;
-                g_file_copy(dest_file,
-                            src_file,
-                            m_default_copy_flag,
-                            nullptr,
-                            nullptr,
-                            nullptr,
-                            &err);
-                if (err) {
-                    qDebug()<<node->destUri();
-                    qDebug()<<node->uri();
-                    qDebug()<<err->message;
-                    g_error_free(err);
-                }
-                g_object_unref(dest_file);
-                g_object_unref(src_file);
+        case FileNode::Handling: {
+            if (node->responseType() == OverWriteOne || node->responseType() == OverWriteAll || node->responseType() == Cancel) {
+                break;
             }
-            operationRollbackedOne(node->destUri(), node->uri());
+            auto destFile = wrapGFile(g_file_new_for_uri(node->destUri().toUtf8().constData()));
+            g_file_delete(destFile.get()->get(), nullptr, nullptr);
             break;
         }
+        default:
+            break;
         }
-        break;
-    }
-    default: {
-        //make sure all nodes were rollbacked.
-        if (node->isFolder()) {
-            auto children = node->children();
-            for (auto child : *children) {
-                rollbackNodeRecursively(child);
-            }
-        }
-        break;
-    }
     }
+
+//    switch (node->state()) {
+//    case FileNode::Handling: {
+//        break;
+//    }
+//    case FileNode::Handled: {
+//        //do not clear the dest file if ignored or overwrite or backuped.
+//        if (node->responseType() != Other)
+//            break;
+
+//        if (node->isFolder()) {
+//            auto children = node->children();
+//            for (auto child : *children) {
+//                rollbackNodeRecursively(child);
+//            }
+//            GFile *dest_file = g_file_new_for_uri(node->destUri().toUtf8().constData());
+//            g_file_delete(dest_file, nullptr, nullptr);
+//            g_object_unref(dest_file);
+//        } else {
+//            GFile *dest_file = g_file_new_for_uri(node->destUri().toUtf8().constData());
+//            g_file_delete(dest_file, nullptr, nullptr);
+//            g_object_unref(dest_file);
+//        }
+//        operationRollbackedOne(node->destUri(), node->uri());
+//        break;
+//    }
+//    case FileNode::Cleared: {
+//        switch (node->responseType()) {
+//        case Other: {
+//            if (node->isFolder()) {
+//                GFile *src_file = g_file_new_for_uri(node->uri().toUtf8().constData());
+//                g_file_make_directory(src_file, nullptr, nullptr);
+//                g_object_unref(src_file);
+//                auto children = node->children();
+//                for (auto child : *children) {
+//                    rollbackNodeRecursively(child);
+//                }
+//                //try deleting the dest directory
+//                GFile *dest_file = g_file_new_for_uri(node->destUri().toUtf8().constData());
+//                g_file_delete(dest_file, nullptr, nullptr);
+//                g_object_unref(dest_file);
+//            } else {
+//                GFile *dest_file = g_file_new_for_uri(node->destUri().toUtf8().constData());
+//                GFile *src_file = g_file_new_for_uri(node->uri().toUtf8().constData());
+//                //"rollback"
+//                GError *err = nullptr;
+//                g_file_move(dest_file,
+//                            src_file,
+//                            m_default_copy_flag,
+//                            nullptr,
+//                            nullptr,
+//                            nullptr,
+//                            &err);
+//                if (err) {
+//                    qDebug()<<node->destUri();
+//                    qDebug()<<node->uri();
+//                    qDebug()<<err->message;
+//                    g_error_free(err);
+//                }
+//                g_object_unref(dest_file);
+//                g_object_unref(src_file);
+//            }
+//            operationRollbackedOne(node->destUri(), node->uri());
+//            break;
+//        }
+//        default: {
+//            //copy if err handle response type is valid.
+//            if (node->isFolder()) {
+//                GFile *src_file = g_file_new_for_uri(node->uri().toUtf8().constData());
+//                g_file_make_directory(src_file, nullptr, nullptr);
+//                g_object_unref(src_file);
+//                auto children = node->children();
+//                for (auto child : *children) {
+//                    rollbackNodeRecursively(child);
+//                }
+//                GFile *dest_file = g_file_new_for_uri(node->destUri().toUtf8().constData());
+//                g_object_unref(dest_file);
+//            } else {
+//                GFile *dest_file = g_file_new_for_uri(node->destUri().toUtf8().constData());
+//                GFile *src_file = g_file_new_for_uri(node->uri().toUtf8().constData());
+//                //"rollback"
+//                GError *err = nullptr;
+//                g_file_copy(dest_file,
+//                            src_file,
+//                            m_default_copy_flag,
+//                            nullptr,
+//                            nullptr,
+//                            nullptr,
+//                            &err);
+//                if (err) {
+//                    qDebug()<<node->destUri();
+//                    qDebug()<<node->uri();
+//                    qDebug()<<err->message;
+//                    g_error_free(err);
+//                }
+//                g_object_unref(dest_file);
+//                g_object_unref(src_file);
+//            }
+//            operationRollbackedOne(node->destUri(), node->uri());
+//            break;
+//        }
+//        }
+//        break;
+//    }
+//    default: {
+//        //make sure all nodes were rollbacked.
+//        if (node->isFolder()) {
+//            auto children = node->children();
+//            for (auto child : *children) {
+//                rollbackNodeRecursively(child);
+//            }
+//        }
+//        break;
+//    }
+//    }
 }
 
 void FileMoveOperation::copyRecursively(FileNode *node)
@@ -547,9 +525,12 @@ void FileMoveOperation::copyRecursively(FileNode *node)
     m_current_dest_dir_uri = dest_dir_uri;
     g_free(dest_dir_uri);
     g_object_unref(dest_parent);
+    QString destName = "";
 
 fallback_retry:
     if (node->isFolder()) {
+        auto realDestUri = node->resolveDestFileUri(m_dest_dir_uri);
+        destFile = wrapGFile(g_file_new_for_uri(realDestUri.toUtf8().constData()));
         GError *err = nullptr;
         auto fileIconName = FileUtils::getFileIconName(m_current_src_uri, false);
         auto destFileName = FileUtils::isFileDirectory(m_current_dest_dir_uri) ? nullptr : m_current_dest_dir_uri;
@@ -557,6 +538,7 @@ fallback_retry:
         Q_EMIT FileProgressCallback(m_current_src_uri, destFileName, fileIconName, node->size(), node->size());
         g_file_make_directory(destFile.get()->get(),getCancellable().get()->get(), &err);
         if (err) {
+            setHasError(true);
             FileOperationError except;
             if (err->code == G_IO_ERROR_CANCELLED) {
                 return;
@@ -602,19 +584,19 @@ fallback_retry:
                 break;
             }
             case OverWriteOne: {
-                node->setState(FileNode::Handled);
+                //node->setState(FileNode::Handled);
                 node->setErrorResponse(OverWriteOne);
                 //make dir has no overwrite
                 break;
             }
             case OverWriteAll: {
-                node->setState(FileNode::Handled);
+                //node->setState(FileNode::Handled);
                 node->setErrorResponse(OverWriteOne);
                 m_prehandle_hash.insert(err->code, OverWriteOne);
                 break;
             }
             case BackupOne: {
-                node->setState(FileNode::Handled);
+                //node->setState(FileNode::Handled);
                 node->setErrorResponse(BackupOne);
                 // use custom name
                 QString name = "";
@@ -633,29 +615,25 @@ fallback_retry:
                         node->setDestFileName(name);
                     }
                 }
-                if (FileUtils::isFileExsit(node->destUri())) {
+                node->resolveDestFileUri(m_dest_dir_uri);
+                while (FileUtils::isFileExsit(node->destUri())) {
                     handleDuplicate(node);
+                    node->resolveDestFileUri(m_dest_dir_uri);
                 }
                 g_object_unref(destFile.get());
                 destFile = wrapGFile(g_file_new_for_uri(node->destUri().toUtf8().constData()));
+                setHasError(false);
                 goto fallback_retry;
             }
             case BackupAll: {
-                node->setState(FileNode::Handled);
-                node->setErrorResponse(BackupOne);
-                if (FileUtils::isFileExsit(node->destUri())) {
-                    handleDuplicate(node);
-                }
                 m_prehandle_hash.insert(err->code, BackupOne);
-                g_object_unref(destFile.get());
-                destFile = wrapGFile(g_file_new_for_uri(node->destUri().toUtf8().constData()));
                 goto fallback_retry;
             }
             case Retry: {
                 goto fallback_retry;
             }
             case Cancel: {
-                node->setState(FileNode::Handled);
+                node->setState(FileNode::Unhandled);
                 cancel();
                 break;
             }
@@ -663,7 +641,7 @@ fallback_retry:
                 break;
             }
         } else {
-            node->setState(FileNode::Handled);
+            //node->setState(FileNode::Handled);
         }
 
         fileIconName = FileUtils::getFileIconName(m_current_src_uri, false);
@@ -678,19 +656,46 @@ fallback_retry:
     } else {
         GError *err = nullptr;
         GFileWrapperPtr sourceFile = wrapGFile(g_file_new_for_uri(node->uri().toUtf8().constData()));
-        g_file_copy(sourceFile.get()->get(),
-                    destFile.get()->get(),
-                    m_default_copy_flag,
-                    getCancellable().get()->get(),
-                    GFileProgressCallback(progress_callback),
-                    this,
-                    &err);
+        auto realDestUri = node->resolveDestFileUri(m_dest_dir_uri);
+        destFile = wrapGFile(g_file_new_for_uri(realDestUri.toUtf8().constData()));
+//        g_file_copy(sourceFile.get()->get(),
+//                    destFile.get()->get(),
+//                    m_default_copy_flag,
+//                    getCancellable().get()->get(),
+//                    GFileProgressCallback(progress_callback),
+//                    this,
+//                    &err);
+
+        FileCopy fileCopy (node->uri(), realDestUri, m_default_copy_flag,
+                           getCancellable().get()->get(),
+                           GFileProgressCallback(progress_callback),
+                           this,
+                           &err);
+        fileCopy.connect(this, &FileOperation::operationPause, &fileCopy, &FileCopy::pause, Qt::DirectConnection);
+        fileCopy.connect(this, &FileOperation::operationResume, &fileCopy, &FileCopy::resume, Qt::DirectConnection);
+        fileCopy.connect(this, &FileOperation::operationCancel, &fileCopy, &FileCopy::cancel, Qt::DirectConnection);
+        if (m_is_pause) fileCopy.pause();
+        fileCopy.run();
 
         if (err) {
-            FileOperationError except;
-            if (err->code == G_IO_ERROR_CANCELLED) {
+            setHasError(true);
+            switch (err->code) {
+            case G_IO_ERROR_CANCELLED:
                 return;
+            case G_IO_ERROR_INVALID_FILENAME: {
+                QString newDestUri;
+                if (makeFileNameValidForDestFS(m_current_src_uri, m_dest_dir_uri, &newDestUri)) {
+                    if (newDestUri != destName) {
+                        destName = newDestUri;
+                        node->setDestFileName(newDestUri);
+                        goto fallback_retry;
+                    }
+                }
+                break;
             }
+            }
+
+            FileOperationError except;
             auto errWrapperPtr = GErrorWrapper::wrapFrom(err);
             int handle_type = prehandle(err);
             except.isCritical = true;
@@ -728,26 +733,46 @@ fallback_retry:
                 break;
             }
             case OverWriteOne: {
-                g_file_copy(sourceFile.get()->get(),
-                            destFile.get()->get(),
-                            GFileCopyFlags(m_default_copy_flag | G_FILE_COPY_OVERWRITE),
-                            getCancellable().get()->get(),
-                            GFileProgressCallback(progress_callback),
-                            this,
-                            nullptr);
-                node->setState(FileNode::Handled);
+//                g_file_copy(sourceFile.get()->get(),
+//                            destFile.get()->get(),
+//                            GFileCopyFlags(m_default_copy_flag | G_FILE_COPY_OVERWRITE),
+//                            getCancellable().get()->get(),
+//                            GFileProgressCallback(progress_callback),
+//                            this,
+//                            nullptr);
+                FileCopy fileCopy (node->uri(), realDestUri, GFileCopyFlags(m_default_copy_flag | G_FILE_COPY_OVERWRITE),
+                                   getCancellable().get()->get(),
+                                   GFileProgressCallback(progress_callback),
+                                   this,
+                                   &err);
+                fileCopy.connect(this, &FileOperation::operationPause, &fileCopy, &FileCopy::pause, Qt::DirectConnection);
+                fileCopy.connect(this, &FileOperation::operationResume, &fileCopy, &FileCopy::resume, Qt::DirectConnection);
+                fileCopy.connect(this, &FileOperation::operationCancel, &fileCopy, &FileCopy::cancel, Qt::DirectConnection);
+                if (m_is_pause) fileCopy.pause();
+                fileCopy.run();
+                //node->setState(FileNode::Handled);
                 node->setErrorResponse(OverWriteOne);
                 break;
             }
             case OverWriteAll: {
-                g_file_copy(sourceFile.get()->get(),
-                            destFile.get()->get(),
-                            GFileCopyFlags(m_default_copy_flag | G_FILE_COPY_OVERWRITE),
-                            getCancellable().get()->get(),
-                            GFileProgressCallback(progress_callback),
-                            this,
-                            nullptr);
-                node->setState(FileNode::Handled);
+//                g_file_copy(sourceFile.get()->get(),
+//                            destFile.get()->get(),
+//                            GFileCopyFlags(m_default_copy_flag | G_FILE_COPY_OVERWRITE),
+//                            getCancellable().get()->get(),
+//                            GFileProgressCallback(progress_callback),
+//                            this,
+//                            nullptr);
+                FileCopy fileCopy (node->uri(), realDestUri, GFileCopyFlags(m_default_copy_flag | G_FILE_COPY_OVERWRITE),
+                                   getCancellable().get()->get(),
+                                   GFileProgressCallback(progress_callback),
+                                   this,
+                                   &err);
+                fileCopy.connect(this, &FileOperation::operationPause, &fileCopy, &FileCopy::pause, Qt::DirectConnection);
+                fileCopy.connect(this, &FileOperation::operationResume, &fileCopy, &FileCopy::resume, Qt::DirectConnection);
+                fileCopy.connect(this, &FileOperation::operationCancel, &fileCopy, &FileCopy::cancel, Qt::DirectConnection);
+                if (m_is_pause) fileCopy.pause();
+                fileCopy.run();
+                //node->setState(FileNode::Handled);
                 node->setErrorResponse(OverWriteOne);
                 m_prehandle_hash.insert(err->code, OverWriteOne);
                 break;
@@ -768,43 +793,44 @@ fallback_retry:
                         node->setDestFileName(name + "." + endStr);
                     }
                 }
-                if (FileUtils::isFileExsit(node->destUri())) {
+                while (FileUtils::isFileExsit(node->destUri())) {
                     handleDuplicate(node);
+                    node->resolveDestFileUri(m_dest_dir_uri);
                 }
                 auto handledDestFileUri = node->resolveDestFileUri(m_dest_dir_uri);
                 auto handledDestFile = wrapGFile(g_file_new_for_uri(handledDestFileUri.toUtf8()));
-                g_file_copy(sourceFile.get()->get(),
-                            handledDestFile.get()->get(),
-                            GFileCopyFlags(m_default_copy_flag | G_FILE_COPY_BACKUP),
-                            getCancellable().get()->get(),
-                            GFileProgressCallback(progress_callback),
-                            this,
-                            nullptr);
-                node->setState(FileNode::Handled);
+//                g_file_copy(sourceFile.get()->get(),
+//                            handledDestFile.get()->get(),
+//                            GFileCopyFlags(m_default_copy_flag | G_FILE_COPY_BACKUP),
+//                            getCancellable().get()->get(),
+//                            GFileProgressCallback(progress_callback),
+//                            this,
+//                            nullptr);
+                FileCopy fileCopy (node->uri(), realDestUri, GFileCopyFlags(m_default_copy_flag | G_FILE_COPY_BACKUP),
+                                   getCancellable().get()->get(),
+                                   GFileProgressCallback(progress_callback),
+                                   this,
+                                   &err);
+                fileCopy.connect(this, &FileOperation::operationPause, &fileCopy, &FileCopy::pause, Qt::DirectConnection);
+                fileCopy.connect(this, &FileOperation::operationResume, &fileCopy, &FileCopy::resume, Qt::DirectConnection);
+                fileCopy.connect(this, &FileOperation::operationCancel, &fileCopy, &FileCopy::cancel, Qt::DirectConnection);
+                if (m_is_pause) fileCopy.pause();
+                fileCopy.run();
+                //node->setState(FileNode::Handled);
                 node->setErrorResponse(BackupOne);
+                setHasError(false);
                 break;
             }
             case BackupAll: {
-                handleDuplicate(node);
-                auto handledDestFileUri = node->resolveDestFileUri(m_dest_dir_uri);
-                auto handledDestFile = wrapGFile(g_file_new_for_uri(handledDestFileUri.toUtf8()));
-                g_file_copy(sourceFile.get()->get(),
-                            handledDestFile.get()->get(),
-                            GFileCopyFlags(m_default_copy_flag | G_FILE_COPY_BACKUP),
-                            getCancellable().get()->get(),
-                            GFileProgressCallback(progress_callback),
-                            this,
-                            nullptr);
-                node->setState(FileNode::Handled);
-                node->setErrorResponse(BackupOne);
                 m_prehandle_hash.insert(err->code, BackupOne);
+                goto fallback_retry;
                 break;
             }
             case Retry: {
                 goto fallback_retry;
             }
             case Cancel: {
-                node->setState(FileNode::Handled);
+                node->setErrorResponse(Cancel);
                 cancel();
                 break;
             }
@@ -812,8 +838,9 @@ fallback_retry:
                 break;
             }
         } else {
-            node->setState(FileNode::Handled);
+            //node->setState(FileNode::Handled);
         }
+        fileSync(node->uri(), realDestUri);
         m_current_offset += node->size();
         auto fileIconName = FileUtils::getFileIconName(m_current_src_uri, false);
         auto destFileName = FileUtils::isFileDirectory(node->destUri()) ? nullptr : node->destUri();
@@ -834,18 +861,17 @@ void FileMoveOperation::deleteRecursively(FileNode *node)
         for (auto child : *(node->children())) {
             deleteRecursively(child);
         }
-        g_file_delete(file,
-                      getCancellable().get()->get(),
-                      nullptr);
-        node->setState(FileNode::Cleared);
+        if (node->state() != FileNode::Unhandled) {
+            g_file_delete(file, getCancellable().get()->get(), nullptr);
+            node->setState(FileNode::Handled);
+        }
     } else {
-        g_file_delete(file,
-                      getCancellable().get()->get(),
-                      nullptr);
-        node->setState(FileNode::Cleared);
+        if (node->state() != FileNode::Unhandled) {
+            g_file_delete(file, getCancellable().get()->get(), nullptr);
+            node->setState(FileNode::Handled);
+        }
     }
     g_object_unref(file);
-    qDebug()<<"deleted";
     operationAfterProgressedOne(node->uri());
 }
 
@@ -878,10 +904,14 @@ void FileMoveOperation::moveForceUseFallback()
     }
     operationProgressed();
 
-    if (!m_copy_move) {
+    if (m_move_action == Qt::TargetMoveAction) {
+        m_info.get()->m_type = FileOperationInfo::Move;
         for (auto node : nodes) {
             deleteRecursively(node);
         }
+    } else {
+        m_info.get()->m_type = FileOperationInfo::Copy;
+        m_info.get()->m_opposite_type = FileOperationInfo::Delete;
     }
 
     if (isCancelled())
@@ -889,12 +919,16 @@ void FileMoveOperation::moveForceUseFallback()
 
     for (auto file : nodes) {
         qDebug()<<file->uri();
-        if (isCancelled() && !hasError()) {
+        if (isCancelled()) {
             rollbackNodeRecursively(file);
         }
     }
 
+    m_info.get()->m_src_uris.clear();
+    m_info.get()->m_dest_uris.clear();
     for (auto node : nodes) {
+        m_info.get()->m_src_uris<<node->uri();
+        m_info.get()->m_dest_uris<<node->destUri();
         delete node;
     }
 
@@ -969,14 +1003,24 @@ start:
     if (m_force_use_fallback) {
         moveForceUseFallback();
         operationStartSnyc();
-        QProcess p;
-        p.start("sync");
-        p.waitForFinished(-1);
+
+        auto info = getOperationInfo();
+        auto destDirUri = info.get()->m_dest_dir_uri;
+        auto dest_file = g_file_new_for_uri(destDirUri.toUtf8().constData());
+        auto path = g_file_get_path(dest_file);
+        g_object_unref(dest_file);
+//        if (path) {
+//            QProcess p;
+//            auto shell_path = g_shell_quote(path);
+//            g_free(path);
+//            p.start(QString("sync -d %1").arg(shell_path));
+//            g_free(shell_path);
+//            p.waitForFinished(-1);
+//        }
     }
     qDebug()<<"finished";
 end:
     Q_EMIT operationFinished();
-    //notifyFileWatcherOperationFinished();
 }
 
 void FileMoveOperation::cancel()
