@@ -44,6 +44,10 @@
 #include "file-watcher.h"
 #include "audio-play-manager.h"
 
+#include "properties-window.h"
+
+#include <QVector4D>
+
 #include <QDebug>
 
 using namespace Peony;
@@ -66,9 +70,7 @@ FileOperationManager::FileOperationManager(QObject *parent) : QObject(parent)
 
     //
     connect(m_progressbar, &FileOperationProgressBar::canceled, [=] () {
-        if (!m_allow_parallel) {
-            m_progressbar->removeAllProgressbar();
-        }
+        m_progressbar->removeAllProgressbar();
     });
 }
 
@@ -111,6 +113,64 @@ bool FileOperationManager::isAllowParallel()
 
 void FileOperationManager::startOperation(FileOperation *operation, bool addToHistory)
 {
+    auto operationInfo = operation->getOperationInfo();
+
+    if (operationInfo.get()->operationType() == FileOperationInfo::Trash) {
+        auto value = GlobalSettings::getInstance()->getValue("showTrashDialog");
+        if (value.isValid()) {
+            if (value.toBool() == false) {
+                goto start;
+            }
+        }
+        // check dialog
+        QMessageBox questionBox;
+        questionBox.addButton(QMessageBox::Yes);
+        questionBox.addButton(QMessageBox::No);
+        questionBox.addButton(tr("No, go to settings"), QMessageBox::ActionRole);
+        questionBox.setText(tr("Do you want to put selected %1 item(s) into trash?").arg(operationInfo.get()->sources().count()));
+        auto result = questionBox.exec();
+
+        if (result != QMessageBox::Yes) {
+            if (result != QMessageBox::No) {
+                // settings
+                QStringList uris;
+                uris<<"trash:///";
+                auto propertyWindow = new PropertiesWindow(uris);
+                propertyWindow->show();
+            }
+            return;
+        }
+    }
+
+    // do not add move operation between favorite:///
+    // FIXME: due to some desgin issues, we can not
+    // support undo/redo with favorite:/// yet. that
+    // should be fixed in the future.
+
+    // dnd use copy move mode here between different
+    // file system, so we should better check operation class,
+    // not operation info type.
+    if (dynamic_cast<FileMoveOperation *>(operation)) {
+        if (addToHistory) {
+            for (QString uri : operationInfo.get()->sources()) {
+                if (uri.startsWith("favorite:///")) {
+                    addToHistory = false;
+                    break;
+                }
+            }
+            if (addToHistory) {
+                for (QString uri : operationInfo.get()->dests()) {
+                    if (uri.startsWith("favorite:///")) {
+                        addToHistory = false;
+                        break;
+                    }
+                }
+            }
+        }
+    }
+
+start:
+
     QApplication::setQuitOnLastWindowClosed(false);
 
     connect(operation, &FileOperation::operationFinished, this, [=]() {
@@ -131,7 +191,7 @@ void FileOperationManager::startOperation(FileOperation *operation, bool addToHi
         });
     }, Qt::BlockingQueuedConnection);
 
-    auto operationInfo = operation->getOperationInfo();
+
 
     bool allowParallel = m_allow_parallel;
 
@@ -185,10 +245,15 @@ void FileOperationManager::startOperation(FileOperation *operation, bool addToHi
    proc->connect(operation, &FileOperation::operationRollbackedOne, proc, &ProgressBar::onFileRollbacked);
    proc->connect(operation, &FileOperation::operationStartSnyc, proc, &ProgressBar::onStartSync);
    proc->connect(operation, &FileOperation::operationFinished, proc, &ProgressBar::onFinished);
-   proc->connect(proc, &ProgressBar::cancelled, operation, &Peony::FileOperation::cancel);
+   proc->connect(proc, &ProgressBar::cancelled, operation, &FileOperation::cancel);
+   proc->connect(proc, &ProgressBar::cancelled, operation, &FileOperation::operationCancel);
+   proc->connect(proc, &ProgressBar::pause, operation, &FileOperation::operationPause);
+   proc->connect(proc, &ProgressBar::resume, operation, &FileOperation::operationResume);
+
    operation->connect(operation, &FileOperation::errored, [=]() {
        operation->setHasError(true);
    });
+
    operation->connect(operation, &FileOperation::errored, this, &FileOperationManager::handleError, Qt::BlockingQueuedConnection);
    operation->connect(operation, &FileOperation::operationFinished, this, [=](){
        Q_EMIT this->operationFinished(operation->getOperationInfo(), !operation->hasError());
@@ -256,6 +321,8 @@ void FileOperationManager::startUndoOrRedo(std::shared_ptr<FileOperationInfo> in
     }
     case FileOperationInfo::Move: {
         op = new FileMoveOperation(info->m_src_uris, info->m_dest_dir_uri);
+        auto moveOp = qobject_cast<FileMoveOperation *>(op);
+        moveOp->setAction(info->m_drop_action);
         break;
     }
     case FileOperationInfo::Rename: {
@@ -263,9 +330,7 @@ void FileOperationManager::startUndoOrRedo(std::shared_ptr<FileOperationInfo> in
             op = new FileRenameOperation(info->m_src_uris.isEmpty()? nullptr: info->m_src_uris.at(0),
                                          info->m_dest_dir_uri);
         } else {
-            auto destUri = info->m_node_map.first();
-            QUrl url = destUri;
-            op = new FileRenameOperation(info->m_node_map.firstKey(), url.fileName());
+            op = new FileRenameOperation(info->m_node_map.firstKey(), info.get()->m_newname);
         }
         break;
     }
@@ -362,6 +427,15 @@ void FileOperationManager::handleError(FileOperationError &error)
         if (m_progressbar->isHidden()) {
             m_progressbar->m_error = true;
         }
+        auto dialog = dynamic_cast<QWidget *>(handle);
+        if (dialog) {
+            dialog->setProperty("useCustomShadow", true);
+            dialog->setProperty("customShadowDarkness", 0.5);
+            dialog->setProperty("customShadowWidth", 30);
+            dialog->setProperty("customShadowRadius", QVector4D(1, 1, 1, 1));
+            dialog->setProperty("customShadowMargins", QVector4D(30, 30, 30, 30));
+        }
+
         handle->handle(error);
         delete handle;
         m_progressbar->m_error = false;
@@ -381,25 +455,53 @@ void FileOperationManager::unregisterFileWatcher(FileWatcher *watcher)
 
 void FileOperationManager::manuallyNotifyDirectoryChanged(FileOperationInfo *info)
 {
-    if (!info)
+    if (!info) {
         return;
+    }
 
     // skip create template opeartion, it will be handled by operation itself.
-    if (info->m_src_dir_uri == QStandardPaths::writableLocation(QStandardPaths::TempLocation))
+    if (info->m_src_dir_uri == QStandardPaths::writableLocation(QStandardPaths::TempLocation)) {
         return;
+    }
 
     for (auto watcher : m_watchers) {
         if (!watcher->supportMonitor()) {
             auto srcDir = info->m_src_dir_uri;
             auto destDir = info->m_dest_dir_uri;
+            auto firstUri = info->m_src_uris.first();
             if (info->operationType() == FileOperationInfo::Link || info->operationType() == FileOperationInfo::Rename) {
-                srcDir = FileUtils::getParentUri(info->m_src_uris.first());
+                srcDir = FileUtils::getParentUri(firstUri);
             }
+
+            if ("" == srcDir) {
+                if (firstUri.endsWith("/")) {
+                    firstUri.chop(1);
+                }
+
+                QStringList fileSplit = firstUri.split("/");
+                fileSplit.pop_back();
+
+                srcDir = fileSplit.join("/");
+            }
+
             // check watcher directory
+            // srcDir is null in samba filesystem, so that it not work
+            // currentUri maybe is 'file:///run/user/1000/gvfs/smb-share:server=xxx,share=xxx/' or 'smb://xxx'
             if (watcher->currentUri() == srcDir || watcher->currentUri() == destDir) {
                 // tell the view/model the directory should be updated
                 watcher->requestUpdateDirectory();
             }
+
+            qDebug() << "src:" << srcDir << " == dest:" << destDir << " == type:" << info->operationType();
+
+            if (srcDir.startsWith("smb://")
+                 || srcDir.startsWith("ftp://")
+                 || srcDir.startsWith("sftp://")
+                 || destDir.startsWith("smb://")
+                 || destDir.startsWith("ftp://")
+                 || destDir.startsWith("sftp://")) {
+                watcher->requestUpdateDirectory();
+            }
         }
     }
 }
@@ -440,7 +542,7 @@ void FileOperationInfo::oppositeInfoConstruct(Type type)
         }
         case Trash: {
             m_opposite_type = Untrash;
-            commonOppositeInfoConstruct();
+            trashOppositeInfoConstruct();
             break;
         }
         case Untrash: {
@@ -529,9 +631,21 @@ void FileOperationInfo::UntrashOppositeInfoConstruct()
     return;
 }
 
+void FileOperationInfo::trashOppositeInfoConstruct()
+{
+    // note that this function is unreliable.
+    // the info would be updated while FileTrashOperation::run()
+    // again.
+    commonOppositeInfoConstruct();
+}
+
 std::shared_ptr<FileOperationInfo> FileOperationInfo::getOppositeInfo(FileOperationInfo *info) {
 
     auto oppositeInfo = std::make_shared<FileOperationInfo>(info->m_dest_uris, info->m_src_dir_uri, m_opposite_type);
+    if (info->m_drop_action == Qt::TargetMoveAction) {
+        oppositeInfo->m_drop_action = Qt::TargetMoveAction;
+        oppositeInfo->m_type = FileOperationInfo::Move;
+    }
     QMap<QString, QString> oppsiteMap;
     for (auto key : m_node_map.keys()) {
         auto value = m_node_map.value(key);
