@@ -109,6 +109,8 @@ const QString FileItem::uri()
     return m_info->uri();
 }
 
+#include"file-operation-manager.h"
+
 QVector<FileItem*> *FileItem::findChildrenSync()
 {
     Q_EMIT m_model->findChildrenStarted();
@@ -145,9 +147,12 @@ void FileItem::findChildrenAsync()
     //NOTE: entry a new root might destroyed the current enumeration work.
     //the root item will be delete, so we should cancel the previous enumeration.
     enumerator->connect(this, &FileItem::cancelFindChildren, enumerator, &FileEnumerator::cancel);
+    enumerator->connect(enumerator, &FileEnumerator::cancelled, m_model, [=](){
+        m_model->findChildrenFinished();
+    });
     enumerator->connect(enumerator, &FileEnumerator::prepared, this, [=](std::shared_ptr<GErrorWrapper> err, const QString &targetUri, bool critical) {
         if (critical) {
-            Peony::AudioPlayManager::getInstance()->playWarningAudio();
+            //Peony::AudioPlayManager::getInstance()->playWarningAudio();
             QMessageBox::critical(nullptr, tr("Error"), err->message());
             enumerator->cancel();
             return;
@@ -160,15 +165,7 @@ void FileItem::findChildrenAsync()
                 GFile *targetFile = g_file_new_for_uri(targetUri.toUtf8().constData());
                 QUrl targetUrl = targetUri;
                 auto path = g_file_get_path(targetFile);
-                if (path && !targetUrl.isLocalFile() && false) {
-                    QString localUri = QString("file://%1").arg(path);
-                    this->m_info = FileInfo::fromUri(localUri);
-                    enumerator->setEnumerateDirectory(localUri);
-                    g_free(path);
-                } else {
-                    enumerator->setEnumerateDirectory(targetFile);
-                }
-
+                enumerator->setEnumerateDirectory(targetFile);
                 g_object_unref(targetFile);
             }
 
@@ -176,7 +173,6 @@ void FileItem::findChildrenAsync()
             return;
         }
 
-        //FIXME: replace BLOCKING api in ui thread.
         auto target = FileUtils::getTargetUri(m_info->uri());
         if (!target.isEmpty()) {
             enumerator->cancel();
@@ -186,20 +182,20 @@ void FileItem::findChildrenAsync()
         }
         if (err) {
             qDebug()<<"file item error:" <<err->message()<<enumerator->getEnumerateUri();
-            Peony::AudioPlayManager::getInstance()->playWarningAudio();
+            //Peony::AudioPlayManager::getInstance()->playWarningAudio();
             if (err.get()->code() == G_IO_ERROR_NOT_FOUND || err.get()->code() == G_IO_ERROR_PERMISSION_DENIED) {
                 enumerator->cancel();
                 //fix goto removed path in case device is ejected
                 if (this->uri().startsWith("file:///media"))
                 {
                     //check bookmark and delete
-                    BookMarkManager::getInstance()->removeBookMark(this->uri());
-                    m_model->setRootUri("computer:///");
+                    BookMarkManager::getInstance()->removeBookMark(uri2FavoriteUri(this->uri()));
+                    m_model->sendPathChangeRequest("computer:///");
                 }
                 else
                     m_model->setRootUri(FileUtils::getParentUri(this->uri()));
 
-                auto fileInfo = FileInfo::fromUri(this->uri(), false);
+                auto fileInfo = FileInfo::fromUri(this->uri());
                 if (err.get()->code() == G_IO_ERROR_NOT_FOUND && fileInfo->isSymbolLink())
                 {
                     auto result = QMessageBox::question(nullptr, tr("Open Link failed"),
@@ -275,7 +271,7 @@ void FileItem::findChildrenAsync()
                         }
                     });
 
-                    connect(job, &FileInfoJob::infoUpdated, this, [=](){
+                    connect(job, &FileInfoJob::infoUpdated, child, [=](){
                         m_model->dataChanged(child->firstColumnIndex(), child->lastColumnIndex());
                     });
 
@@ -290,25 +286,27 @@ void FileItem::findChildrenAsync()
             enumerator->cancel();
             delete enumerator;
 
-            m_watcher = std::make_shared<FileWatcher>(this->m_info->uri());
+            m_watcher = std::make_shared<FileWatcher>(this->m_info->uri(), nullptr, true);
             m_watcher->setMonitorChildrenChange(true);
             connect(m_watcher.get(), &FileWatcher::fileCreated, this, [=](QString uri) {
                 //add new item to m_children
                 //tell the model update
                 this->onChildAdded(uri);
                 Q_EMIT this->childAdded(uri);
+                qDebug() << "inpositive Model onChildAdded:" <<uri;
             });
             connect(m_watcher.get(), &FileWatcher::fileDeleted, this, [=](QString uri) {
                 //check bookmark and delete
-                auto info = FileInfo::fromUri(uri, false);
+                auto info = FileInfo::fromUri(uri);
                 if (info->isDir())
                 {
-                    BookMarkManager::getInstance()->removeBookMark(uri);
+                    BookMarkManager::getInstance()->removeBookMark(uri2FavoriteUri(uri));
                 }
                 //remove the crosponding child
                 //tell the model update
                 this->onChildRemoved(uri);
                 Q_EMIT this->childRemoved(uri);
+                ThumbnailManager::getInstance()->releaseThumbnail(uri);
             });
             connect(m_watcher.get(), &FileWatcher::fileChanged, this, [=](const QString &uri) {
                 auto index = m_model->indexFromUri(uri);
@@ -328,6 +326,10 @@ void FileItem::findChildrenAsync()
                     infoJob->queryAsync();
                 }
             });
+            connect(m_watcher.get(), &FileWatcher::fileRenamed, this, [=](const QString &oldUri, const QString &newUri) {
+                Q_EMIT this->renamed(oldUri, newUri);
+                this->onRenamed(oldUri, newUri);
+            });
             connect(m_watcher.get(), &FileWatcher::thumbnailUpdated, this, [=](const QString &uri) {
                 m_model->dataChanged(m_model->indexFromUri(uri), m_model->indexFromUri(uri));
             });
@@ -345,7 +347,7 @@ void FileItem::findChildrenAsync()
             });
 
             connect(m_watcher.get(), &FileWatcher::directoryUnmounted, this, [=]() {
-                m_model->setRootUri("computer:///");
+                m_model->sendPathChangeRequest("computer:///");
             });
             //qDebug()<<"startMonitor";
 
@@ -387,7 +389,7 @@ void FileItem::findChildrenAsync()
 
                     m_ending_uris.removeOne(uri);
                     if (isEnding && m_ending_uris.isEmpty()) {
-                        qApp->processEvents();
+                        //qApp->processEvents();
                         Q_EMIT m_model->findChildrenFinished();
                         Q_EMIT m_model->updated();
                     }
@@ -407,26 +409,29 @@ void FileItem::findChildrenAsync()
             if (!m_model||!m_children||!m_info)
                 return;
 
-            m_watcher = std::make_shared<FileWatcher>(this->m_info->uri());
+            m_watcher = std::make_shared<FileWatcher>(this->m_info->uri(), nullptr, true);
             m_watcher->setMonitorChildrenChange(true);
             connect(m_watcher.get(), &FileWatcher::fileCreated, this, [=](QString uri) {
                 //add new item to m_children
                 //tell the model update
                 this->onChildAdded(uri);
                 Q_EMIT this->childAdded(uri);
+                qDebug() << "positive onChildAdded:" <<uri;
                 ThumbnailManager::getInstance()->createThumbnail(uri, m_thumbnail_watcher);
             });
             connect(m_watcher.get(), &FileWatcher::fileDeleted, this, [=](QString uri) {
                 //check bookmark and delete
-                auto info = FileInfo::fromUri(uri, false);
+                auto info = FileInfo::fromUri(uri);
                 if (info->isDir())
                 {
-                    BookMarkManager::getInstance()->removeBookMark(uri);
+                    BookMarkManager::getInstance()->removeBookMark(uri2FavoriteUri(uri));
                 }
                 //remove the crosponding child
                 //tell the model update
                 this->onChildRemoved(uri);
                 Q_EMIT this->childRemoved(uri);
+                qDebug() << "childRemoved:" <<uri;
+                ThumbnailManager::getInstance()->releaseThumbnail(uri);
             });
             connect(m_watcher.get(), &FileWatcher::fileChanged, this, [=](const QString &uri) {
                 auto index = m_model->indexFromUri(uri);
@@ -443,6 +448,9 @@ void FileItem::findChildrenAsync()
                     infoJob->queryAsync();
                 }
             });
+            connect(m_watcher.get(), &FileWatcher::fileRenamed, this, [=](const QString &oldUri, const QString &newUri) {
+                this->onRenamed(oldUri, newUri);
+            });
             connect(m_watcher.get(), &FileWatcher::thumbnailUpdated, this, [=](const QString &uri) {
                 m_model->dataChanged(m_model->indexFromUri(uri), m_model->indexFromUri(uri));
             });
@@ -459,7 +467,7 @@ void FileItem::findChildrenAsync()
             });
 
             connect(m_watcher.get(), &FileWatcher::directoryUnmounted, this, [=]() {
-                m_model->setRootUri("computer:///");
+                m_model->sendPathChangeRequest("computer:///");
             });
             //qDebug()<<"startMonitor";
             connect(m_watcher.get(), &FileWatcher::requestUpdateDirectory, this, &FileItem::onUpdateDirectoryRequest);
@@ -488,6 +496,13 @@ bool FileItem::hasChildren()
 
 FileItem *FileItem::getChildFromUri(QString uri)
 {
+    // optimize
+    auto index = m_model->indexFromUri(uri);
+    if (index.isValid()) {
+        return m_model->itemFromIndex(index);
+    }
+    return nullptr;
+    /*
     for (auto item : *m_children) {
         QUrl itemUrl = item->uri();
         QUrl url = uri;
@@ -496,6 +511,7 @@ FileItem *FileItem::getChildFromUri(QString uri)
             return item;
     }
     return nullptr;
+    */
 }
 
 void FileItem::onChildAdded(const QString &uri)
@@ -503,24 +519,42 @@ void FileItem::onChildAdded(const QString &uri)
     qDebug()<<"add child:" << uri;
     FileItem *child = getChildFromUri(uri);
     if (child) {
-        qDebug()<<"has added";
+        qDebug()<<"has added, return";
         //child info maybe changed, so need sync update again
         child->updateInfoAsync();
         //m_model->updated();
         return;
     }
 
+    //add waiting queue to fix show item duplicated issue
+    if (m_waiting_add_queue.contains(uri))
+    {
+        qDebug()<<"is in m_waiting_add_queue, return";
+        return;
+    }
+
     auto info = FileInfo::fromUri(uri);
     auto infoJob = new FileInfoJob(info);
     infoJob->setAutoDelete();
+    m_waiting_add_queue.append(uri);
     infoJob->connect(infoJob, &FileInfoJob::infoUpdated, this, [=]() {
-        auto item = new FileItem(info, this, m_model);
-        m_model->beginInsertRows(firstColumnIndex(), m_children->count(), m_children->count());
-        m_children->append(item);
-        m_model->endInsertRows();
-        //Q_EMIT m_model->dataChanged(item->firstColumnIndex(), item->lastColumnIndex());
-        //Q_EMIT m_model->updated();
-        ThumbnailManager::getInstance()->createThumbnail(info->uri(), m_thumbnail_watcher);
+        m_waiting_add_queue.removeOne(uri);
+        auto item = getChildFromUri(uri);
+        // add exsited checkment. link to: #66999
+        if (!item) {
+            item = new FileItem(info, this, m_model);
+            m_model->beginInsertRows(firstColumnIndex(), m_children->count(), m_children->count());
+            m_children->append(item);
+            m_model->endInsertRows();
+            qDebug() <<"successfully added child:" <<uri;
+            //Q_EMIT m_model->dataChanged(item->firstColumnIndex(), item->lastColumnIndex());
+            //Q_EMIT m_model->updated();
+            QTimer::singleShot(1000, this, [=](){
+                ThumbnailManager::getInstance()->createThumbnail(info->uri(), m_thumbnail_watcher);
+            });
+        } else {
+            qInfo()<<"file"<<uri<<"has arealy in file item model";
+        }
     });
     infoJob->queryAsync();
 
@@ -535,11 +569,15 @@ void FileItem::onChildAdded(const QString &uri)
 
 void FileItem::onChildRemoved(const QString &uri)
 {
+    // fix #62925
+    m_waiting_add_queue.removeOne(uri);
+
     FileItem *child = getChildFromUri(uri);
     if (child) {
         int index = m_children->indexOf(child);
         m_model->beginRemoveRows(this->firstColumnIndex(), index, index);
         m_children->removeOne(child);
+        qDebug() <<"successfully removed child:" <<uri;
         delete child;
         m_model->endRemoveRows();
     }
@@ -588,11 +626,14 @@ void FileItem::onDeleted(const QString &thisUri)
 void FileItem::onRenamed(const QString &oldUri, const QString &newUri)
 {
     qDebug()<<"renamed";
-    Q_UNUSED(oldUri);
-    if (m_parent) {
-        FileItem *newRootItem = new FileItem(FileInfo::fromUri(newUri), nullptr, m_model);
-        m_model->setRootItem(newRootItem);
+
+    FileItem *child = getChildFromUri(oldUri);
+    if (child) {
+       int index = m_children->indexOf(child);
+        m_children->at(index)->m_info= FileInfo::fromUri(newUri);
+        child->updateInfoAsync();
     }
+
 }
 
 void FileItem::onUpdateDirectoryRequest()
@@ -668,3 +709,42 @@ void FileItem::clearChildren()
     m_watcher.reset();
     m_watcher = nullptr;
 }
+
+/* Func: if it isn't a vaild volume device,it should not be displayed.
+ */
+bool FileItem::shouldShow()
+{
+    QString uri,unixDevice,displayName;
+
+    uri = m_info->uri();
+    if(uri.isEmpty())
+        return false;
+    if("computer:///root.link" == uri)
+        return true;
+
+    //non computer path, no need check
+    //to fix sftp IO stuck issue
+    if (! uri.startsWith("computer:///") || ! uri.endsWith(".drive"))
+        return true;
+
+    displayName = FileUtils::getFileDisplayName(uri);
+    if(displayName.isEmpty())
+        return false;
+
+    if (displayName.contains(":"))
+        return true;
+
+    //if needed, comment to not use this IO stuck API
+    unixDevice = FileUtils::getUnixDevice(uri);
+    if(!unixDevice.isEmpty()){
+        return false;
+    }
+    return true;
+}
+
+QString FileItem::uri2FavoriteUri(const QString &sourceUri)
+{
+    QUrl url = sourceUri;
+    QString favoriteUri = "favorite://" + url.path() + "?schema=" + url.scheme();
+    return favoriteUri;
+}
