@@ -29,9 +29,12 @@
 #include "peony-core_global.h"
 #include <gio/gio.h>
 
+#include <memory>
+
 namespace Peony {
 
 class SideBarModel;
+class FileInfo;
 
 class PEONYCORESHARED_EXPORT SideBarAbstractItem : public QObject
 {
@@ -43,7 +46,9 @@ public:
         FavoriteItem,
         PersonalItem,
         FileSystemItem,
-        SeparatorItem
+        SeparatorItem,
+        VFSItem,
+        SingleItem
     };
 
     explicit SideBarAbstractItem(SideBarModel* model, QObject *parent = nullptr);
@@ -71,8 +76,10 @@ public:
 protected:
     QVector<SideBarAbstractItem*> *m_children = nullptr;
     SideBarModel *m_model = nullptr;
+    std::shared_ptr<FileInfo> m_info;
 
 Q_SIGNALS:
+    void queryInfoFinished();
     void findChildrenFinished();
     void updated();
 
