@@ -32,6 +32,12 @@
 #include "bookmark-manager.h"
 #include "file-operation-utils.h"
 
+#include "vfs-plugin-manager.h"
+#include "side-bar-vfs-item.h"
+
+#include "side-bar-single-item.h"
+#include "file-utils.h"
+
 #include <QIcon>
 #include <QMimeData>
 #include <QUrl>
@@ -47,6 +53,17 @@ SideBarModel::SideBarModel(QObject *parent)
 
     m_root_children = new QVector<SideBarAbstractItem*>();
 
+    auto vfsMgr = VFSPluginManager::getInstance();
+    auto plugins = vfsMgr->registeredPlugins();
+    for (auto plugin : plugins) {
+        if (plugin->uriScheme().contains("kydroid://") || plugin->uriScheme().contains("kmre://")) {
+            continue;
+        }
+        if (plugin->holdInSideBar()) {
+            m_root_children->append(new SideBarVFSItem(plugin, this));
+        }
+    }
+
 //    SideBarSeparatorItem *separator1 = new SideBarSeparatorItem(SideBarSeparatorItem::Large, nullptr, this, this);
 //    m_root_children->append(separator1);
 
@@ -57,6 +74,11 @@ SideBarModel::SideBarModel(QObject *parent)
 //    SideBarSeparatorItem *separator2 = new SideBarSeparatorItem(SideBarSeparatorItem::Small, nullptr, this, this);
 //    m_root_children->append(separator2);
 
+//    if (FileUtils::isFileExsit("file:///data/usershare")) {
+//        SideBarSingleItem *userShareItem = new SideBarSingleItem("file:///data/usershare", nullptr, tr("Shared Data"), this);
+//        m_root_children->append(userShareItem);
+//    }
+
     SideBarPersonalItem *personal_root_item = new SideBarPersonalItem(nullptr, nullptr, this);
     m_root_children->append(personal_root_item);
     //personal_root_item->findChildren();
@@ -70,6 +92,9 @@ SideBarModel::SideBarModel(QObject *parent)
     m_root_children->append(computerItem);
     //computerItem->findChildren();
 
+    SideBarSingleItem *networkItem = new SideBarSingleItem("network:///", "network-workgroup-symbolic", tr("Network"), this);
+    m_root_children->append(networkItem);
+
     endResetModel();
 
     //empty-file separator
@@ -85,7 +110,7 @@ SideBarModel::~SideBarModel()
     delete m_root_children;
 }
 
-QModelIndex SideBarModel::firstCloumnIndex(SideBarAbstractItem *item)
+QModelIndex SideBarModel::firstColumnIndex(SideBarAbstractItem *item)
 {
     if (item->parent() != nullptr) {
         return createIndex(item->parent()->m_children->indexOf(item), 0, item);
@@ -94,7 +119,7 @@ QModelIndex SideBarModel::firstCloumnIndex(SideBarAbstractItem *item)
     }
 }
 
-QModelIndex SideBarModel::lastCloumnIndex(SideBarAbstractItem *item)
+QModelIndex SideBarModel::lastColumnIndex(SideBarAbstractItem *item)
 {
     if (item->parent() != nullptr) {
         createIndex(item->parent()->m_children->indexOf(item), 1, item);
@@ -192,20 +217,34 @@ QVariant SideBarModel::data(const QModelIndex &index, int role) const
         return QVariant();
 
     SideBarAbstractItem *item = static_cast<SideBarAbstractItem*>(index.internalPointer());
-    if (index.column() == 1) {
-        if (role == Qt::DecorationRole && item->isRemoveable())
-            if (item->isMounted())
-                return QVariant(QIcon::fromTheme("media-eject"));
-            else//if volume has been unmounted,doesn't show icon.
-                return QVariant();
-        else {
+
+    if (index.column() == 0 && !index.parent().isValid()) {
+        if(role == Qt::DecorationRole) {
             return QVariant();
         }
     }
 
+    if (index.column() == 1) {
+        if(role == Qt::DecorationRole){
+            bool unmountAble,ejectAble;
+            unmountAble = item->isMountable();
+            ejectAble = item->isEjectable();
+            if(unmountAble && ejectAble)
+                return QVariant(QIcon::fromTheme("media-eject-symbolic"));
+            else if(unmountAble){
+                if(item->isMounted())
+                    return QVariant(QIcon::fromTheme("media-eject-symbolic"));
+                else
+                    return QVariant();
+            }else
+                return QVariant();
+        }else
+            return QVariant();
+    }
+
     switch (role) {
     case Qt::DecorationRole:
-        return QIcon::fromTheme("ukui-" + item->iconName(), QIcon::fromTheme(item->iconName()));
+        return QIcon::fromTheme(item->iconName() + "-symbolic", QIcon::fromTheme(item->iconName()));
     case Qt::DisplayRole:
         return item->displayName();
     case Qt::ToolTipRole:
@@ -289,8 +328,28 @@ void SideBarModel::onIndexUpdated(const QModelIndex &index)
 
 bool SideBarModel::dropMimeData(const QMimeData *data, Qt::DropAction action, int row, int column, const QModelIndex &parent)
 {
-    if (data->urls().isEmpty())
+    auto urls = data->urls();
+
+    QStringList srcUris;
+    if (data->hasFormat("peony-qt/encoded-uris")) {
+        srcUris = data->text().split(" ");
+        for (QString uri : srcUris) {
+            if (uri.startsWith("recent://"))
+                srcUris.removeOne(uri);
+        }
+    } else {
+        for (auto url : urls) {
+            //can not drag file from recent
+            if (url.url().startsWith("recent://"))
+                return false;
+            srcUris<<url.url();
+        }
+    }
+    srcUris.removeDuplicates();
+
+    if (srcUris.isEmpty()) {
         return false;
+    }
 
     auto item = this->itemFromIndex(parent);
     qDebug()<<"SideBarModel::dropMimeData:" <<action<<row<<column<<parent.data();
@@ -298,14 +357,15 @@ bool SideBarModel::dropMimeData(const QMimeData *data, Qt::DropAction action, in
 
         auto bookmark = BookMarkManager::getInstance();
         if (bookmark->isLoaded()) {
-            for (auto url : data->urls()) {
-                auto info = FileInfo::fromUri(url.toDisplayString(), false);
+            for (auto url : srcUris) {
+                //FIXME: replace BLOCKING api in ui thread.
+                auto info = FileInfo::fromUri(url);
                 if (info->displayName().isNull()) {
                     FileInfoJob j(info);
                     j.querySync();
                 }
                 if (info->isDir()) {
-                    bookmark->addBookMark(url.url());
+                    bookmark->addBookMark(url);
                 }
             }
         }
@@ -334,17 +394,30 @@ bool SideBarModel::dropMimeData(const QMimeData *data, Qt::DropAction action, in
 //    }
     case SideBarAbstractItem::PersonalItem:
     case SideBarAbstractItem::FileSystemItem: {
-        QStringList uris;
-        for (auto url : data->urls()) {
-            uris<<url.url();
-        }
+        QStringList uris = srcUris;
+
+        //can not drag file to recent
+        if (item->uri().startsWith("recent://"))
+            return false;
 
         for(auto uri : uris)
         {
             if (uri.startsWith("trash://"))
                 return false;
+            //can not drag file from recent
+            if (uri.startsWith("recent://"))
+                return false;
+        }
+        if (action == Qt::MoveAction)
+        {
+            FileOperationUtils::move(uris, item->uri(), true, true);
+            //qDebug() << "sideBarModel moveOp";
+        }
+        else if (action == Qt::CopyAction)
+        {
+            FileOperationUtils::copy(uris, item->uri(), true);
+            //qDebug() << "sideBarModel CopyOp";
         }
-        FileOperationUtils::move(uris, item->uri(), true, true);
         break;
     }
     }
@@ -353,5 +426,11 @@ bool SideBarModel::dropMimeData(const QMimeData *data, Qt::DropAction action, in
 
 Qt::DropActions SideBarModel::supportedDropActions() const
 {
+    return Qt::MoveAction|Qt::CopyAction;
     return Qt::MoveAction|Qt::CopyAction|Qt::LinkAction;
 }
+
+Qt::DropActions SideBarModel::supportedDragActions() const
+{
+    return Qt::MoveAction;
+}
