@@ -20,13 +20,21 @@
  *
  */
 
+#include "file-utils.h"
 #include "format_dialog.h"
+#include "side-bar-menu.h"
+#include "volume-manager.h"
 #include "ui_format_dialog.h"
+#include "side-bar-abstract-item.h"
+#include "linux-pwd-helper.h"
 
-#include <QMessageBox>
 #include <QObject>
+#include <QMessageBox>
+#include <KWindowSystem>
 
 using namespace  Peony;
+static bool b_finished = false;
+static bool b_failed = false;
 
 Format_Dialog::Format_Dialog(const QString &m_uris,SideBarAbstractItem *m_item,QWidget *parent) :
     QDialog(parent),
@@ -41,20 +49,50 @@ Format_Dialog::Format_Dialog(const QString &m_uris,SideBarAbstractItem *m_item,Q
        //from uris get the rom size
        //FIXME: replace BLOCKING api in ui thread.
        auto targetUri = FileUtils::getTargetUri(fm_uris);
+       if (targetUri.isEmpty()) {
+           targetUri = fm_uris;
+       }
        GFile *fm_file = g_file_new_for_uri(targetUri .toUtf8().constData());
 
        GFileInfo *fm_info = g_file_query_filesystem_info(fm_file, "*", nullptr, nullptr);
        quint64 total = g_file_info_get_attribute_uint64(fm_info, G_FILE_ATTRIBUTE_FILESYSTEM_SIZE);
 
-       //get the rom size
-       char *total_format = g_format_size(total);
-
        //add the rom size value into  rom_size combox
-       ui->comboBox_rom_size->addItem(total_format);
+       //fix system Udisk calculate size wrong issue
+       QString m_volume_name, m_unix_device, m_display_name;
+       FileUtils::queryVolumeInfo(m_uris, m_volume_name, m_unix_device, m_display_name);
+       bool hasSetRomSize = false;
+       //U disk or other mobile device
+       if (! m_unix_device.isEmpty() && ! m_uris.startsWith("computer:///WDC"))
+       {
+          char dev_name[256] ={0};
+          strncpy(dev_name, m_unix_device.toUtf8().constData(),sizeof(m_unix_device.toUtf8().constData()-1));
+          auto size = FileUtils::getDeviceSize(dev_name);
+          if (size > 0)
+          {
+              QString sizeInfo = QString::number(size, 'f', 1);
+              qDebug() << "size:" <<size;
+              sizeInfo += "G";
+              ui->label_rom_size_text->setText(sizeInfo);
+              hasSetRomSize = true;
+          }
+       }
 
+       if (! hasSetRomSize)
+       {
+           //Calculated by 1024 bytes
+           char *total_format = strtok(g_format_size_full(total,G_FORMAT_SIZE_IEC_UNITS),"iB");
+           ui->label_rom_size_text->setText(total_format);
+       }
 
        auto mount = VolumeManager::getMountFromUri(targetUri);
-       ui->lineEdit_device_name->setText(mount->name());
+       //fix name not show complete in bottom issue, bug#36887
+       ui->lineEdit_device_name->setFixedHeight(40);
+       if (mount.get()) {
+            ui->lineEdit_device_name->setText(mount->name());
+       } else {
+            ui->lineEdit_device_name->setText(LinuxPWDHelper::getCurrentUser().fullName());
+       }
 
        ui->progressBar_process->setValue(0);
 
@@ -89,12 +127,17 @@ static void unmount_finished(GFile* file, GAsyncResult* result, gpointer udata)
 
     if (g_file_unmount_mountable_with_operation_finish (file, result, &err) == TRUE){
         flags = 1;
+        char *uri = g_file_get_uri(file);
+        VolumeManager::getInstance()->fileUnmounted(uri);
+        if (uri)
+            g_free(uri);
     }
 
     //add QMessageBox error ,let user know the error messages
     
     if (err) {
         flags = 0;
+        b_failed = true;
         
         QMessageBox message_error;
           
@@ -122,26 +165,31 @@ static void unmount_finished(GFile* file, GAsyncResult* result, gpointer udata)
 
 void Format_Dialog::acceptFormat(bool)
 {
+    ui->pushButton_ok->setDisabled(true);
+    ui->pushButton_close->setDisabled(true);
+
     //check format or not 
-   if(!format_makesure_dialog()){
+    if(!format_makesure_dialog()){
         return;
-   };
+    };
+
+    //keep this window above, fix bug #41227
+    KWindowSystem::setState(this->winId(), KWindowSystem::KeepAbove);
 
     //init the value
     char rom_size[1024] ={0},rom_type[1024]={0},rom_name[1024]={0},dev_name[1024]={0};
-    int quick_clean = 0;
-
+    int full_clean = 0;
 
     //get values from ui
-    strncpy(rom_size,ui->comboBox_rom_size->itemText(0).toUtf8().constData(),sizeof(ui->comboBox_rom_size->itemText(0).toUtf8().constData())-1);
+    //strncpy(rom_size,ui->comboBox_rom_size->itemText(0).toUtf8().constData(),sizeof(ui->comboBox_rom_size->itemText(0).toUtf8().constData())-1);
     strncpy(rom_type,ui->comboBox_system->currentText().toUtf8().constData(),sizeof(ui->comboBox_system->currentText().toUtf8().constData())-1);
     strcpy(rom_name,ui->lineEdit_device_name->text().toUtf8().constData());
 
     //disable name and rom size list
-    ui->comboBox_rom_size->setDisabled(true);
+    //ui->comboBox_rom_size->setDisabled(true);
     ui->comboBox_system->setDisabled(true);
 
-    quick_clean = ui->checkBox_clean_or_not->isChecked();
+    full_clean = ui->checkBox_clean_or_not->isChecked();
 
     // umount device
     //fm_item ->unmount();
@@ -171,44 +219,44 @@ void Format_Dialog::acceptFormat(bool)
     //int format_value = 0;
 
     //begin format
-    //kdisk_format(dev_name,devtype.toLower().toUtf8().constData(),quick_clean?"zero":NULL,rom_name,&format_value);
+    //kdisk_format(dev_name,devtype.toLower().toUtf8().constData(),full_clean?"zero":NULL,rom_name,&format_value);
 
     //begin start my_timer, processbar
     my_time  = new QTimer(this);
 
     m_cost_seconds = 0;
-    if(quick_clean){
-        my_time->setInterval(500);
-        m_total_predict = 1200;
-    }else{
+    m_simulate_progress = 0;
+    b_finished = false;
+    b_failed = false;
+    if(full_clean){
         my_time->setInterval(1000);
-        m_total_predict = 3600;
+        m_total_predict = 1800;
+    }else{
+        my_time->setInterval(500);
+        m_total_predict = 150;
     }
 
     //begin loop
-    connect(my_time,SIGNAL(timeout()),this,SLOT(formatloop()));
-
-   // my_time->start();
+    connect(my_time, SIGNAL(timeout()), this, SLOT(formatloop()));
 
     //while get ensure emit , do format 
-      connect(this,&Format_Dialog::ensure_format,[=](bool){
-
-        int format_value = 0;
-        //do format 
-        kdisk_format(dev_name,devtype.toLower().toUtf8().constData(),quick_clean?"zero":NULL,rom_name,&format_value);
-        
+    connect(this,&Format_Dialog::ensure_format,[=](bool){
         // time begin loop
         my_time->start();
 
         // set ui button disable
         ui->pushButton_ok->setDisabled(TRUE);
         ui->pushButton_close->setDisabled(TRUE);
-        ui->lineEdit_device_name->setDisabled(TRUE);
+        //ui->lineEdit_device_name->setDisabled(TRUE);
+        //use set readonly property, fix exit issue link to task#33686
+        ui->lineEdit_device_name->setReadOnly(true);
         ui->checkBox_clean_or_not->setDisabled(TRUE);
+
+        int format_value = 0;
+        //do format
+        kdisk_format(dev_name, devtype.toLower().toUtf8().constData(),
+                     full_clean?"zero":NULL, rom_name,&format_value);
     });
-
-
-
 }
 
 double Format_Dialog::get_format_bytes_done(const gchar * device_name)
@@ -240,9 +288,21 @@ double Format_Dialog::get_format_bytes_done(const gchar * device_name)
     return 0;
 }
 
-
 void Format_Dialog::formatloop(){
 
+    if (b_finished)
+    {
+        ui->progressBar_process->setValue(100);
+        ui->label_process->setText("100%");
+        my_time->stop();
+        return;
+    }
+    else if (b_failed)
+    {
+        my_time->stop();
+        return;
+    }
+
     QString volname, devName, voldisplayname;
     static char name_dev[256] ={0};
     char prestr[10] = {0};
@@ -258,29 +318,35 @@ void Format_Dialog::formatloop(){
 
     double pre = (get_format_bytes_done(name_dev) * 100);
     double cost = m_cost_seconds * 100/m_total_predict;
+    if (cost > 100)
+        cost = 100;
 
-    if ((pre < 1 && cost <= 99) || pre < cost)
-        pre = cost;
-
-    sprintf(prestr,"%.1f",pre);
-    strcat(prestr,"%");
-
-    if(pre>=100){
-
-        ui->progressBar_process->setValue(100);
-
-        ui->label_process->setText("100%");
-
-        my_time->stop();
-
-    }else{
-
-          ui->progressBar_process->setValue(pre);
-          ui->label_process->setText(prestr);
+    if (m_simulate_progress >= pre){
+        //fix waiting in 100% issue
+        if (m_simulate_progress < 99)
+           m_simulate_progress += (cost - pre)/100;
+    }
+    else{
+        m_simulate_progress = pre;
     }
 
-}
+    qDebug() << "formatloop predict and cost:" <<pre <<cost
+             <<m_simulate_progress <<m_cost_seconds <<b_finished;
 
+    sprintf(prestr,"%.1f",m_simulate_progress);
+    strcat(prestr,"%");
+
+    if(m_simulate_progress>=100){
+        b_finished = true;
+        ui->progressBar_process->setValue(100);
+        ui->label_process->setText("100%");
+        my_time->stop();
+    }
+    else{
+          ui->progressBar_process->setValue(m_simulate_progress);
+          ui->label_process->setText(prestr);
+    }
+}
 
 void Format_Dialog::cancel_format(const gchar* device_name){
 
@@ -397,7 +463,7 @@ static void format_cb (GObject *source_object, GAsyncResult *res ,gpointer user_
     if (!udisks_block_call_format_finish (UDISKS_BLOCK (source_object), res,&error))
     {
         char *p = NULL;
-        if(NULL!=error&&NULL!=(p=strstr(error->message, "wipefs:"))){
+        if(NULL != error && NULL != (p=strstr(error->message, "wipefs:"))){
             notify_init("Peony");
             NotifyNotification *notify;
             QString title = QObject::tr("File Manager");
@@ -411,23 +477,22 @@ static void format_cb (GObject *source_object, GAsyncResult *res ,gpointer user_
             g_clear_error(&error);
         }
         end_flag = -1;
-        *(data->format_finish) =  -1; //format success
-
+        *(data->format_finish) =  -1; //format error
     }
     else
+    {
         end_flag = 1;
-        *(data->format_finish) =  1; //format error
-
+        *(data->format_finish) =  1; //format success
+    }
 
     if(end_flag == 1){
-
+        b_finished = true;
         data->dl->ui->progressBar_process->setValue(100);
         data->dl->ui->label_process->setText("100%");
-
         data->dl->format_ok_dialog();
-
-    }else{
-
+    }
+    else{
+        b_failed = true;
         data->dl->format_err_dialog();  
     }
 
@@ -435,37 +500,38 @@ static void format_cb (GObject *source_object, GAsyncResult *res ,gpointer user_
     data->dl->close();
 
     createformatfree(data);
-
 };
 
 
 void Format_Dialog::format_ok_dialog()
 {
-    QMessageBox::about(m_parent,tr("qmesg_notify"),tr("Format operation has been finished successfully."));
-};
+    QMessageBox::about(m_parent,QObject::tr("qmesg_notify"),QObject::tr("Format operation has been finished successfully."));
+}
 
 
 void Format_Dialog::format_err_dialog()
 {
-      QMessageBox::warning(m_parent,tr("qmesg_notify"),tr("Sorry, the format operation is failed!"));
-};
+      QMessageBox::warning(m_parent,QObject::tr("qmesg_notify"),QObject::tr("Sorry, the format operation is failed!"));
+}
 
 bool Format_Dialog::format_makesure_dialog(){
 
     QMessageBox message_format;
 
-    message_format.setText(tr("Formatting this volume will erase all data on it. Please backup all retained data before formatting. Do you want to continue ?"));
+    message_format.setText(QObject::tr("Formatting this volume will erase all data on it. Please backup all retained data before formatting. Do you want to continue ?"));
 
-    message_format.setWindowTitle(tr("format"));
+    message_format.setWindowTitle(QObject::tr("format"));
 
-    QPushButton *okButton = message_format.addButton(tr("begin format"),QMessageBox::YesRole);
+    QPushButton *okButton = message_format.addButton(QObject::tr("begin format"),QMessageBox::YesRole);
 
-    QPushButton *cancelButton = message_format.addButton(tr("close"),QMessageBox::NoRole);
+    QPushButton *cancelButton = message_format.addButton(QObject::tr("close"),QMessageBox::NoRole);
 
     message_format.exec();
 
     if(message_format.clickedButton() == cancelButton)
     {
+        ui->pushButton_ok->setDisabled(false);
+        ui->pushButton_close->setDisabled(false);
         return false;
     }
 
@@ -499,7 +565,6 @@ void Format_Dialog::ensure_format_cb (CreateformatData *data){
                                g_variant_new_boolean (TRUE));
     }
 
-
     if (data->erase_type != NULL){
         g_variant_builder_add (&options_builder, "{sv}", "erase",
                                g_variant_new_string (data->erase_type));
@@ -570,10 +635,6 @@ void Format_Dialog::ensure_format_disk(CreateformatData *data){
 
 }
 
-
-
-
-
 UDisksObject *Format_Dialog::get_object_from_block_device (UDisksClient *client,const gchar *block_device)
 {
     struct stat statbuf;
