@@ -32,6 +32,8 @@
 
 #include <QLocale>
 #include <QCollator>
+#include <QStandardPaths>
+#include <QUrl>
 
 using namespace Peony;
 
@@ -56,8 +58,8 @@ DesktopItemProxyModel::DesktopItemProxyModel(QObject *parent) : QSortFilterProxy
     setSortCaseSensitivity(Qt::CaseInsensitive);
     setDynamicSortFilter(false);
     auto settings = GlobalSettings::getInstance();
-    m_show_hidden = settings->isExist("show-hidden")? settings->getValue("show-hidden").toBool(): false;
-    //qDebug() <<"DesktopItemProxyModel:" <<settings->isExist("show-hidden")<<m_show_hidden;
+    m_show_hidden = settings->isExist(SHOW_HIDDEN_PREFERENCE)? settings->getValue(SHOW_HIDDEN_PREFERENCE).toBool(): false;
+    //qDebug() <<"DesktopItemProxyModel:" <<settings->isExist(SHOW_HIDDEN_PREFERENCE)<<m_show_hidden;
 
     m_bwListInfo = new BWListInfo();
     m_jsonOp = new PeonyJsonOperation();
@@ -88,6 +90,14 @@ bool DesktopItemProxyModel::filterAcceptsRow(int source_row, const QModelIndex &
         return false;
     }
 
+    //fix desktop show Desktop folder issue, bug#20293
+    if (QUrl(uri).path() == QStandardPaths::writableLocation(QStandardPaths::DesktopLocation) + "/Desktop"
+        || QUrl(uri).path() == QStandardPaths::writableLocation(QStandardPaths::HomeLocation) + "/Desktop" + "/Desktop")
+    {
+        if (! QFile::exists(QUrl(uri).path()))
+           return false;
+    }
+
     if (info->isDesktopFile() && nullptr != info->desktopName()){
         if (m_bwListInfo->isBlackListMode()){
             return !m_bwListInfo->desktopNameExist(info->desktopName());
@@ -178,7 +188,7 @@ bool DesktopItemProxyModel::lessThan(const QModelIndex &source_left, const QMode
 
 void DesktopItemProxyModel::setShowHidden(bool showHidden)
 {
-    GlobalSettings::getInstance()->setValue("show-hidden", showHidden);
+    GlobalSettings::getInstance()->setValue(SHOW_HIDDEN_PREFERENCE, showHidden);
     m_show_hidden = showHidden;
     invalidateFilter();
 }
