@@ -44,6 +44,7 @@
 #include <QProcess>
 #include <QStandardPaths>
 #include <QMessageBox>
+#include <QtConcurrent>
 
 #include <QUrl>
 #include <QDir>
@@ -53,8 +54,9 @@ using namespace Peony;
 
 DesktopMenu::DesktopMenu(DirectoryViewIface *view, QWidget *parent) : QMenu(parent)
 {
-    setProperty("useIconHighlightEffect", true);
-    setProperty("iconHighlightEffectMode", 1);
+    //comment old highlight effect
+//    setProperty("useIconHighlightEffect", true);
+//    setProperty("iconHighlightEffectMode", 1);
     setProperty("fillIconSymbolicColor", true);
 
     m_view = view;
@@ -104,12 +106,12 @@ const QList<QAction *> DesktopMenu::constructOpenOpActions()
 
     bool isBackgroundMenu = m_selections.isEmpty();
     if (isBackgroundMenu) {
-        l<<addAction(QIcon::fromTheme("window-new-symbolic"), tr("&Open in new Window"));
+        l<<addAction(QIcon::fromTheme("window-new-symbolic"), tr("Open in new Window"));
         connect(l.last(), &QAction::triggered, [=]() {
             this->openWindow(m_directory);
         });
 
-        l<<addAction(tr("Select &All"));
+        l<<addAction(tr("Select All"));
         connect(l.last(), &QAction::triggered, [=]() {
             //qDebug() << "select all";
             m_view->invertSelections();
@@ -132,39 +134,50 @@ const QList<QAction *> DesktopMenu::constructOpenOpActions()
                 displayName = fontMetrics().elidedText(displayName, Qt::ElideRight, ELIDE_TEXT_LENGTH * charWidth);
             }
             if (info->isDir()) {
-                l<<addAction(QIcon::fromTheme("document-open-symbolic"), tr("&Open \"%1\"").arg(displayName));
+                l<<addAction(QIcon::fromTheme("document-open-symbolic"), tr("Open"));
                 connect(l.last(), &QAction::triggered, [=]() {
                     this->openWindow(m_selections);
                 });
 
-                auto openWithAction = addAction(tr("Open \"%1\" &with...").arg(displayName));
-                QMenu *openWithMenu = new QMenu(this);
                 auto recommendActions = FileLaunchManager::getRecommendActions(m_selections.first());
-                for (auto action : recommendActions) {
-                    action->setParent(openWithMenu);
-                    openWithMenu->addAction(static_cast<QAction*>(action));
+                if (recommendActions.count() > 1)
+                {
+                    auto openWithAction = addAction(tr("Open with..."));
+                    QMenu *openWithMenu = new QMenu(this);
+
+                    for (auto action : recommendActions) {
+                        action->setParent(openWithMenu);
+                        openWithMenu->addAction(static_cast<QAction*>(action));
+                    }
+                    auto fallbackActions = FileLaunchManager::getFallbackActions(m_selections.first());
+                    for (auto action : fallbackActions) {
+                        action->setParent(openWithMenu);
+                        openWithMenu->addAction(static_cast<QAction*>(action));
+                    }
+                    openWithMenu->addSeparator();
+                    openWithMenu->addAction(tr("More applications..."), [=]() {
+                        FileLauchDialog d(m_selections.first());
+                        d.exec();
+                    });
+                    openWithAction->setMenu(openWithMenu);
                 }
-                auto fallbackActions = FileLaunchManager::getFallbackActions(m_selections.first());
-                for (auto action : fallbackActions) {
-                    action->setParent(openWithMenu);
-                    openWithMenu->addAction(static_cast<QAction*>(action));
-                }
-                openWithMenu->addSeparator();
-                openWithMenu->addAction(tr("&More applications..."), [=]() {
-                    FileLauchDialog d(m_selections.first());
-                    d.exec();
-                });
-                openWithAction->setMenu(openWithMenu);
             } else if (!info->isVolume()) {
-                l<<addAction(QIcon::fromTheme("document-open-symbolic"), tr("&Open \"%1\"").arg(displayName));
+                l<<addAction(QIcon::fromTheme("document-open-symbolic"), tr("Open"));
                 connect(l.last(), &QAction::triggered, [=]() {
                     auto uri = m_selections.first();
                     FileLaunchManager::openAsync(uri);
                 });
-                auto openWithAction = addAction(tr("Open \"%1\" with...").arg(displayName));
+                auto openWithAction = addAction(tr("Open with..."));
                 //FIXME: add sub menu for open with action.
                 QMenu *openWithMenu = new QMenu(this);
                 auto recommendActions = FileLaunchManager::getRecommendActions(m_selections.first());
+                //fix has default open app but no recommend actions issue, link to bug#61365
+                if (recommendActions.count() == 0)
+                {
+                    auto action = FileLaunchManager::getDefaultAction(m_selections.first());
+                    if (action != NULL && action->getAppInfoDisplayName().length() > 0)
+                        recommendActions.append(action);
+                }
                 for (auto action : recommendActions) {
                     action->setParent(openWithMenu);
                     openWithMenu->addAction(static_cast<QAction*>(action));
@@ -175,13 +188,13 @@ const QList<QAction *> DesktopMenu::constructOpenOpActions()
                     openWithMenu->addAction(static_cast<QAction*>(action));
                 }
                 openWithMenu->addSeparator();
-                openWithMenu->addAction(tr("&More applications..."), [=]() {
+                openWithMenu->addAction(tr("More applications..."), [=]() {
                     FileLauchDialog d(m_selections.first());
                     d.exec();
                 });
                 openWithAction->setMenu(openWithMenu);
             } else {
-                l<<addAction(tr("&Open"));
+                l<<addAction(tr("Open"));
                 connect(l.last(), &QAction::triggered, [=]() {
                     auto uri = m_selections.first();
                     //FIXME:
@@ -192,10 +205,10 @@ const QList<QAction *> DesktopMenu::constructOpenOpActions()
             {
                 auto info = FileInfo::fromUri(m_selections.first());
                 auto displayName = info->displayName();
-                l<<addAction(QIcon::fromTheme("document-open-symbolic"), tr("&Open \"%1\"").arg(displayName));
+                l<<addAction(QIcon::fromTheme("document-open-symbolic"), tr("Open"));
             }
             else
-                l<<addAction(QIcon::fromTheme("document-open-symbolic"), tr("&Open %1 selected files").arg(m_selections.count()));
+                l<<addAction(QIcon::fromTheme("document-open-symbolic"), tr("Open %1 selected files").arg(m_selections.count()));
 
             connect(l.last(), &QAction::triggered, [=]() {
                 qDebug()<<"triggered:"<<m_selections.count();
@@ -240,57 +253,67 @@ const QList<QAction *> DesktopMenu::constructCreateTemplateActions()
         addAction(createAction);
 
         //enumerate template dir
-        QDir templateDir(g_get_user_special_dir(G_USER_DIRECTORY_TEMPLATES));
-        auto templates = templateDir.entryList(QDir::AllEntries|QDir::NoDotAndDotDot);
-        if (!templates.isEmpty()) {
-            for (auto t : templates) {
-                QFileInfo qinfo(templateDir, t);
-                GFile *gtk_file = g_file_new_for_path(qinfo.filePath().toUtf8().data());
-                char *uri_str = g_file_get_uri(gtk_file);
-                std::shared_ptr<FileInfo> info = FileInfo::fromUri(uri_str);
+//        QDir templateDir(g_get_user_special_dir(G_USER_DIRECTORY_TEMPLATES));
+        QString templatePath = GlobalSettings::getInstance()->getValue(TEMPLATES_DIR).toString();
+        if(!templatePath.isEmpty())
+        {
+            QDir templateDir(templatePath);
+            auto templates = templateDir.entryList(QDir::AllEntries|QDir::NoDotAndDotDot);
+            if (!templates.isEmpty()) {
+                for (auto t : templates) {
+                    QFileInfo qinfo(templateDir, t);
+                    GFile *gtk_file = g_file_new_for_path(qinfo.filePath().toUtf8().data());
+                    char *uri_str = g_file_get_uri(gtk_file);
+                    //FIXME: replace BLOCKING api in ui thread.
+                    std::shared_ptr<FileInfo> info = FileInfo::fromUri(uri_str);
 
-                QString mimeType = info->mimeType();
-                if (mimeType.isEmpty()) {
-                    FileInfoJob job(info);
-                    job.querySync();
-                    mimeType = info->mimeType();
-                }
-
-                QIcon tmpIcon;
-                GList *app_infos = g_app_info_get_recommended_for_type(mimeType.toUtf8().constData());
-                GList *l = app_infos;
-                QList<FileLaunchAction *> actions;
-                bool isOnlyUnref = false;
-                while (l) {
-                    auto app_info = static_cast<GAppInfo*>(l->data);
-                    if (!isOnlyUnref) {
-                        GThemedIcon *icon = G_THEMED_ICON(g_app_info_get_icon(app_info));
-                        const char * const * icon_names = g_themed_icon_get_names(icon);
-                        if (icon_names)
-                            tmpIcon = QIcon::fromTheme(*icon_names);
-                        if(!tmpIcon.isNull())
-                            isOnlyUnref = true;
+                    QString mimeType = info->mimeType();
+                    if (mimeType.isEmpty()) {
+                        FileInfoJob job(info);
+                        job.querySync();
+                        mimeType = info->mimeType();
                     }
-                    g_object_unref(app_infos);
-                    l = l->next;
-                }
 
-                QAction *action = new QAction(tmpIcon, qinfo.baseName(), this);
-                connect(action, &QAction::triggered, [=]() {
-                    CreateTemplateOperation op(m_directory, CreateTemplateOperation::Template, t);
-                    op.run();
-                    auto target = op.target();
-                    m_uris_to_edit<<target;
-                });
-                subMenu->addAction(action);
-                g_free(uri_str);
-                g_object_unref(gtk_file);
+                    QIcon tmpIcon;
+                    GList *app_infos = g_app_info_get_recommended_for_type(mimeType.toUtf8().constData());
+                    GList *l = app_infos;
+                    QList<FileLaunchAction *> actions;
+                    bool isOnlyUnref = false;
+                    while (l) {
+                        auto app_info = static_cast<GAppInfo*>(l->data);
+                        if (!isOnlyUnref) {
+                            GThemedIcon *icon = G_THEMED_ICON(g_app_info_get_icon(app_info));
+                            const char * const * icon_names = g_themed_icon_get_names(icon);
+                            if (icon_names)
+                                tmpIcon = QIcon::fromTheme(*icon_names);
+                            if(!tmpIcon.isNull())
+                                isOnlyUnref = true;
+                        }
+                        l = l->next;
+                    }
+                    g_list_free_full(app_infos, g_object_unref);
+
+                    QAction *action = new QAction(tmpIcon, qinfo.baseName(), this);
+                    connect(action, &QAction::triggered, [=]() {
+                        CreateTemplateOperation op(m_directory, CreateTemplateOperation::Template, t);
+                        op.run();
+                        auto target = op.target();
+                        m_uris_to_edit<<target;
+                    });
+                    subMenu->addAction(action);
+                    g_free(uri_str);
+                    g_object_unref(gtk_file);
+                }
+                subMenu->addSeparator();
+            } else {
+                qWarning()<<"the template dir is empty";
             }
-            subMenu->addSeparator();
+        } else {
+            qWarning()<<"the template dir is not exsit";
         }
 
         QList<QAction *> actions;
-        auto createEmptyFileAction = new QAction(QIcon::fromTheme("document-new-symbolic"), tr("Empty &File"), this);
+        auto createEmptyFileAction = new QAction(QIcon::fromTheme("document-new-symbolic"), tr("Empty File"), this);
         actions<<createEmptyFileAction;
         connect(actions.last(), &QAction::triggered, [=]() {
             //FileOperationUtils::create(m_directory);
@@ -300,7 +323,7 @@ const QList<QAction *> DesktopMenu::constructCreateTemplateActions()
             qDebug()<<"target:"<<targetUri;
             m_uris_to_edit<<targetUri;
         });
-        auto createFolderActions = new QAction(QIcon::fromTheme("folder-new-symbolic"), tr("&Folder"), this);
+        auto createFolderActions = new QAction(QIcon::fromTheme("folder-new-symbolic"), tr("Folder"), this);
         actions<<createFolderActions;
         connect(actions.last(), &QAction::triggered, [=]() {
             //FileOperationUtils::create(m_directory, nullptr, CreateTemplateOperation::EmptyFolder);
@@ -327,16 +350,24 @@ const QList<QAction *> DesktopMenu::constructViewOpActions()
         auto desktopView = dynamic_cast<DesktopIconView*>(m_view);
         auto zoomLevel = desktopView->zoomLevel();
 
-        auto smallAction = viewTypeSubMenu->addAction(tr("&Small"), [=]() {
+        auto smallAction = viewTypeSubMenu->addAction(tr("Small"), [=]() {
+            if (desktopView->zoomLevel() == DesktopIconView::Small)
+                return;
             desktopView->setDefaultZoomLevel(DesktopIconView::Small);
         });
-        auto normalAction = viewTypeSubMenu->addAction(tr("&Normal"), [=]() {
+        auto normalAction = viewTypeSubMenu->addAction(tr("Normal"), [=]() {
+            if (desktopView->zoomLevel() == DesktopIconView::Normal)
+                return;
             desktopView->setDefaultZoomLevel(DesktopIconView::Normal);
         });
-        auto largeAction = viewTypeSubMenu->addAction(tr("&Large"), [=]() {
+        auto largeAction = viewTypeSubMenu->addAction(tr("Large"), [=]() {
+            if (desktopView->zoomLevel() == DesktopIconView::Large)
+                return;
             desktopView->setDefaultZoomLevel(DesktopIconView::Large);
         });
-        auto hugeAction = viewTypeSubMenu->addAction(tr("&Huge"), [=]() {
+        auto hugeAction = viewTypeSubMenu->addAction(tr("Huge"), [=]() {
+            if (desktopView->zoomLevel() == DesktopIconView::Huge)
+                return;
             desktopView->setDefaultZoomLevel(DesktopIconView::Huge);
         });
 
@@ -444,7 +475,7 @@ const QList<QAction *> DesktopMenu::constructFileOpActions()
 //                FileOperationUtils::restore(trashChildren);
 //            });
 //            l.last()->setEnabled(!trashChildren.isEmpty());
-            l<<addAction(QIcon::fromTheme("edit-clear-symbolic"), tr("&Clean the trash"), [=]() {
+            l<<addAction(QIcon::fromTheme("edit-clear-symbolic"), tr("Clean the trash"), [=]() {
                 Peony::AudioPlayManager::getInstance()->playWarningAudio();
                 auto result = QMessageBox::question(nullptr, tr("Delete Permanently"), tr("Are you sure that you want to delete these files? "
                                                     "Once you start a deletion, the files deleting will never be "
@@ -458,26 +489,45 @@ const QList<QAction *> DesktopMenu::constructFileOpActions()
         } else if (m_selections.count() == 1 && m_selections.first() == "computer:///") {
 
         } else if (! m_selections.contains(homeUri)) {
-            l<<addAction(QIcon::fromTheme("edit-copy-symbolic"), tr("&Copy"));
+            l<<addAction(QIcon::fromTheme("edit-copy-symbolic"), tr("Copy"));
             connect(l.last(), &QAction::triggered, [=]() {
                 ClipboardUtils::setClipboardFiles(m_selections, false);
             });
             l<<addAction(QIcon::fromTheme("edit-cut-symbolic"), tr("Cut"));
             connect(l.last(), &QAction::triggered, [=]() {
                 ClipboardUtils::setClipboardFiles(m_selections, true);
+                auto desktopView = dynamic_cast<DesktopIconView*>(m_view);
+                desktopView->update();
             });
 
             if (!m_selections.contains("trash:///")) {
-                l<<addAction(QIcon::fromTheme("edit-delete-symbolic"), tr("&Delete to trash"));
-                connect(l.last(), &QAction::triggered, [=]() {
-                    FileOperationUtils::trash(m_selections, true);
-                });
-                //comment delete forever right menu option,reference to mac and Windows
-                //add delete forever option
-//                l<<addAction(QIcon::fromTheme("edit-clear-symbolic"), tr("Delete forever"));
-//                connect(l.last(), &QAction::triggered, [=]() {
-//                    FileOperationUtils::executeRemoveActionWithDialog(m_selections);
-//                });
+                bool canTrash = true;
+                bool canDelete = true;
+                for (auto uri : m_selections) {
+                    auto info = FileInfo::fromUri(uri);
+                    if (! info->canTrash())
+                        canTrash = false;
+
+                    if (! info->canDelete())
+                        canDelete = false;
+                }
+
+                if (canTrash)
+                {
+                    l<<addAction(QIcon::fromTheme("edit-delete-symbolic"), tr("Delete to trash"));
+                    connect(l.last(), &QAction::triggered, [=]() {
+                        FileOperationUtils::trash(m_selections, true);
+                    });
+                }
+                else if(canDelete)
+                {
+                    //comment delete forever right menu option,reference to mac and Windows
+                    //add delete forever option
+                    l<<addAction(QIcon::fromTheme("edit-clear-symbolic"), tr("Delete forever"));
+                    connect(l.last(), &QAction::triggered, [=]() {
+                        FileOperationUtils::executeRemoveActionWithDialog(m_selections);
+                    });
+                }
             }
 
             if (m_selections.count() == 1) {
@@ -488,13 +538,13 @@ const QList<QAction *> DesktopMenu::constructFileOpActions()
             }
         }
     } else {
-        auto pasteAction = addAction(QIcon::fromTheme("edit-paste-symbolic"), tr("&Paste"));
+        auto pasteAction = addAction(QIcon::fromTheme("edit-paste-symbolic"), tr("Paste"));
         l<<pasteAction;
         pasteAction->setEnabled(ClipboardUtils::isClipboardHasFiles());
         connect(l.last(), &QAction::triggered, [=]() {
             ClipboardUtils::pasteClipboardFiles(m_directory);
         });
-        l<<addAction(QIcon::fromTheme("view-refresh-symbolic"), tr("&Refresh"));
+        l<<addAction(QIcon::fromTheme("view-refresh-symbolic"), tr("Refresh"));
         connect(l.last(), &QAction::triggered, [=]() {
             auto desktopView = dynamic_cast<DesktopIconView*>(m_view);
             desktopView->refresh();
@@ -540,11 +590,14 @@ const QList<QAction *> DesktopMenu::constructMenuPluginActions()
     //FIXME:
     auto mgr = DesktopMenuPluginManager::getInstance();
     if (mgr->isLoaded()) {
+        //add debug log to check open-terminal not show in first time issue
+        qDebug() << "DesktopMenu PluginManager is loaded";
         //sort plugiins by name, so the menu option orders is relatively fixed
         auto pluginIds = mgr->getPluginIds();
         qSort(pluginIds.begin(), pluginIds.end());
 
         for (auto id : pluginIds) {
+            qDebug() << "desktop luginIds:" <<id;
             auto plugin = mgr->getPlugin(id);
             auto actions = plugin->menuActions(MenuPluginInterface::DesktopWindow,
                                                m_directory,
@@ -601,19 +654,37 @@ void DesktopMenu::showProperties(const QStringList &uris)
     QStringList args;
     for (auto arg : uris) {
         QUrl url = arg;
-        args<<url.toEncoded();
+        args << url.toEncoded();
     }
 
-    if (uris.contains("computer:///"))
-    {
-        gotoAboutComputer();
-        return;
+    args.removeDuplicates();
+
+    //注释掉这里以修复BUG#17809
+    if (uris.contains("computer:///")) {
+        args.removeAt(args.indexOf("computer:///"));
+        QtConcurrent::run([=]() {
+            gotoAboutComputer();
+        });
+    }
+
+    if (uris.contains("trash:///") && uris.count() > 1) {
+        args.removeAt(args.indexOf("trash:///"));
+        QtConcurrent::run([=]() {
+            QProcess p;
+#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
+            p.setProgram("peony");
+            p.setArguments(QStringList() << "--show-properties" << "trash:///");
+            p.startDetached();
+#else
+            p.startDetached("peony", QStringList()<<"--show-properties"<<args);
+#endif
+        });
     }
 
     QProcess p;
 #if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
     p.setProgram("peony");
-    p.setArguments(QStringList()<<"--show-properties"<<args);
+    p.setArguments(QStringList() << "--show-properties" << args);
     p.startDetached();
 #else
     p.startDetached("peony", QStringList()<<"--show-properties"<<args);
