@@ -39,7 +39,7 @@ namespace Peony {
 
 class DesktopIconView;
 
-class DesktopWindow : public QMainWindow
+class DesktopWindow : public QWidget
 {
     Q_OBJECT
 
@@ -50,6 +50,8 @@ public:
 public:
     const QString getCurrentBgPath();
     const QColor getCurrentColor();
+    QString getAccountBackground();
+    void setAccountBackground();
     bool getIsPrimary() {
         return m_is_primary;
     }
@@ -100,8 +102,6 @@ private:
     QPixmap m_bg_font_pixmap;
     QPixmap m_bg_back_pixmap;
 
-    QPixmap m_bg_font_cache_pixmap;
-    QPixmap m_bg_back_cache_pixmap;
 
     QGraphicsOpacityEffect *m_opacity_effect;
 
