@@ -30,6 +30,10 @@
 
 #include "desktop-icon-view.h"
 
+#include "primary-manager.h"
+#include "plasma-shell-manager.h"
+#include "desktop-menu.h"
+
 #include <QCommandLineParser>
 #include <QCommandLineOption>
 #include <QTimer>
@@ -53,6 +57,8 @@
 #include <QDBusReply>
 #include <QDesktopServices>
 
+#include <QScreen>
+
 #define KYLIN_USER_GUIDE_PATH "/"
 #define KYLIN_USER_GUIDE_SERVICE QString("com.kylinUserGuide.hotel_%1").arg(getuid())
 #define KYLIN_USER_GUIDE_INTERFACE "com.guide.hotel"
@@ -62,6 +68,8 @@
 static bool has_desktop = false;
 static bool has_daemon = false;
 static Peony::DesktopIconView *desktop_icon_view = nullptr;
+static PrimaryManager *screensMonitor = nullptr;
+static QMainWindow *virtualDesktopWindow = nullptr;
 
 //record of desktop start time
 qint64 PeonyDesktopApplication::peony_desktop_start_time = 0;
@@ -108,10 +116,27 @@ void trySetDefaultFolderUrlHandler() {
     });
 }
 
+QRect caculateVirtualDesktopGeometry() {
+    QRegion screensRegion;
+    for (auto screen : qApp->screens()) {
+        screensRegion += screen->geometry();
+    }
+
+    if (screensMonitor) {
+        int x = screensMonitor->getScreenGeometry("x");
+        int y = screensMonitor->getScreenGeometry("y");
+        int width = screensMonitor->getScreenGeometry("width");
+        int height = screensMonitor->getScreenGeometry("height");
+        screensRegion += QRect(x, y, width, height);
+    }
+
+    auto rect = screensRegion.boundingRect();
+    return rect;
+}
+
 PeonyDesktopApplication::PeonyDesktopApplication(int &argc, char *argv[], const char *applicationName) : SingleApplication (argc, argv, applicationName, true)
 {
-    setApplicationVersion("v3.0.0");
-    setApplicationName("peony-qt-desktop");
+    setApplicationVersion(QString("v%1").arg(VERSION));
     //setApplicationDisplayName(tr("Peony-Qt Desktop"));
 
     QTranslator *t = new QTranslator(this);
@@ -123,6 +148,8 @@ PeonyDesktopApplication::PeonyDesktopApplication(int &argc, char *argv[], const
     QTranslator *t3 = new QTranslator(this);
     t3->load("/usr/share/qt5/translations/qt_"+QLocale::system().name());
     QApplication::installTranslator(t3);
+    setApplicationName(tr("peony-qt-desktop"));
+    setWindowIcon(QIcon::fromTheme("system-file-manager"));
 
     if (this->isPrimary()) {
         qDebug()<<"isPrimary screen";
@@ -133,7 +160,12 @@ PeonyDesktopApplication::PeonyDesktopApplication(int &argc, char *argv[], const
         file.open(QFile::ReadOnly);
         setStyleSheet(QString::fromLatin1(file.readAll()));
         file.close();
-        Peony::DesktopMenuPluginManager::getInstance();
+
+        //add 5 seconds delay to load plugins
+        //try to fix first time enter desktop right menu not show open terminal issue
+        QTimer::singleShot(5000, [=]() {
+            Peony::DesktopMenuPluginManager::getInstance();
+        });
 
         /*
         QSystemTrayIcon *trayIcon = new QSystemTrayIcon(this);
@@ -172,7 +204,7 @@ PeonyDesktopApplication::PeonyDesktopApplication(int &argc, char *argv[], const
 Peony::DesktopIconView *PeonyDesktopApplication::getIconView()
 {
     if (!desktop_icon_view)
-        desktop_icon_view = new Peony::DesktopIconView;
+        desktop_icon_view = new Peony::DesktopIconView(virtualDesktopWindow);
     return desktop_icon_view;
 }
 
@@ -290,15 +322,99 @@ void PeonyDesktopApplication::parseCmd(quint32 id, QByteArray msg, bool isPrimar
 
         if (parser.isSet(desktopOption)) {
             if (!has_desktop) {
-                //FIXME: load menu plugin
-                //FIXME: take over desktop displaying
-                getIconView();
+                virtualDesktopWindow = new QMainWindow;
+                virtualDesktopWindow->setAttribute(Qt::WA_TranslucentBackground);
+                virtualDesktopWindow->setWindowFlag(Qt::FramelessWindowHint);
+                virtualDesktopWindow->setAttribute(Qt::WA_X11NetWmWindowTypeDesktop);
+                //virtualDesktopWindow->setAttribute(Qt::WA_TranslucentBackground);
+                auto virtualDesktopWindowRect = caculateVirtualDesktopGeometry();
+                virtualDesktopWindow->setFixedSize(virtualDesktopWindowRect.size());
+                virtualDesktopWindow->show();
+
+                virtualDesktopWindow->setContextMenuPolicy(Qt::CustomContextMenu);
+                virtualDesktopWindow->connect(virtualDesktopWindow, &QMainWindow::customContextMenuRequested, virtualDesktopWindow, [=](const QPoint &pos){
+                    qWarning()<<pos;
+                    auto fixedPos = getIconView()->mapFromGlobal(pos);
+                    auto index = PeonyDesktopApplication::getIconView()->indexAt(fixedPos);
+                    if (!index.isValid()) {
+                        PeonyDesktopApplication::getIconView()->clearSelection();
+                    } else {
+                        if (!PeonyDesktopApplication::getIconView()->selectionModel()->selection().indexes().contains(index)) {
+                            PeonyDesktopApplication::getIconView()->clearSelection();
+                            PeonyDesktopApplication::getIconView()->selectionModel()->select(index, QItemSelectionModel::Select);
+                        }
+                    }
+
+                    QTimer::singleShot(1, [=]() {
+                        DesktopMenu menu(PeonyDesktopApplication::getIconView());
+                        if (PeonyDesktopApplication::getIconView()->getSelections().isEmpty()) {
+                            auto action = menu.addAction(tr("set background"));
+                            connect(action, &QAction::triggered, [=]() {
+                                //go to control center set background
+                                DesktopWindow::gotoSetBackground();
+            //                    QFileDialog dlg;
+            //                    dlg.setNameFilters(QStringList() << "*.jpg"
+            //                                       << "*.png");
+            //                    if (dlg.exec()) {
+            //                        auto url = dlg.selectedUrls().first();
+            //                        this->setBg(url.path());
+            //                        // qDebug()<<url;
+            //                        Q_EMIT this->changeBg(url.path());
+            //                    }
+                            });
+                        }
+
+                        for (auto screen : qApp->screens()) {
+                            if (screen->geometry().contains(pos));
+                            //menu.windowHandle()->setScreen(screen);
+                        }
+                        menu.exec(pos);
+                        auto urisToEdit = menu.urisToEdit();
+                        if (urisToEdit.count() == 1) {
+                            QTimer::singleShot(
+                            100, this, [=]() {
+                                PeonyDesktopApplication::getIconView()->editUri(urisToEdit.first());
+                            });
+                        }
+                    });
+                });
+
                 for(auto screen : this->screens())
                 {
                     addWindow(screen);
                 }
             }
             has_desktop = true;
+            PlasmaShellManager::getInstance()->setRole(virtualDesktopWindow->windowHandle(), KWayland::Client::PlasmaShellSurface::Role::Desktop);
+
+            // check ukui wayland session, monitor ukui settings daemon dbus
+            if (QString(qgetenv("DESKTOP_SESSION")) == "ukui-wayland") {
+                screensMonitor = new PrimaryManager;
+                connect(screensMonitor, &PrimaryManager::priScreenChangedSignal, this, [=](int x, int y, int width, int height){
+                    auto virtualDesktopWindowRect = caculateVirtualDesktopGeometry();
+                    virtualDesktopWindow->setFixedSize(virtualDesktopWindowRect.size());
+                    getIconView()->setGeometry(x, y, width, height);
+                });
+                screensMonitor->start();
+                // init
+                getIconView()->show();
+                int x = screensMonitor->getScreenGeometry("x");
+                int y = screensMonitor->getScreenGeometry("y");
+                int width = screensMonitor->getScreenGeometry("width");
+                int height = screensMonitor->getScreenGeometry("height");
+                QRect geometry = QRect(x, y, width, height);
+                if (geometry.size() == QSize(0, 0)) {
+                    for (auto screen : qApp->screens()) {
+                        if (screen->geometry().topLeft() == QPoint(0, 0)) {
+                            geometry.setSize(screen->geometry().size());
+                            break;
+                        }
+                    }
+                }
+                getIconView()->setGeometry(x, y, width, height);
+            } else {
+                getIconView()->setGeometry(qApp->primaryScreen()->geometry());
+            }
         }
 
         connect(this, &QApplication::paletteChanged, this, [=](const QPalette &pal) {
@@ -323,18 +439,30 @@ void PeonyDesktopApplication::parseCmd(quint32 id, QByteArray msg, bool isPrimar
 
 void PeonyDesktopApplication::addWindow(QScreen *screen, bool checkPrimay)
 {
+    auto virtualDesktopWindowRect = caculateVirtualDesktopGeometry();
+    virtualDesktopWindow->setFixedSize(virtualDesktopWindowRect.size());
+    if (screen != nullptr) {
+        qDebug()<<"screenAdded"<<screen->name()<<screen<<m_window_list.size()<<screen->availableSize();
+        connect(screen, &QScreen::geometryChanged, this, [=](){
+            auto virtualDesktopWindowRect = caculateVirtualDesktopGeometry();
+            virtualDesktopWindow->setFixedSize(virtualDesktopWindowRect.size());
+        });
+    } else {
+        return;
+    }
+
     Peony::DesktopWindow *window;
     if (checkPrimay) {
         bool is_primary = isPrimaryScreen(screen);
-        window = new Peony::DesktopWindow(screen, is_primary);
+        window = new Peony::DesktopWindow(screen, is_primary, virtualDesktopWindow);
         if (is_primary)
         {
-            window->setCentralWidget(desktop_icon_view);
+//            window->setCentralWidget(desktop_icon_view);
             window->updateView();
             //connect(window, &Peony::DesktopWindow::changeBg, this, &PeonyDesktopApplication::changeBgProcess);
         }
     } else {
-        window = new Peony::DesktopWindow(screen, false);
+        window = new Peony::DesktopWindow(screen, false, virtualDesktopWindow);
     }
 
     connect(window, &Peony::DesktopWindow::checkWindow, this, &PeonyDesktopApplication::checkWindowProcess);
@@ -344,6 +472,11 @@ void PeonyDesktopApplication::addWindow(QScreen *screen, bool checkPrimay)
     for (auto window : m_window_list) {
         window->updateWinGeometry();
     }
+
+    window->show();
+
+    getIconView()->show();
+    getIconView()->raise();
 }
 
 void PeonyDesktopApplication::layoutDirectionChangedProcess(Qt::LayoutDirection direction)
@@ -354,82 +487,21 @@ void PeonyDesktopApplication::layoutDirectionChangedProcess(Qt::LayoutDirection
 
 void PeonyDesktopApplication::primaryScreenChangedProcess(QScreen *screen)
 {
-    if (screen != nullptr)
-        qDebug()<<"primaryScreenChangedProcess"<<screen->name()<<screen->geometry()<<screen->availableGeometry()<<screen->virtualGeometry();
-    else {
-        qWarning()<<"no primary screen!";
+    if (screensMonitor)
         return;
-    }
-
-    bool need_exchange = false;
-    QScreen *preMainScreen = nullptr;
-    Peony::DesktopWindow *rawPrimaryWindow = nullptr;
-    Peony::DesktopWindow *currentPrimayWindow = nullptr;
-    for(auto win : m_window_list)
-    {
-        if (win->centralWidget())
-            rawPrimaryWindow = win;
-
-        if (win->getScreen() == screen)
-            currentPrimayWindow = win;
-        //need exchange window screen
-//        if (win->getView() && win->getScreen() != screen)
-//        {
-//            preMainScreen = win->getScreen();
-//            need_exchange = true;
-//            break;
-//        }
-    }
-
-    if (rawPrimaryWindow && currentPrimayWindow) {
-        currentPrimayWindow->setCentralWidget(getIconView());
-        //desktop_icon_view->show();
-        currentPrimayWindow->updateView();
-        currentPrimayWindow->hide();
-        currentPrimayWindow->show();
-    }
-    return;
-
-    //do not check window need exchange
-    //cause we always put the desktop icon view into window
-    //which in current primary screen.
-    if (need_exchange)
-    {
-        for(auto win : m_window_list)
-        {
-            //qDebug()<<"before screen info"<<win->getScreen()->name()<<win->getScreen()->geometry()<<win->geometry()<<preMainScreen->name();
-            win->disconnectSignal();
-            if (win->getScreen() == preMainScreen)
-            {
-                win->setScreen(screen);
-                win->setIsPrimary(true);
-            }
-            else if (win->getScreen() == screen) {
-                win->setScreen(preMainScreen);
-                win->setIsPrimary(false);
-            }
-            win->connectSignal();
-            win->updateWinGeometry();
-            //qDebug()<<"end screen info"<<win->getScreen()->name()<<win->getScreen()->geometry()<<win->geometry();
-            //if (win->getView())
-            //qDebug()<<"view info:"<<win->getView();
-        }
-    }
+    getIconView()->setGeometry(screen->availableGeometry());
+    getIconView()->raise();
 }
 
 void PeonyDesktopApplication::screenAddedProcess(QScreen *screen)
 {
-    if (screen != nullptr)
-        qDebug()<<"screenAdded"<<screen->name()<<screen<<m_window_list.size()<<screen->availableSize();
-    else {
-        return;
-    }
-
     addWindow(screen, false);
 }
 
 void PeonyDesktopApplication::screenRemovedProcess(QScreen *screen)
 {
+    auto virtualDesktopWindowRect = caculateVirtualDesktopGeometry();
+    virtualDesktopWindow->setFixedSize(virtualDesktopWindowRect.size());
     //if (screen != nullptr)
     //qDebug()<<"screenRemoved"<<screen->name()<<screen->serialNumber();
 
@@ -441,6 +513,7 @@ void PeonyDesktopApplication::screenRemovedProcess(QScreen *screen)
         {
             qDebug()<<"remove window";
             m_window_list.removeOne(win);
+//            win->setCentralWidget(nullptr);
             win->deleteLater();
         }
     }
@@ -492,11 +565,13 @@ void guessContentTypeCallback(GObject* object,GAsyncResult *res,gpointer data)
     char *mountUri;
     bool openFolder;
     QProcess process;
+    static QString lastMountUri;
 
     error = NULL;
     openFolder = true;
     root = g_mount_get_default_location(G_MOUNT(object));
     mountUri = g_file_get_uri(root);
+
     openFolderCmd = "peony " + QString(mountUri);
     guessType = g_mount_guess_content_type_finish(G_MOUNT(object),res,&error);
 
@@ -504,13 +579,33 @@ void guessContentTypeCallback(GObject* object,GAsyncResult *res,gpointer data)
         g_error_free(error);
         error = NULL;
     }else{
+        GDrive *drive = g_mount_get_drive(G_MOUNT(object));
+        char *unixDevice = NULL;
+        if(drive){
+            unixDevice = g_drive_get_identifier(drive,G_DRIVE_IDENTIFIER_KIND_UNIX_DEVICE);
+            g_object_unref(drive);
+        }
+
         if(guessType && g_strv_length(guessType) > 0){
             int n;
             for(n = 0; guessType[n]; ++n){
                 if(g_content_type_is_a(guessType[n],"x-content/win32-software"))
                     openFolder = false;
+                if(unixDevice && !strcmp(guessType[n],"x-content/bootable-media") && !strstr(unixDevice,"/dev/sr"))
+                    openFolder = false;
                 if(!strcmp(guessType[n],"x-content/blank-dvd") || !strcmp(guessType[n],"x-content/blank-cd"))
                     openFolder = false;
+                if(strstr(guessType[n],"x-content/audio-")){
+                    if(!lastMountUri.compare(mountUri)){
+                        lastMountUri.clear();
+                        break;
+                    }
+                    lastMountUri = mountUri;
+                }
+
+                QString uri = mountUri;
+                if (uri.startsWith("gphoto") || uri.startsWith("mtp"))
+                    break;
 
                 if(openFolder)
                     process.startDetached(openFolderCmd);
@@ -519,13 +614,6 @@ void guessContentTypeCallback(GObject* object,GAsyncResult *res,gpointer data)
             }
             g_strfreev(guessType);
         }else{
-            GDrive *drive = g_mount_get_drive(G_MOUNT(object));
-            char *unixDevice = NULL;
-            if(drive){
-                unixDevice = g_drive_get_identifier(drive,G_DRIVE_IDENTIFIER_KIND_UNIX_DEVICE);
-                g_object_unref(drive);
-            }
-
             //Only DvD devices are allowed to open folder automatically.
             if(unixDevice && !strcmp(unixDevice,"/dev/sr") && QGSettings::isSchemaInstalled(DESKTOP_MEDIA_HANDLE)){
                 QGSettings* autoMountSettings =  new QGSettings(DESKTOP_MEDIA_HANDLE);
@@ -535,8 +623,8 @@ void guessContentTypeCallback(GObject* object,GAsyncResult *res,gpointer data)
                 }
             }
 
-            g_free(unixDevice);
         }
+        g_free(unixDevice);
     }
 
     g_free(mountUri);
@@ -569,6 +657,6 @@ void PeonyDesktopApplication::volumeRemovedProcess(const std::shared_ptr<Peony::
     }
 
     //if it is possible, we stop it's drive after eject successfully.
-    if(gdrive && g_drive_can_stop(gdrive))
-        g_drive_stop(gdrive,G_MOUNT_UNMOUNT_NONE,NULL,NULL,NULL,NULL);
+   // if(gdrive && g_drive_can_stop(gdrive))
+   //     g_drive_stop(gdrive,G_MOUNT_UNMOUNT_NONE,NULL,NULL,NULL,NULL);
 };
