@@ -34,7 +34,6 @@
 
 #include "directory-view-factory-manager.h"
 #include "directory-view-plugin-iface2.h"
-#include "search-vfs-uri-parser.h"
 #include "file-info.h"
 #include "file-info-job.h"
 
@@ -55,23 +54,22 @@
 
 #include <QtConcurrent>
 
+#include <QX11Info>
+
+#include <QPainter>
+
 #include <QDebug>
 
 static HeaderBarStyle *global_instance = nullptr;
 static QString terminal_cmd = nullptr;
 
-static QString gPlatform = nullptr;
-
 HeaderBar::HeaderBar(MainWindow *parent) : QToolBar(parent)
 {
-    if (gPlatform.isNull()) {
-        gPlatform = qgetenv("XDG_SESSION_TYPE");
-    }
-
     setAttribute(Qt::WA_AcceptTouchEvents);
 
     setMouseTracking(true);
     setStyle(HeaderBarStyle::getStyle());
+    setFocusPolicy(Qt::TabFocus);
 
     m_window = parent;
     //disable default menu
@@ -81,40 +79,66 @@ HeaderBar::HeaderBar(MainWindow *parent) : QToolBar(parent)
                   "background-color: transparent;"
                   "border: 0px solid transparent;"
                   "margin: 4px 5px 4px 5px;"
-                  "};");
+                  "}");
 
     setMovable(false);
 
-    auto a = addAction(QIcon::fromTheme("folder-new-symbolic"), tr("Create Folder"), [=]() {
-        //use the same function
-        m_window->createFolderOperation();
-    });
-    auto createFolder = qobject_cast<QToolButton *>(widgetForAction(a));
-    createFolder->setAutoRaise(false);
-    createFolder->setFixedSize(QSize(40, 40));
-    createFolder->setIconSize(QSize(16, 16));
-    m_create_folder = createFolder;
+//    auto a = addAction(QIcon::fromTheme("folder-new-symbolic"), tr("Create Folder"), [=]() {
+//        //use the same function
+//        m_window->createFolderOperation();
+//    });
+//    auto createFolder = qobject_cast<QToolButton *>(widgetForAction(a));
+//    createFolder->setAutoRaise(false);
+//    createFolder->setFixedSize(QSize(40, 40));
+//    createFolder->setIconSize(QSize(16, 16));
+//    m_create_folder = createFolder;
 
-    addSpacing(2);
+    //use theme buttons
+//    auto createFolder = new HeadBarPushButton(this);
+//    m_create_folder = createFolder;
+//    createFolder->setFixedSize(QSize(40, 40));
+//    createFolder->setIconSize(QSize(16, 16));
+//    createFolder->setIcon(QIcon::fromTheme("folder-new-symbolic"));
+//    createFolder->setToolTip(tr("Create Folder"));
+//    addWidget(createFolder);
+//    connect(createFolder, &QPushButton::clicked, m_window, [=]() {
+//        //use the same function
+//        m_window->createFolderOperation();
+//    });
+
+//    addSpacing(2);
 
     //find a terminal when init
-    findDefaultTerminal();
-    a = addAction(QIcon::fromTheme("terminal-app-symbolic"), tr("Open Terminal"), [=]() {
-        //open the default terminal
-        openDefaultTerminal();
-    });
-    auto openTerminal = qobject_cast<QToolButton *>(widgetForAction(a));
-    openTerminal->setAutoRaise(false);
-    openTerminal->setFixedSize(QSize(40, 40));
-    openTerminal->setIconSize(QSize(16, 16));
+//    findDefaultTerminal();
+//    a = addAction(QIcon::fromTheme("terminal-app-symbolic"), tr("Open Terminal"), [=]() {
+//        //open the default terminal
+//        openDefaultTerminal();
+//    });
+//    auto openTerminal = qobject_cast<QToolButton *>(widgetForAction(a));
+//    openTerminal->setAutoRaise(false);
+//    openTerminal->setFixedSize(QSize(40, 40));
+//    openTerminal->setIconSize(QSize(16, 16));
 
-    addSpacing(9);
+    //use theme buttons
+//    auto openTerminal = new HeadBarPushButton(this);
+//    openTerminal->setFixedSize(QSize(40, 40));
+//    openTerminal->setIconSize(QSize(16, 16));
+//    openTerminal->setIcon(QIcon::fromTheme("terminal-app-symbolic"));
+//    openTerminal->setToolTip(tr("Open Terminal"));
+//    addWidget(openTerminal);
+//    connect(openTerminal, &QPushButton::clicked, m_window, [=]() {
+//        //open the default terminal
+//        openDefaultTerminal();
+//    });
+
+//    addSpacing(9 - 4);
 
     auto goBack = new HeadBarPushButton(this);
     m_go_back = goBack;
     goBack->setEnabled(false);
     goBack->setToolTip(tr("Go Back"));
-    goBack->setFixedSize(QSize(36, 28));
+    goBack->setFixedSize(QSize(40, 40));
+    goBack->setIconSize(QSize(16, 16));
     goBack->setIcon(QIcon::fromTheme("go-previous-symbolic"));
     addWidget(goBack);
 
@@ -122,17 +146,20 @@ HeaderBar::HeaderBar(MainWindow *parent) : QToolBar(parent)
     m_go_forward = goForward;
     goForward->setEnabled(false);
     goForward->setToolTip(tr("Go Forward"));
-    goForward->setFixedSize(QSize(36, 28));
+    goForward->setFixedSize(QSize(40, 40));
+    goForward->setIconSize(QSize(16, 16));
     goForward->setIcon(QIcon::fromTheme("go-next-symbolic"));
     addWidget(goForward);
     connect(goForward, &QPushButton::clicked, m_window, [=]() {
         m_window->getCurrentPage()->goForward();
     });
 
-    addSpacing(9);
+    addSpacing(ADDRESS_BAR_LEFT_WIDTH);
 
     auto locationBar = new Peony::AdvancedLocationBar(this);
+    locationBar->setMinimumWidth(ADDRESS_BAR_MINIMUN_WIDTH);
     m_location_bar = locationBar;
+    m_location_bar->setFocusPolicy(Qt::FocusPolicy(m_location_bar->focusPolicy() & ~Qt::TabFocus));
     addWidget(locationBar);
 
     connect(goBack, &QPushButton::clicked, m_window, [=]() {
@@ -148,30 +175,45 @@ HeaderBar::HeaderBar(MainWindow *parent) : QToolBar(parent)
         m_window->getCurrentPage()->setSortFilter(index);
     });
     connect(m_location_bar, &Peony::AdvancedLocationBar::searchRequest, [=](const QString &path, const QString &key){
-        //key is null, clean search content, show all files
-        if (key == "" || key.isNull())
-            Q_EMIT this->updateLocationRequest(path, false);
-        else
-        {
-            auto targetUri = Peony::SearchVFSUriParser::parseSearchKey(path, key, true, false, "", m_search_recursive);
-            Q_EMIT this->updateLocationRequest(targetUri, false);
-        }
+//        m_window->forceStopLoading();
+//        //key is null, clean search content, show all files
+//        if (key == "" || key.isNull())
+//            Q_EMIT this->updateLocationRequest(path, true);
+//        else
+//        {
+//            auto targetUri = Peony::SearchVFSUriParser::parseSearchKey(path, key, true, false, "", m_search_recursive);
+//            Q_EMIT this->updateLocationRequest(targetUri, true);
+//        }
+
+        //search update all in main window
+        m_window->forceStopLoading();
+        Q_EMIT this->updateSearch(path, key, true);
     });
 
     connect(m_location_bar, &Peony::AdvancedLocationBar::updateWindowLocationRequest, this, &HeaderBar::updateLocationRequest);
 
-    addSpacing(9);
-    a = addAction(QIcon::fromTheme("edit-find-symbolic"), tr("Search"));
-    connect(a, &QAction::triggered, this, &HeaderBar::searchButtonClicked);
-    auto search = qobject_cast<QToolButton *>(widgetForAction(a));
-    search->setAutoRaise(false);
-    search->setFixedSize(QSize(40, 40));
-    setIconSize(QSize(16, 16));
+    addSpacing(ADDRESS_BAR_RIGHT_WIDTH);
+//    auto a = addAction(QIcon::fromTheme("edit-find-symbolic"), tr("Search"));
+//    connect(a, &QAction::triggered, this, &HeaderBar::searchButtonClicked);
+//    auto search = qobject_cast<QToolButton *>(widgetForAction(a));
+//    search->setAutoRaise(false);
+//    search->setFixedSize(QSize(40, 40));
+//    setIconSize(QSize(16, 16));
+//    m_search_button = search;
+
+    //use theme buttons
+    auto search = new HeadBarPushButton(this);
     m_search_button = search;
+    search->setFixedSize(QSize(SEARCH_BTN_WIDTH, SEARCH_BTN_WIDTH));
+    search->setIconSize(QSize(16, 16));
+    search->setIcon(QIcon::fromTheme("edit-find-symbolic"));
+    search->setToolTip(tr("Search"));
+    addWidget(search);
+    connect(search, &QPushButton::clicked, this, &HeaderBar::searchButtonClicked);
 
-    addSpacing(9);
+    addSpacing(DRAG_AREA_DEFAULT_WIDTH);
 
-    a = addAction(QIcon::fromTheme("view-grid-symbolic"), tr("View Type"));
+    auto a = addAction(QIcon::fromTheme("view-grid-symbolic"), tr("View Type"));
     auto viewType = qobject_cast<QToolButton *>(widgetForAction(a));
     viewType->setAutoRaise(false);
     viewType->setFixedSize(QSize(57, 40));
@@ -235,11 +277,54 @@ HeaderBar::HeaderBar(MainWindow *parent) : QToolBar(parent)
     m_operation_menu = new OperationMenu(m_window, this);
     a->setMenu(m_operation_menu);
 
+//    createFolder->setFlat(true);
+//    createFolder->setProperty("isWindowButton", 1);
+//    createFolder->setProperty("useIconHighlightEffect", 2);
+//    createFolder->setProperty("isIcon", true);
+
+//    openTerminal->setFlat(true);
+//    openTerminal->setProperty("isWindowButton", 1);
+//    openTerminal->setProperty("useIconHighlightEffect", 2);
+//    openTerminal->setProperty("isIcon", true);
+
+    search->setFlat(true);
+    search->setProperty("isWindowButton", 1);
+    search->setProperty("useIconHighlightEffect", 2);
+    search->setProperty("isIcon", true);
+
+    goBack->setFlat(true);
+    goBack->setProperty("isWindowButton", 1);
+    goBack->setProperty("useIconHighlightEffect", 2);
+    goBack->setProperty("isIcon", true);
+    goForward->setFlat(true);
+    goForward->setProperty("isWindowButton", 1);
+    goForward->setProperty("useIconHighlightEffect", 2);
+    goForward->setProperty("isIcon", true);
+
     for (auto action : actions()) {
         auto w = widgetForAction(action);
-        w->setProperty("useIconHighlightEffect", true);
-        w->setProperty("iconHighlightEffectMode", 1);
+
+        if (w != search && qobject_cast<QToolButton *>(w)) {
+            w->setProperty("isWindowButton", 1);
+            if (auto toolButton = qobject_cast<QToolButton *>(w)) {
+                toolButton->setAutoRaise(true);
+            }
+            w->setProperty("useIconHighlightEffect", 2);
+        }
     }
+
+    setMinimumWidth(GBACK_BTN_WIDTH * 2
+                    + ADDRESS_BAR_LEFT_WIDTH + ADDRESS_BAR_MINIMUN_WIDTH + ADDRESS_BAR_RIGHT_WIDTH
+                    + SEARCH_BTN_WIDTH
+                    + DRAG_AREA_MINIMUN_WIDTH);
+//    m_focus_list<<(createFolder);
+//    m_focus_list<<(openTerminal);
+    m_focus_list<<(goBack);
+    m_focus_list<<(goForward);
+    m_focus_list<<(search);
+    m_focus_list<<(viewType);
+    m_focus_list<<(sortType);
+    m_focus_list<<(popMenu);
 }
 
 void HeaderBar::findDefaultTerminal()
@@ -330,6 +415,14 @@ void HeaderBar::closeSearch()
     setSearchMode(false);
 }
 
+void HeaderBar::initFocus()
+{
+    for (auto widget : m_focus_list) {
+        widget->setFocusPolicy(Qt::StrongFocus);
+        m_window->addFocusWidgetToFocusList(widget);
+    }
+}
+
 void HeaderBar::updateSearchRecursive(bool recursive)
 {
     m_search_recursive = recursive;
@@ -355,6 +448,11 @@ void HeaderBar::setLocation(const QString &uri)
     m_location_bar->updateLocation(uri);
 }
 
+void HeaderBar::cancelEdit()
+{
+    m_location_bar->cancelEdit();
+}
+
 void HeaderBar::startEdit(bool bSearch)
 {
     //qDebug() << "bSearch" <<bSearch <<m_search_mode;
@@ -393,24 +491,27 @@ void HeaderBar::updateIcons()
     m_go_forward->setEnabled(m_window->getCurrentPage()->canGoForward());
 
     //fix create folder fail issue in special path
-    auto curUri = m_window->getCurrentUri();
-    auto info = Peony::FileInfo::fromUri(curUri, false);
-    Peony::FileInfoJob job(info);
-    job.querySync();
-    if (info->canWrite())
-        m_create_folder->setEnabled(true);
-    else
-        m_create_folder->setEnabled(false);
-
-    m_go_back->setProperty("useIconHighlightEffect", true);
-    m_go_back->setProperty("iconHighlightEffectMode", 1);
-    m_go_forward->setProperty("useIconHighlightEffect", true);
-    m_go_forward->setProperty("iconHighlightEffectMode", 1);
+//    auto curUri = m_window->getCurrentUri();
+//    auto info = Peony::FileInfo::fromUri(curUri);
+    //Peony::FileInfoJob job(info);
+    //job.querySync();
+//    if (info->canWrite())
+//        m_create_folder->setEnabled(true);
+//    else
+//        m_create_folder->setEnabled(false);
 
     //maximize & restore
     updateMaximizeState();
 }
 
+void HeaderBar::updateHeaderState()
+{
+//    if (! m_window->getFilterWorking())
+//        m_create_folder->setEnabled(true);
+//    else
+//        m_create_folder->setEnabled(false);
+}
+
 void HeaderBar::updateMaximizeState()
 {
     //maximize & restore
@@ -513,7 +614,7 @@ bool HeaderBarContainer::eventFilter(QObject *obj, QEvent *e)
     Q_UNUSED(obj)
     auto window = qobject_cast<MainWindow *>(obj);
     if (window) {
-        if (e->type() == QEvent::Resize) {
+        if (e->type() == QEvent::Resize || QEvent::WindowStateChange == e->type()) {
             if (window->isMaximized()) {
                 m_max_or_restore->setIcon(QIcon::fromTheme("window-restore-symbolic"));
                 //m_max_or_restore->setToolTip(tr("Restore"));
@@ -522,6 +623,14 @@ bool HeaderBarContainer::eventFilter(QObject *obj, QEvent *e)
                 //m_max_or_restore->setToolTip(tr("Maximize"));
             }
         }
+        //fix double click space window has no change issue, bug#38499
+        else if (e->type() == QEvent::MouseButtonDblClick)
+        {
+            if (window->isMaximized())
+                window->showNormal();
+            else
+                window->showMaximized();
+        }
         return false;
     } else {
         if (e->type() == QEvent::MouseMove) {
@@ -547,6 +656,8 @@ void HeaderBarContainer::addHeaderBar(HeaderBar *headerBar)
     headerBar->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
     m_layout->addWidget(headerBar);
 
+    headerBar->initFocus();
+
     addWindowButtons();
 
     m_internal_widget->setLayout(m_layout);
@@ -603,6 +714,19 @@ void HeaderBarContainer::addWindowButtons()
     close->setAutoRaise(false);
     close->setFixedSize(QSize(40, 40));
     close->setIconSize(QSize(16, 16));
+
+    minimize->setProperty("isWindowButton", 1);
+    minimize->setProperty("useIconHighlightEffect", 0x2);
+    minimize->setAutoRaise(true);
+
+    maximizeAndRestore->setProperty("isWindowButton", 1);
+    maximizeAndRestore->setProperty("useIconHighlightEffect", 0x2);
+    maximizeAndRestore->setAutoRaise(true);
+
+    close->setProperty("isWindowButton", 2);
+    close->setProperty("useIconHighlightEffect", 0x2);
+    close->setAutoRaise(true);
+
     connect(close, &QToolButton::clicked, this, [=]() {
         m_header_bar->m_window->close();
     });
@@ -631,16 +755,25 @@ void HeaderBarContainer::addWindowButtons()
     close->setMouseTracking(true);
     close->installEventFilter(this);
 
-    for (int i = 0; i < 3; i++) {
-        auto w = layout->itemAt(i)->widget();
-        w->setProperty("useIconHighlightEffect", true);
-        w->setProperty("iconHighlightEffectMode", 1);
-    }
-
-    if (gPlatform == "wayland") {
+    if (!QX11Info::isPlatformX11()) {
         minimize->setVisible(false);
         maximizeAndRestore->setVisible(false);
         close->setVisible(false);
         m_layout->removeItem(layout);
     }
+
+    m_header_bar->m_window->addFocusWidgetToFocusList(minimize);
+    m_header_bar->m_window->addFocusWidgetToFocusList(maximizeAndRestore);
+    m_header_bar->m_window->addFocusWidgetToFocusList(close);
+}
+
+void HeaderBarContainer::paintEvent(QPaintEvent *e)
+{
+    QPainter p(this);
+    QStyleOptionToolBar opt;
+    initStyleOption(&opt);
+    bool isEnable = opt.state & QStyle::State_Enabled;
+    bool isActive = opt.state & QStyle::State_Active;
+    auto color = qApp->palette().color(isEnable? isActive? QPalette::Active: QPalette::Inactive: QPalette::Disabled, QPalette::Base);
+    p.fillRect(this->rect(), color);
 }
