@@ -26,8 +26,13 @@
 #include <QTabBar>
 #include <QProxyStyle>
 #include <QTimer>
+#include <memory>
 
 class QToolButton;
+class QDrag;
+namespace Peony {
+class FileInfo;
+}
 
 class NavigationTabBar : public QTabBar
 {
@@ -49,7 +54,6 @@ public Q_SLOTS:
 protected:
     void tabRemoved(int index) override;
     void tabInserted(int index) override;
-    void relayoutFloatButton(bool insterted);
 
     void dragEnterEvent(QDragEnterEvent *e) override;
     void dragMoveEvent(QDragMoveEvent *e) override;
@@ -63,12 +67,15 @@ protected:
     void resizeEvent(QResizeEvent *e) override;
 
 private:
-    QToolButton *m_float_button;
-
     QTimer m_drag_timer;
     bool m_start_drag = false;
+    QPoint m_press_pos;
+    QDrag *m_drag = nullptr;
+    bool m_should_trigger_drop = false;
 
     const int ELIDE_TEXT_LENGTH = 16;
+
+    std::shared_ptr<Peony::FileInfo> m_info;
 };
 
 class TabBarStyle : public QProxyStyle
@@ -79,6 +86,9 @@ class TabBarStyle : public QProxyStyle
     TabBarStyle() {}
 
     int pixelMetric(PixelMetric metric, const QStyleOption *option = nullptr, const QWidget *widget = nullptr) const override;
+    QRect subElementRect(SubElement element, const QStyleOption *option, const QWidget *widget) const override;
+    void drawComplexControl(ComplexControl control, const QStyleOptionComplex *option, QPainter *painter, const QWidget *widget) const override;
+    void drawControl(ControlElement element, const QStyleOption *option, QPainter *painter, const QWidget *widget) const override;
 };
 
 #endif // NAVIGATIONTABBAR_H
