@@ -25,9 +25,9 @@
 #include "file-utils.h"
 #include "search-vfs-uri-parser.h"
 #include "tab-widget.h"
+#include "file-info.h"
 
 #include "global-settings.h"
-#include "main-window.h"
 
 #include <QLabel>
 #include <QPainter>
@@ -57,6 +57,7 @@ TabStatusBar::TabStatusBar(TabWidget *tab, QWidget *parent) : QStatusBar(parent)
     addWidget(m_label, 1);
 
     m_slider = new QSlider(Qt::Horizontal, this);
+    m_slider->setFocusPolicy(Qt::FocusPolicy(Qt::WheelFocus & ~Qt::TabFocus));
     m_slider->setRange(0, 100);
 
     auto mainWindow = qobject_cast<MainWindow *>(this->topLevelWidget());
@@ -88,78 +89,54 @@ void TabStatusBar::update()
     if (!m_tab)
         return;
 
+    //qDebug() << "TabStatusBar::update";
     auto selections = m_tab->getCurrentSelectionFileInfos();
-    auto uri = m_tab->getCurrentUri();
+
+    //show current path files count
+    if (selections.count() ==0)
+    {
+        auto uris = m_tab->getCurrentAllFileInfos();
+        if (uris.count() == 0)
+            m_label->setText("");
+        else
+            m_label->setText(tr(" \%1 items ").arg(uris.count()));
+
+        return;
+    }
 
     //fix select special item issue
     if (selections.count() == 1 && (selections.first()->uri().isNull()
-        || selections.first()->uri() == "network:///"))
+        || (selections.first()->uri() == "network:///"
+        || selections.first()->uri() == "computer:///")))
     {
         m_label->setText("");
         return;
     }
 
-    if (! selections.isEmpty()) {
-        QString directoriesString = "";
-        int directoryCount = 0;
-        QString filesString="";
-        int fileCount = 0;
-        goffset size = 0;
-        for (auto selection : selections) {
-            if(selection->isDir()) {
-                directoryCount++;
-            } else if (!selection->isVolume()) {
-                fileCount++;
-                size += selection->size();
-            }
-        }
-        auto format_size = g_format_size(size);
-        //qDebug() << "directoryCount:" <<directoryCount <<",fileCount" <<fileCount <<format_size;
-
-        //in computer, only show selected count
-        if (uri != "computer:///")
+    int specialCount = 0;
+    goffset size = 0;
+    for (auto selection : selections) {
+        //not count special path
+        if (selection->uri() == "network:///"
+           || selection->uri() == "computer:///")
         {
-            if (selections.count() == 1) {
-                if (directoryCount == 1 && selections.first()->displayName() != "")
-                    directoriesString = QString(", %1").arg(selections.first()->displayName());
-                if (fileCount == 1 && size >0)
-                    filesString = QString(", %1, %2").arg(selections.first()->displayName()).arg(format_size);
-            } else if (directoryCount > 1 && (fileCount > 1)) {
-                directoriesString = tr("; %1 folders").arg(directoryCount);
-                if (size >0)
-                   filesString = tr("; %1 files, %2 total").arg(fileCount).arg(format_size);
-            } else if (directoryCount == 1 && (fileCount > 1)) {
-                directoriesString = tr("; %1 folder").arg(directoryCount);
-                if (size >0)
-                   filesString = tr("; %1 file, %2").arg(fileCount).arg(format_size);
-            } else if (fileCount == 0) {
-                directoriesString = tr("; %1 folders").arg(directoryCount);
-            } else if (size >0){
-                filesString = tr("; %1 files, %2 total").arg(fileCount).arg(format_size);
-            }
+            specialCount++;
+            continue;
         }
 
-        //qDebug() << "directoriesString:" <<directoriesString <<filesString;
-        m_label->setText(tr("%1 selected").arg(selections.count()) + directoriesString + filesString);
-        //showMessage(tr("%1 files selected ").arg(selections.count()));
-        g_free(format_size);
-    }
-    else {
-        //FIXME: replace BLOCKING api in ui thread.
-        auto displayName = Peony::FileUtils::getFileDisplayName(uri);
-        //qDebug() << "status bar text:" <<displayName <<uri;
-        if (uri.startsWith("search:///"))
-        {
-            QString nameRegexp = Peony::SearchVFSUriParser::getSearchUriNameRegexp(uri);
-            QString targetDirectory = Peony::SearchVFSUriParser::getSearchUriTargetDirectory(uri);
-            displayName = tr("Search \"%1\" in \"%2\"").arg(nameRegexp).arg(targetDirectory);
-            m_label->setText(displayName);
-        }
-        else {
-            QUrl url = m_tab->getCurrentUri();
-            m_label->setText(url.toDisplayString());
+        if(! selection->isDir() && ! selection->isVolume()){
+            size += selection->size();
         }
     }
+
+   //Calculated by 1024 bytes
+    auto format_size  = g_format_size_full(size, G_FORMAT_SIZE_IEC_UNITS);
+    if (size > 0)
+        m_label->setText(tr(" selected \%1 items    \%2").arg(selections.count()).arg(format_size));
+    else
+        m_label->setText(tr(" selected \%1 items").arg(selections.count()- specialCount));
+
+    g_free(format_size);
 }
 
 void TabStatusBar::update(const QString &message)
@@ -216,6 +193,16 @@ void ElidedLabel::setText(const QString &text)
 
 void ElidedLabel::paintEvent(QPaintEvent *event)
 {
+    /*!
+     * \note
+     * paint status bar background and text.
+     *
+     * designer want to layout status bar into the view, however the status bar belongs to main window now.
+     * that means status bar will be layout over the view. it is not possible to archive the ui desginer goals untils we
+     * destroy the current directory view frameworks.
+     *
+     * it is a complex problem, not an easy one. so do not think about changing the layout here to solve the problem easily.
+     */
     QStyleOption opt;
     opt.initFrom(this);
     bool active = opt.state &QStyle::State_Active;
@@ -225,40 +212,40 @@ void ElidedLabel::paintEvent(QPaintEvent *event)
     QFontMetrics fm(this->font());
     auto elidedText = fm.elidedText(m_text, Qt::TextElideMode::ElideRight, this->size().width() - 150);
     QPainter p(this);
-    //p.setCompositionMode(QPainter::CompositionMode_SourceIn);
-    QLinearGradient linearGradient;
-    linearGradient.setStart(QPoint(10, this->height()));
-    linearGradient.setFinalStop(QPoint(10, 0));
-    linearGradient.setColorAt(0, base);
-    linearGradient.setColorAt(0.75, base);
-    linearGradient.setColorAt(1, Qt::transparent);
+//    //p.setCompositionMode(QPainter::CompositionMode_SourceIn);
+//    QLinearGradient linearGradient;
+//    linearGradient.setStart(QPoint(10, this->height()));
+//    linearGradient.setFinalStop(QPoint(10, 0));
+//    linearGradient.setColorAt(0, base);
+//    linearGradient.setColorAt(0.75, base);
+//    linearGradient.setColorAt(1, Qt::transparent);
 
     int overlap = qApp->style()->pixelMetric(QStyle::PM_ScrollView_ScrollBarOverlap);
     int layoutWidth = qApp->style()->pixelMetric(QStyle::PM_DefaultFrameWidth);
     int adjustedY2 = qMin(0, overlap - layoutWidth);
 
     QPainterPath path;
-    path.addRect(this->rect().adjusted(0, 0, adjustedY2 - this->height(), 0));
+    path.addRect(this->rect().adjusted(0, 0, adjustedY2 - this->height() + 14, 0));
 
-    p.fillPath(path, linearGradient);
+    p.fillPath(path, base);
 
-    QPainterPath path2;
+//    QPainterPath path2;
 
-    int radius = this->height();
-    QPoint pos = QPoint(this->width() + adjustedY2 - this->height(), this->height());
-    //QRect targetRect = QRect(pos.x() - radius, pos.y() - radius, radius*2, radius*2);
-    path2.moveTo(pos);
-    //path2.arcTo(targetRect, 0, 90);
+//    int radius = this->height();
+//    QPoint pos = QPoint(this->width() + adjustedY2 - this->height(), this->height());
+//    QRect targetRect = QRect(pos.x() - radius, pos.y() - radius, radius*2, radius*2);
+//    path2.moveTo(pos);
+//    path2.arcTo(targetRect, 0, 90);
 
-    QRadialGradient radialGradient;
-    radialGradient.setCenter(pos);
-    radialGradient.setFocalPoint(pos);
-    radialGradient.setRadius(radius);
-    radialGradient.setColorAt(0, base);
-    radialGradient.setColorAt(0.75, base);
-    radialGradient.setColorAt(1, Qt::transparent);
-    p.fillPath(path2, radialGradient);
+//    QRadialGradient radialGradient;
+//    radialGradient.setCenter(pos);
+//    radialGradient.setFocalPoint(pos);
+//    radialGradient.setRadius(radius);
+//    radialGradient.setColorAt(0, base);
+//    radialGradient.setColorAt(0.75, base);
+//    radialGradient.setColorAt(1, Qt::transparent);
+//    p.fillPath(path2, radialGradient);
 
-    style()->drawItemText(&p, this->rect().adjusted(30, 0, -120, 0), Qt::AlignLeft, qApp->palette(), this->isEnabled(), elidedText, QPalette::WindowText);
+    style()->drawItemText(&p, this->rect().adjusted(30, 0, -120, 0), Qt::AlignLeft | Qt::AlignVCenter, qApp->palette(), this->isEnabled(), elidedText, QPalette::WindowText);
 }
 
