@@ -31,6 +31,7 @@
 #include "file-launch-manager.h"
 #include "search-vfs-uri-parser.h"
 #include "properties-window.h"
+#include "file-enumerator.h"
 
 #include <QStackedWidget>
 #include <QToolButton>
@@ -52,6 +53,9 @@
 #include "directory-view-factory-manager.h"
 #include "global-settings.h"
 #include "main-window.h"
+#include "volume-manager.h"
+
+#include "file-info-job.h"
 
 #include <QApplication>
 #include <QStandardPaths>
@@ -72,7 +76,8 @@ TabWidget::TabWidget(QWidget *parent) : QMainWindow(parent)
     m_stack->setContentsMargins(0, 0, 0, 0);
     m_buttons = new PreviewPageButtonGroups(this);
     m_preview_page_container = new QStackedWidget(this);
-    m_preview_page_container->setMinimumWidth(200);
+    m_preview_page_container->setContentsMargins(0, 2, 0, 0);
+    m_preview_page_container->setMinimumWidth(300);
 
     //status bar
     m_status_bar = new TabStatusBar(this, this);
@@ -98,17 +103,44 @@ TabWidget::TabWidget(QWidget *parent) : QMainWindow(parent)
 
     connect(m_tab_bar, &NavigationTabBar::closeWindowRequest, this, &TabWidget::closeWindowRequest);
 
-    QHBoxLayout *t = new QHBoxLayout(this);
+    QHBoxLayout *t = new QHBoxLayout();
     QActionGroup *group = new QActionGroup(this);
     group->setExclusive(true);
     m_tab_bar_bg = new QWidget(this);
     m_tab_bar_bg->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
     QToolBar *previewButtons = new QToolBar(this);
+    previewButtons->setMovable(false);
+    previewButtons->setAttribute(Qt::WA_TranslucentBackground);
+    previewButtons->setAutoFillBackground(false);
+    previewButtons->setObjectName("previewButtons");
+    previewButtons->setStyle(TabBarStyle::getStyle());
     m_tool_bar = previewButtons;
-    //previewButtons->setFixedHeight(m_tab_bar->height());
+   // previewButtons->setFixedSize(QSize(40, 40));
+    previewButtons->setIconSize(QSize(16,16));
     t->setContentsMargins(0, 0, 5, 0);
     t->addWidget(m_tab_bar_bg);
 
+    auto spacer = new QWidget(this);
+    spacer->setFixedWidth(qApp->style()->pixelMetric(QStyle::PM_ToolBarItemSpacing) * 2 + 36);
+    spacer->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
+    t->addWidget(spacer);
+    auto addPageButton = new QToolButton(this);
+    m_add_page_button = addPageButton;
+    addPageButton->setObjectName("addPageButton");
+    addPageButton->setProperty("isWindowButton", 1);
+    addPageButton->setStyle(TabBarStyle::getStyle());
+    addPageButton->setIcon(QIcon::fromTheme("list-add-symbolic"));
+    spacer->setVisible(false);
+    addPageButton->setFixedSize(m_tab_bar->height() + 2, m_tab_bar->height() + 2);
+    addPageButton->setProperty("useIconHighlightEffect", 2);
+//    addPageButton->setProperty("iconHighlightEffectMode", 1);
+//    addPageButton->setProperty("fillIconSymbolicColor", true);
+
+
+    connect(addPageButton, &QPushButton::clicked, this, [=](){
+        m_tab_bar->addPageRequest(m_tab_bar->tabData(m_tab_bar->currentIndex()).toString(), true);
+    });
+
     updateTabBarGeometry();
 
     auto manager = Peony::PreviewPageFactoryManager::getInstance();
@@ -143,11 +175,20 @@ TabWidget::TabWidget(QWidget *parent) : QMainWindow(parent)
         button->setProperty("useIconHighlightEffect", true);
         button->setProperty("iconHighlightEffectMode", 1);
         button->setProperty("fillIconSymbolicColor", true);
+
+        //use theme buttons
+//        auto button = new QPushButton(this);
+//        button->setFixedSize(QSize(26, 26));
+//        button->setIconSize(QSize(16, 16));
+//        button->setFlat(true);
+//        button->setProperty("isWindowButton", 1);
+//        button->setProperty("useIconHighlightEffect", 2);
+//        button->setProperty("isIcon", true);
     }
-    t->addWidget(previewButtons);
+    m_tool_bar->setFixedWidth(m_tool_bar->sizeHint().width());
 
     //trash quick operate buttons
-    QHBoxLayout *trash = new QHBoxLayout(this);
+    QHBoxLayout *trash = new QHBoxLayout();
     m_trash_bar_layout = trash;
     QToolBar *trashButtons = new QToolBar(this);
     m_trash_bar = trashButtons;
@@ -164,6 +205,9 @@ TabWidget::TabWidget(QWidget *parent) : QMainWindow(parent)
     recover->setFixedWidth(TRASH_BUTTON_WIDTH);
     recover->setFixedHeight(TRASH_BUTTON_HEIGHT);
     m_recover_button = recover;
+    //hide trash button to fix bug 31322, according to designer advice
+    m_recover_button->hide();
+
     //trash->addSpacing(10);
     trash->addWidget(Label, Qt::AlignLeft);
     trash->setContentsMargins(10, 0, 10, 0);
@@ -199,11 +243,15 @@ TabWidget::TabWidget(QWidget *parent) : QMainWindow(parent)
     s->setChildrenCollapsible(false);
     s->setContentsMargins(0, 0, 0, 0);
     s->setHandleWidth(1);
-    s->setStretchFactor(0, 1);
+
     s->addWidget(m_stack);
     m_stack->installEventFilter(this);
-    s->addWidget(m_preview_page_container);
+    //s->addWidget(m_preview_page_container);
     m_preview_page_container->hide();
+
+    s->setStretchFactor(0, 3);
+    s->setStretchFactor(1, 2);
+
     vbox->addWidget(s);
     w->setLayout(vbox);
     setCentralWidget(w);
@@ -223,22 +271,33 @@ TabWidget::TabWidget(QWidget *parent) : QMainWindow(parent)
     });
 
     connect(this, &TabWidget::activePageLocationChanged, m_status_bar, [=]() {
+        if (m_first_add_page) {
+            previewButtons->setEnabled(true);
+            s->addWidget(m_preview_page_container);
+            m_first_add_page = false;
+        }
         m_status_bar->update();
     });
+
+    previewButtons->setEnabled(false);
 }
 
 void TabWidget::initAdvanceSearch()
 {
     //advance search bar
-    QHBoxLayout *search = new QHBoxLayout(this);
+    QHBoxLayout *search = new QHBoxLayout();
     m_search_bar_layout = search;
     QToolBar *searchButtons = new QToolBar(this);
     m_search_bar = searchButtons;
-    QPushButton *closeButton = new QPushButton(QIcon::fromTheme("tab-close"), "", searchButtons);
+    QPushButton *closeButton = new QPushButton(QIcon::fromTheme("window-close-symbolic"), "", searchButtons);
     m_search_close = closeButton;
     closeButton->setFixedHeight(20);
     closeButton->setFixedWidth(20);
-    closeButton->setToolTip(tr("Close advance search."));
+    closeButton->setToolTip(tr("Close Filter."));
+    closeButton->setFlat(true);
+    closeButton->setProperty("isWindowButton", 1);
+    closeButton->setProperty("useIconHighlightEffect", 2);
+    closeButton->setProperty("isIcon", true);
 
     connect(closeButton, &QPushButton::clicked, [=]()
     {
@@ -246,7 +305,7 @@ void TabWidget::initAdvanceSearch()
         Q_EMIT this->closeSearch();
     });
 
-    QLabel *title = new QLabel(tr("Search"), searchButtons);
+    QLabel *title = new QLabel(tr("Filter"), searchButtons);
     m_search_title = title;
     title->setFixedWidth(TRASH_BUTTON_WIDTH);
     title->setFixedHeight(TRASH_BUTTON_HEIGHT);
@@ -265,6 +324,7 @@ void TabWidget::initAdvanceSearch()
     //qDebug() << QIcon(":/custom/icons/child-folder").name();
     childButton->setIcon(QIcon(":/custom/icons/child-folder"));
     childButton->setToolTip(tr("Search recursively"));
+    m_search_child->setVisible(false);
     connect(childButton, &QPushButton::clicked, this, &TabWidget::searchChildUpdate);
     //set default select recursive
     m_search_child_flag = true;
@@ -273,13 +333,13 @@ void TabWidget::initAdvanceSearch()
     m_search_child->setChecked(m_search_child_flag);
     m_search_child->setDown(m_search_child_flag);;
 
-    QPushButton *moreButton = new QPushButton(tr("more options"),searchButtons);
-    m_search_more = moreButton;
-    moreButton->setFixedHeight(TRASH_BUTTON_HEIGHT);
-    moreButton->setFixedWidth(TRASH_BUTTON_WIDTH *2);
-    moreButton->setToolTip(tr("Show/hide advance search"));
+//    QPushButton *moreButton = new QPushButton(tr("more options"),searchButtons);
+//    m_search_more = moreButton;
+//    moreButton->setFixedHeight(TRASH_BUTTON_HEIGHT);
+//    moreButton->setFixedWidth(TRASH_BUTTON_WIDTH *2);
+//    moreButton->setToolTip(tr("Show/hide advance search"));
 
-    connect(moreButton, &QPushButton::clicked, this, &TabWidget::updateSearchList);
+//    connect(moreButton, &QPushButton::clicked, this, &TabWidget::updateSearchList);
 
     search->addWidget(closeButton, Qt::AlignLeft);
     search->addSpacing(10);
@@ -288,8 +348,8 @@ void TabWidget::initAdvanceSearch()
     search->addWidget(tabButton, Qt::AlignLeft);
     search->addSpacing(10);
     search->addWidget(childButton, Qt::AlignLeft);
-    search->addSpacing(10);
-    search->addWidget(moreButton, Qt::AlignLeft);
+//    search->addSpacing(10);
+//    search->addWidget(moreButton, Qt::AlignLeft);
     search->addSpacing(10);
     search->addWidget(searchButtons);
     search->setContentsMargins(10, 0, 10, 0);
@@ -298,7 +358,7 @@ void TabWidget::initAdvanceSearch()
     closeButton->setVisible(false);
     title->setVisible(false);
     childButton->setVisible(false);
-    moreButton->setVisible(false);
+//    moreButton->setVisible(false);
 }
 
 //search conditions changed, update filter
@@ -346,13 +406,13 @@ void TabWidget::browsePath()
     if (target_path != "" && target_path != getCurrentUri())
     {
         updateSearchPathButton(target_path);
-        Q_EMIT this->updateWindowLocationRequest(target_path, true);
+        Q_EMIT this->updateSearch(target_path);
     }
 }
 
 void TabWidget::addNewConditionBar()
 {
-    QHBoxLayout *layout = new QHBoxLayout(this);
+    QHBoxLayout *layout = new QHBoxLayout();
     m_layout_list.append(layout);
 
     QToolBar *optionBar = new QToolBar(this);
@@ -391,17 +451,26 @@ void TabWidget::addNewConditionBar()
     inputBox->setFixedHeight(TRASH_BUTTON_HEIGHT);
     inputBox->setFixedWidth(TRASH_BUTTON_WIDTH *4);
     inputBox->setPlaceholderText(tr("Please input key words..."));
+    inputBox->setText("");
 
-    QPushButton *addButton = new QPushButton(QIcon::fromTheme("add"), "", optionBar);
+    QPushButton *addButton = new QPushButton(QIcon::fromTheme("list-add-symbolic"), "", optionBar);
     m_add_button_list.append(addButton);
     addButton->setFixedHeight(20);
     addButton->setFixedWidth(20);
+    addButton->setFlat(true);
+    addButton->setProperty("isWindowButton", 1);
+    addButton->setProperty("useIconHighlightEffect", 2);
+    addButton->setProperty("isIcon", true);
     connect(addButton, &QPushButton::clicked, this, &TabWidget::addNewConditionBar);
 
-    QPushButton *removeButton = new QPushButton(QIcon::fromTheme("remove"), "", optionBar);
+    QPushButton *removeButton = new QPushButton(QIcon::fromTheme("list-remove-symbolic"), "", optionBar);
     m_remove_button_list.append(removeButton);
     removeButton->setFixedHeight(20);
     removeButton->setFixedWidth(20);
+    removeButton->setFlat(true);
+    removeButton->setProperty("isWindowButton", 1);
+    removeButton->setProperty("useIconHighlightEffect", 2);
+    removeButton->setProperty("isIcon", true);
     //mapper for button clicked parse index
     auto signalMapper = new QSignalMapper(this);
     connect(removeButton, SIGNAL(clicked()), signalMapper, SLOT(map()));
@@ -409,7 +478,11 @@ void TabWidget::addNewConditionBar()
     connect(signalMapper, SIGNAL(mapped(int)), this, SLOT(removeConditionBar(int)));
     m_remove_mapper_list.append(signalMapper);
 
-    layout->addSpacing(TRASH_BUTTON_WIDTH + 40);
+    layout->addWidget(addButton, Qt::AlignRight);
+    layout->addSpacing(10);
+    layout->addWidget(removeButton, Qt::AlignRight);
+    layout->addSpacing(10);
+    layout->addSpacing(TRASH_BUTTON_WIDTH - 20);
     layout->addWidget(conditionCombox, Qt::AlignLeft);
     layout->addSpacing(10);
     layout->addWidget(linkLabel, Qt::AlignLeft);
@@ -417,12 +490,9 @@ void TabWidget::addNewConditionBar()
     layout->addWidget(classifyCombox, Qt::AlignLeft);
     layout->addWidget(inputBox, Qt::AlignLeft);
     layout->addWidget(optionBar);
-    layout->addWidget(addButton, Qt::AlignRight);
-    layout->addSpacing(10);
-    layout->addWidget(removeButton, Qt::AlignRight);
     layout->setContentsMargins(10, 0, 10, 5);
 
-    if (index == 0)
+    if (index%4 >= 3)
     {
         classifyCombox->hide();
         linkLabel->setText(tr("contains"));
@@ -434,12 +504,15 @@ void TabWidget::addNewConditionBar()
             linkLabel->setFixedWidth(TRASH_BUTTON_WIDTH);
     }
     else
-        inputBox->hide();
+    {
+       inputBox->hide();
+    }
+
 
     connect(conditionCombox, &QComboBox::currentTextChanged, [=]()
     {
         auto cur = conditionCombox->currentIndex();
-        if (cur == 0)
+        if (cur%4 >= 3)
         {
             classifyCombox->hide();
             inputBox->show();
@@ -522,12 +595,12 @@ QStringList TabWidget::getCurrentClassify(int rowCount)
 {
     QStringList currentList;
     currentList.clear();
-    if (rowCount >= m_option_list.size()-1)
-        return m_file_size_list;
 
-    switch (rowCount) {
-    case 1:
+    switch (rowCount%4) {
+    case 0:
         return m_file_type_list;
+    case 1:
+        return m_file_size_list;
     case 2:
         return m_file_mtime_list;
     default:
@@ -550,7 +623,7 @@ void TabWidget::updateTrashBarVisible(const QString &uri)
     m_trash_bar->setVisible(visible);
     m_trash_label->setVisible(visible);
     m_clear_button->setVisible(visible);
-    m_recover_button->setVisible(visible);
+    //m_recover_button->setVisible(visible);
 
     if (uri.startsWith("trash://") || uri.startsWith("recent://"))
         m_tool_bar->setVisible(false);
@@ -589,14 +662,16 @@ void TabWidget::updateSearchBar(bool showSearch)
     m_show_search_bar = showSearch;
     if (showSearch)
     {
+        //default add one bar
+        updateSearchList();
         m_search_path->show();
         m_search_close->show();
         m_search_title->show();
         m_search_bar->show();
-        m_search_child->show();
-        m_search_more->show();
+        //m_search_child->show();
+        //m_search_more->show();
         m_search_bar_layout->setContentsMargins(10, 5, 10, 5);
-        m_search_more->setIcon(QIcon::fromTheme("go-down"));
+        //m_search_more->setIcon(QIcon::fromTheme("go-down"));
         updateSearchPathButton();
     }
     else
@@ -605,8 +680,8 @@ void TabWidget::updateSearchBar(bool showSearch)
         m_search_close->hide();
         m_search_title->hide();
         m_search_bar->hide();
-        m_search_child->hide();
-        m_search_more->hide();
+        //m_search_child->hide();
+        //m_search_more->hide();
         m_search_bar_layout->setContentsMargins(10, 0, 10, 0);
     }
 
@@ -628,6 +703,22 @@ void TabWidget::updateButtons()
         m_remove_button_list[0]->setDisabled(true);
     else
         m_remove_button_list[0]->setDisabled(false);
+
+    //limit total number to 10
+    if (m_search_bar_count >= 10)
+    {
+        for(int i=0;i<m_search_bar_count;i++)
+        {
+            m_add_button_list[i]->setDisabled(true);
+        }
+    }
+    else
+    {
+        for(int i=0;i<m_search_bar_count;i++)
+        {
+            m_add_button_list[i]->setDisabled(false);
+        }
+    }
 }
 
 void TabWidget::updateSearchPathButton(const QString &uri)
@@ -643,7 +734,6 @@ void TabWidget::updateSearchPathButton(const QString &uri)
         if (! getCurrentUri().isNull())
             curUri = getCurrentUri();
     }
-    //FIXME: replace BLOCKING api in ui thread.
     auto iconName = Peony::FileUtils::getFileIconName(curUri);
     auto displayName = Peony::FileUtils::getFileDisplayName(curUri);
     qDebug() << "iconName:" <<iconName <<displayName<<curUri;
@@ -662,9 +752,10 @@ void TabWidget::updateSearchList()
 {
     m_show_search_list = !m_show_search_list;
     //if not show search bar, then don't show search list
-    if (m_show_search_list && m_show_search_bar)
+    qDebug() << "updateSearchList:" <<m_show_search_list <<m_show_search_bar;
+    if (m_show_search_bar)
     {
-        m_search_more->setIcon(QIcon::fromTheme("go-up"));
+        //m_search_more->setIcon(QIcon::fromTheme("go-up"));
         //first click to show advance serach
         if(m_search_bar_list.count() ==0)
         {
@@ -677,7 +768,7 @@ void TabWidget::updateSearchList()
         {
             m_conditions_list[i]->show();
             m_link_label_list[i]->show();
-            if (m_conditions_list[i]->currentIndex() >0)
+            if (m_conditions_list[i]->currentIndex()%4 < 3)
                 m_classify_list[i]->show();
             else
                 m_input_list[i]->show();
@@ -690,7 +781,7 @@ void TabWidget::updateSearchList()
     else
     {
         //hide search list
-        m_search_more->setIcon(QIcon::fromTheme("go-down"));
+        //m_search_more->setIcon(QIcon::fromTheme("go-down"));
         for(int i=0; i<m_search_bar_list.count(); i++)
         {
             m_conditions_list[i]->hide();
@@ -715,51 +806,71 @@ Peony::DirectoryViewContainer *TabWidget::currentPage()
 
 const QString TabWidget::getCurrentUri()
 {
+    if (!currentPage())
+        return nullptr;
     return currentPage()->getCurrentUri();
 }
 
 const QStringList TabWidget::getCurrentSelections()
 {
+    if (!currentPage())
+        return QStringList();
     return currentPage()->getCurrentSelections();
 }
 
 const QStringList TabWidget::getAllFileUris()
 {
+    if (!currentPage())
+        return QStringList();
     return currentPage()->getAllFileUris();
 }
 
 const QStringList TabWidget::getBackList()
 {
+    if (!currentPage())
+        return QStringList();
     return currentPage()->getBackList();
 }
 
 const QStringList TabWidget::getForwardList()
 {
+    if (!currentPage())
+        return QStringList();
     return currentPage()->getForwardList();
 }
 
 bool TabWidget::canGoBack()
 {
+    if (!currentPage())
+        return false;
     return currentPage()->canGoBack();
 }
 
 bool TabWidget::canGoForward()
 {
+    if (!currentPage())
+        return false;
     return currentPage()->canGoForward();
 }
 
 bool TabWidget::canCdUp()
 {
+    if (!currentPage())
+        return false;
     return currentPage()->canCdUp();
 }
 
 int TabWidget::getSortType()
 {
+    if (!currentPage())
+        return 0;
     return currentPage()->getSortType();
 }
 
 Qt::SortOrder TabWidget::getSortOrder()
 {
+    if (!currentPage())
+        return Qt::AscendingOrder;
     return currentPage()->getSortOrder();
 }
 
@@ -803,62 +914,120 @@ void TabWidget::setPreviewPage(Peony::PreviewPageIface *previewPage)
 
 void TabWidget::addPage(const QString &uri, bool jumpTo)
 {
-    auto info = Peony::FileInfo::fromUri(uri, false);
-    if (! info->isDir())
-        return;
+    setCursor(QCursor(Qt::WaitCursor));
 
-    QCursor c;
-    c.setShape(Qt::WaitCursor);
-    this->setCursor(c);
+    auto info = Peony::FileInfo::fromUri(uri);
+    auto infoJob = new Peony::FileInfoJob(info);
+    infoJob->setAutoDelete();
 
-    m_tab_bar->addPage(uri, jumpTo);
-    int zoomLevel = -1;
+    connect(infoJob, &Peony::FileInfoJob::queryAsyncFinished, this, [=](){
+        auto enumerator = new Peony::FileEnumerator;
+        enumerator->setEnumerateDirectory(info.get()->uri());
+        enumerator->setAutoDelete();
+        connect(enumerator, &Peony::FileEnumerator::enumerateFinished, this, [=](bool successed){
+            if (!successed) {
+                if (!currentPage()) {
+                    QTimer::singleShot(100, topLevelWidget(), &QWidget::close);
+                }
+                return;
+            }
+        });
+        connect(enumerator, &Peony::FileEnumerator::prepared, this, [=](const std::shared_ptr<Peony::GErrorWrapper> &err = nullptr, const QString &t = nullptr, bool critical = false){
+            if (critical) {
+                QMessageBox::critical(0, 0, err.get()->message());
+                setCursor(QCursor(Qt::ArrowCursor));
+                // if there is no active page, window should be closed to avoid crash. link to: #48031
+                if (!currentPage()) {
+                    this->topLevelWidget()->close();
+                }
+                return;
+            }
+            auto viewContainer = new Peony::DirectoryViewContainer(m_stack);
+            bool hasCurrentPage = currentPage();
+            bool hasView = false;
+            if (hasCurrentPage)
+                hasView = currentPage()->getView();
+            int zoomLevel = -1;
 
-    bool hasCurrentPage = false;
+            if (hasCurrentPage) {
+                // perfer to use current page view type
+                auto internalViews = Peony::DirectoryViewFactoryManager2::getInstance()->internalViews();
+                //fix continuously click add button quickly crash issue, bug #41425
+                if (hasView && internalViews.contains(currentPage()->getView()->viewId()))
+                    viewContainer->switchViewType(currentPage()->getView()->viewId());
 
-    if (currentPage()) {
-        hasCurrentPage = true;
-        zoomLevel = currentPage()->getView()->currentZoomLevel();
-    }
+                if (hasView && hasCurrentPage) {
+                    hasCurrentPage = true;
+                    zoomLevel = currentPage()->getView()->currentZoomLevel();
+                }
+            } else {
+                viewContainer->switchViewType(Peony::GlobalSettings::getInstance()->getValue(DEFAULT_VIEW_ID).toString());
+            }
+            viewContainer->setMinimumWidth(300);
+            m_stack->addWidget(viewContainer);
+            if (jumpTo) {
+                m_stack->setCurrentWidget(viewContainer);
+            }
 
-    auto viewContainer = new Peony::DirectoryViewContainer(m_stack);
-    viewContainer->setSortType(Peony::FileItemModel::FileName);
-    viewContainer->setSortOrder(Qt::AscendingOrder);
+            //auto viewContainer = new Peony::DirectoryViewContainer(m_stack);
+            auto settings = Peony::GlobalSettings::getInstance();
+            auto sortType = settings->isExist(SORT_COLUMN)? settings->getValue(SORT_COLUMN).toInt(): 0;
+            auto sortOrder = settings->isExist(SORT_ORDER)? settings->getValue(SORT_ORDER).toInt(): 0;
+            viewContainer->setSortType(Peony::FileItemModel::ColumnType(sortType));
+            viewContainer->setSortOrder(Qt::SortOrder(sortOrder));
 
-    m_stack->addWidget(viewContainer);
-    viewContainer->goToUri(uri, false, true);
-    if (jumpTo) {
-        m_stack->setCurrentWidget(viewContainer);
-    }
+            //process open symbolic link
+            auto realUri = uri;
+            if (info->isSymbolLink() && info->symlinkTarget().length() >0 && uri.startsWith("file://"))
+                realUri = "file://" + info->symlinkTarget();
 
-    bindContainerSignal(viewContainer);
-    updateTrashBarVisible(uri);
+            //m_stack->addWidget(viewContainer);
+            viewContainer->goToUri(realUri, false, true);
 
-    if (hasCurrentPage) {
-        // perfer to use current page view type
-        auto internalViews = Peony::DirectoryViewFactoryManager2::getInstance()->internalViews();
-        if (internalViews.contains(currentPage()->getView()->viewId()))
-            viewContainer->switchViewType(currentPage()->getView()->viewId());
-    }
+            bindContainerSignal(viewContainer);
+            updateTrashBarVisible(uri);
 
-    if (zoomLevel > 0)
-        viewContainer->getView()->setCurrentZoomLevel(zoomLevel);
-    else
-        viewContainer->getView()->setCurrentZoomLevel(Peony::GlobalSettings::getInstance()->getValue(DEFAULT_VIEW_ZOOM_LEVEL).toInt());
+            if (zoomLevel > 0)
+                viewContainer->getView()->setCurrentZoomLevel(zoomLevel);
+            else
+                viewContainer->getView()->setCurrentZoomLevel(Peony::GlobalSettings::getInstance()->getValue(DEFAULT_VIEW_ZOOM_LEVEL).toInt());
+
+            m_tab_bar->addPage(realUri, jumpTo);
+            updateTabBarGeometry();
+        });
+        enumerator->prepare();
+    });
+
+    infoJob->queryAsync();
 }
 
 void TabWidget::goToUri(const QString &uri, bool addHistory, bool forceUpdate)
 {
-    qDebug() << "goToUri:" <<uri;
+    if (!currentPage()) {
+        // do not trigger go to uri if there is no active page, avoid crash. link to: #45684
+        return;
+    }
+    qDebug() << "goToUri:" << uri;
     currentPage()->goToUri(uri, addHistory, forceUpdate);
     m_tab_bar->updateLocation(m_tab_bar->currentIndex(), uri);
     updateTrashBarVisible(uri);
+    updatePreviewPage();
 }
 
 void TabWidget::updateTabPageTitle()
 {
     qDebug() << "updateTabPageTitle:" <<getCurrentUri();
-    m_tab_bar->updateLocation(m_tab_bar->currentIndex(), getCurrentUri());
+    //fix error for glib2 signal: G_FILE_MONITOR_EVENT_DELETED
+    if("trash:///" == getCurrentUri()){
+        Peony::VolumeManager* vm = Peony::VolumeManager::getInstance();
+        connect(vm,&Peony::VolumeManager::volumeRemoved,this,[=](const std::shared_ptr<Peony::Volume> &volume){
+            refresh();
+        });
+        connect(vm,&Peony::VolumeManager::volumeAdded,this,[=](const std::shared_ptr<Peony::Volume> &volume){
+            refresh();
+        });
+    }
+    m_tab_bar->updateLocation(m_tab_bar->currentIndex(), QUrl::fromPercentEncoding(getCurrentUri().toLocal8Bit()));
     updateTrashBarVisible(getCurrentUri());
 }
 
@@ -969,18 +1138,19 @@ void TabWidget::updateAdvanceConditions()
     clearConditions();
 
     //get key list for proxy-filter
+    //input name not show, must be empty
     QStringList keyList;
     for(int i=0; i<m_layout_list.count(); i++)
     {
         QString input = m_input_list[i]->text();
-        if (m_conditions_list[i]->currentIndex() > 0)
-        {
-            addFilterCondition(m_conditions_list[i]->currentIndex(), m_classify_list[i]->currentIndex());
-        }
-        else if(input != "" && ! keyList.contains(input))
+        if(input != "" && ! keyList.contains(input))
         {
             keyList.append(input);
         }
+        else
+        {
+            addFilterCondition(m_conditions_list[i]->currentIndex(), m_classify_list[i]->currentIndex());
+        }
     }
 
     //update file name filter
@@ -1012,19 +1182,14 @@ void TabWidget::editUris(const QStringList &uris)
 void TabWidget::onViewDoubleClicked(const QString &uri)
 {
     qDebug()<<"tab widget double clicked"<<uri;
-    auto info = Peony::FileInfo::fromUri(uri, false);
+    auto info = Peony::FileInfo::fromUri(uri);
     if (info->uri().startsWith("trash://")) {
         auto w = new Peony::PropertiesWindow(QStringList()<<uri);
         w->show();
         return;
     }
     if (info->isDir() || info->isVolume() || info->isVirtual()) {
-        //process open symbolic link
-        auto info = Peony::FileInfo::fromUri(uri, false);
-        QString targetUri = info.get()->targetUri();
-        if (targetUri.isEmpty())
-            targetUri = uri;
-        Q_EMIT this->updateWindowLocationRequest(targetUri, true);
+        Q_EMIT this->updateWindowLocationRequest(uri, true);
     } else {
         Peony::FileLaunchManager::openAsync(uri, false, false);
     }
@@ -1066,6 +1231,8 @@ void TabWidget::removeTab(int index)
     widget->deleteLater();
     if (m_stack->count() > 0)
         Q_EMIT activePageChanged();
+
+    updateTabBarGeometry();
 }
 
 void TabWidget::bindContainerSignal(Peony::DirectoryViewContainer *container)
@@ -1112,7 +1279,17 @@ void TabWidget::resizeEvent(QResizeEvent *e)
 
 void TabWidget::updateTabBarGeometry()
 {
-    m_tab_bar->setGeometry(0, 4, m_tab_bar_bg->width(), m_tab_bar->height());
+    int minRightPadding = m_tool_bar->width() + m_add_page_button->width() + 12;
+
+    int tabBarWidth = qMin(m_tab_bar->sizeHint().width() + 4, m_tab_bar_bg->width() - minRightPadding - 5);
+
+    m_add_page_button->move(tabBarWidth + 8, 5);
+    m_add_page_button->raise();
+
+    m_tool_bar->move(m_tab_bar_bg->width() - m_tool_bar->width() - 5, 6);
+    m_tool_bar->raise();
+
+    m_tab_bar->setGeometry(2, 2, tabBarWidth, m_tab_bar->sizeHint().height());
     m_tab_bar_bg->setFixedHeight(m_tab_bar->height());
     m_tab_bar->raise();
 }
@@ -1136,6 +1313,17 @@ const QList<std::shared_ptr<Peony::FileInfo>> TabWidget::getCurrentSelectionFile
     return infos;
 }
 
+const QList<std::shared_ptr<Peony::FileInfo>> TabWidget::getCurrentAllFileInfos()
+{
+    const QStringList uris = getAllFileUris();
+    QList<std::shared_ptr<Peony::FileInfo>> infos;
+    for(auto uri : uris) {
+        auto info = Peony::FileInfo::fromUri(uri);
+        infos<<info;
+    }
+    return infos;
+}
+
 PreviewPageContainer::PreviewPageContainer(QWidget *parent) : QStackedWidget(parent)
 {
 
