@@ -63,6 +63,7 @@
 
 #include "fm-window.h"
 #include "main-window.h"
+#include "global-settings.h"
 
 #include <QFile>
 
@@ -89,6 +90,11 @@
 
 #include "complementary-style.h"
 
+#include "volume-manager.h"
+
+#include "file-enumerator.h"
+#include "gerror-wrapper.h"
+
 #include <QTranslator>
 #include <QLocale>
 
@@ -108,11 +114,11 @@
 
 //record of peony start time
 qint64 PeonyApplication::peony_start_time = 0;
+static bool m_resident = false;
 
 PeonyApplication::PeonyApplication(int &argc, char *argv[], const char *applicationName) : SingleApplication (argc, argv, applicationName, true)
 {
-    setApplicationVersion("v3.0.0");
-    setApplicationName("peony-qt");
+    setApplicationVersion(QString("v%1").arg(VERSION));
     //setApplicationDisplayName(tr("Peony-Qt"));
 
     QFile file(":/data/libpeony-qt-styled.qss");
@@ -132,6 +138,8 @@ PeonyApplication::PeonyApplication(int &argc, char *argv[], const char *applicat
     QApplication::installTranslator(t3);
     setStyle(Peony::ComplementaryStyle::getStyle());
 
+    setApplicationName(tr("peony-qt"));
+
     parser.addOption(quitOption);
     parser.addOption(showItemsOption);
     parser.addOption(showFoldersOption);
@@ -139,6 +147,9 @@ PeonyApplication::PeonyApplication(int &argc, char *argv[], const char *applicat
 
     parser.addPositionalArgument("files", tr("Files or directories to open"), tr("[FILE1, FILE2,...]"));
 
+    //unmount all ftp node when close all window
+    connect(qApp, &QApplication::lastWindowClosed, this, &PeonyApplication::unmountAllFtpLinks);
+
     if (this->isSecondary()) {
         parser.addHelpOption();
         parser.addVersionOption();
@@ -147,12 +158,13 @@ PeonyApplication::PeonyApplication(int &argc, char *argv[], const char *applicat
             auto dir = g_get_current_dir();
             args<<"peony"<<dir;
             g_free(dir);
-            auto message = args.join(' ').toUtf8();
+            auto message = getUriMessage(args).toUtf8();
             sendMessage(message);
             return;
         }
         parser.process(arguments());
-        auto message = this->arguments().join(' ').toUtf8();
+        QStringList allArgs = arguments();
+        auto message = getUriMessage(allArgs).toUtf8();
         sendMessage(message);
         return;
     }
@@ -162,7 +174,9 @@ PeonyApplication::PeonyApplication(int &argc, char *argv[], const char *applicat
     }
 
     //parse cmd
-    auto message = this->arguments().join(' ').toUtf8();
+    parser.process(arguments());
+    QStringList allArgs = arguments();
+    auto message = getUriMessage(allArgs).toUtf8();
     parseCmd(this->instanceId(), message);
 
     auto testIcon = QIcon::fromTheme("folder");
@@ -199,269 +213,83 @@ PeonyApplication::PeonyApplication(int &argc, char *argv[], const char *applicat
     //  load plgin
     //  read from command line
     //  do with args
-#ifdef MENU
-    QDir pluginsDir(qApp->applicationDirPath());
-    qDebug()<<pluginsDir;
-    pluginsDir.cdUp();
-    pluginsDir.cd("testdir");
-    pluginsDir.setFilter(QDir::Files);
+}
 
-    qDebug()<<pluginsDir.entryList().count();
-    Q_FOREACH(QString fileName, pluginsDir.entryList(QDir::Files)) {
-        qDebug()<<fileName;
-        QPluginLoader pluginLoader(pluginsDir.absoluteFilePath(fileName));
-        qDebug()<<pluginLoader.fileName();
-        qDebug()<<pluginLoader.metaData();
-        qDebug()<<pluginLoader.load();
-        QObject *plugin = pluginLoader.instance();
-        qDebug()<<"test start";
-        if (plugin) {
-            Peony::MenuPluginInterface *iface = qobject_cast<Peony::MenuPluginInterface *>(plugin);
-            if (iface) {
-                qDebug()<<iface->testPlugin()<<iface->name()<<iface->description();
+static void unmount_finished(GFile* file, GAsyncResult* result, gpointer udata)
+{
 
-                QWidget *widget = new QWidget;
-                widget->setAttribute(Qt::WA_DeleteOnClose);
-                QMenu *menu = new QMenu(widget);
-                QStringList l;
-                Peony::MenuPluginInterface::Types types = Peony::MenuPluginInterface::Types(Peony::MenuPluginInterface::File|
-                        Peony::MenuPluginInterface::Volume|
-                        Peony::MenuPluginInterface::DirectoryBackground|
-                        Peony::MenuPluginInterface::DesktopBackground|
-                        Peony::MenuPluginInterface::Other);
-                auto fileActions = iface->menuActions(types, nullptr, l);
-                for (auto action : fileActions) {
-                    action->setParent(menu);
-                }
-                menu->addActions(fileActions);
+    int flags = 0;
+    GError *err = nullptr;
 
-                widget->setContextMenuPolicy(Qt::CustomContextMenu);
-                widget->connect(widget, &QWidget::customContextMenuRequested, [menu](const QPoint /*&pos*/) {
-                    //menu->exec(pos);
-                    menu->exec(QCursor::pos());
-                });
-                widget->show();
-            }
+    if (g_file_unmount_mountable_with_operation_finish (file, result, &err) == TRUE){
+        flags = 1;
+        char *uri = g_file_get_uri(file);
+        Peony::VolumeManager::getInstance()->fileUnmounted(uri);
+        if (uri)
+            g_free(uri);
+    }
+
+    if (! m_resident)
+    {
+        qApp->setQuitOnLastWindowClosed(true);
+    }
+
+    if (err){
+        qCritical() << "main window unmount_finished error:"<<err->message<<flags;
+        g_error_free(err);
+    }
+
+    //when has no new window, force quit peony
+    if (qApp->topLevelWindows().count() <= 0 && ! m_resident){
+        qDebug() << "has no new window, exit";
+        qApp->exit();
+    }
+}
+
+void PeonyApplication::unmountAllFtpLinks()
+{
+    qDebug() << "lastWindowClosed unmountAllFtpLinks";
+    auto allUris = Peony::FileUtils::getChildrenUris("computer:///");
+    for(auto uri : allUris)
+    {
+        auto targetUri = Peony::FileUtils::getTargetUri(uri);
+        qDebug() << "unmountAllFtpLinks targetUri:" <<targetUri;
+        if (! targetUri.startsWith("smb://") &&
+            ! targetUri.startsWith("sftp://") &&
+            ! targetUri.startsWith("ftp://"))
+            continue;
+
+        m_resident = Peony::GlobalSettings::getInstance()->getValue(RESIDENT_IN_BACKEND).toBool();
+        qApp->setQuitOnLastWindowClosed(false);
+        GFile *file = g_file_new_for_uri(uri.toUtf8().constData());
+        g_file_unmount_mountable_with_operation(file,
+                                                G_MOUNT_UNMOUNT_NONE,
+                                                nullptr,
+                                                nullptr,
+                                                GAsyncReadyCallback(unmount_finished),
+                                                this);
+        g_object_unref(file);
+    }
+}
+
+QString PeonyApplication::getUriMessage(QStringList& strList)
+{
+    QStringList args;
+
+    for (auto uri = strList.constBegin(); uri != strList.constEnd(); ++uri) {
+        if ((*uri).startsWith("-") || (*uri).startsWith("--") || (*uri).startsWith("%")
+                || (*uri).startsWith("/usr/") || (*uri).startsWith("/bin/") || (*uri).startsWith("/sbin/")) {
+            args << *uri;
+        } else if ((*uri).startsWith("/")) {
+            args << Peony::FileUtils::urlEncode("file://" + *uri);
+        } else if ((*uri).contains("://")) {
+            args << Peony::FileUtils::urlEncode(*uri);
+        } else {
+            args << Peony::FileUtils::urlEncode(QString("file://%1/%2").arg(g_get_current_dir()).arg(*uri));
         }
-        qDebug()<<"testEnd";
-    }
-#endif
-
-//#define PREVIEW
-#ifdef PREVIEW
-    qDebug()<<"preview test";
-    auto previewManager = Peony::PreviewPageFactoryManager::getInstance();
-    qDebug()<<previewManager->getPluginNames();
-    for (auto name : previewManager->getPluginNames()) {
-        auto plugin = previewManager->getPlugin(name);
-        auto w = plugin->createPreviewPage();
-        w->startPreview();
-        QTimer::singleShot(1000, [=]() {
-            w->cancel();
-        });
-        auto w1 = dynamic_cast<QWidget*>(w);
-        w1->setAttribute(Qt::WA_DeleteOnClose);
-        w1->show();
     }
 
-#endif
-
-//#define DIRECTORY_VIEW
-#ifdef DIRECTORY_VIEW
-    QDir pluginsDir(qApp->applicationDirPath());
-    qDebug()<<pluginsDir;
-    pluginsDir.cdUp();
-    pluginsDir.cd("testdir2");
-    pluginsDir.setFilter(QDir::Files);
-
-    qDebug()<<"directory view test";
-    auto directoryViewManager = Peony::DirectoryViewFactoryManager::getInstance();
-    qDebug()<<directoryViewManager->getFactoryNames();
-    auto names = directoryViewManager->getFactoryNames();
-    for (auto name : names) {
-        qDebug()<<name;
-        auto factory = directoryViewManager->getFactory(name);
-        auto view = factory->create();
-        auto proxy = new Peony::DirectoryView::StandardViewProxy(view);
-        view->setProxy(proxy);
-        //BUG: it is not safe loading a new uri when
-        //a directory is loading. enve thoug the file enumemeration
-        //is cancelled and, the async method from GFileEnumerator
-        //might still run in thread and return.
-        //This cause program went crash.
-
-        //view->setDirectoryUri("file:///");
-        //view->beginLocationChange();
-        //view->stopLocationChange();
-        qDebug()<<"2";
-        //proxy->setDirectoryUri("network:///");
-        //proxy->setDirectoryUri("file:///home/lanyue");
-        proxy->setDirectoryUri("file:///");
-        proxy->beginLocationChange();
-        QTimer::singleShot(1000, [=]() {
-            //proxy->invertSelections();
-        });
-        connect(proxy, &Peony::DirectoryViewProxyIface::viewDoubleClicked, [=](const QString &uri) {
-            qDebug()<<"app double clicked"<<uri;
-            auto info = Peony::FileInfo::fromUri(uri);
-            if (info->isDir() || info->isVolume() || uri.startsWith("network:")) {
-                proxy->setDirectoryUri(uri);
-                proxy->beginLocationChange();
-            }
-        });
-
-        auto widget = dynamic_cast<QWidget*>(view);
-
-        //widget->setAttribute(Qt::WA_DeleteOnClose);
-        QWidget *container = new QWidget;
-        container->setAttribute(Qt::WA_DeleteOnClose);
-        widget->setParent(container);
-        QVBoxLayout *layout = new QVBoxLayout(container);
-
-        layout->setContentsMargins(0,0,0,0);
-        layout->setSpacing(0);
-
-        container->setLayout(layout);
-        container->layout()->addWidget(widget);
-
-        container->show();
-    }
-#endif
-
-//#define DIRECTORY_VIEW2
-#ifdef DIRECTORY_VIEW2
-    QMainWindow *w = new QMainWindow;
-    QToolBar *t = new QToolBar(w);
-    Peony::PathEdit *e = new Peony::PathEdit;
-    e->setUri("file:///");
-    t->addWidget(e);
-    w->addToolBar(Qt::TopToolBarArea, t);
-
-    auto tabPage = new Peony::TabPage(w);
-    w->setCentralWidget(tabPage);
-
-    w->connect(e, &QLineEdit::returnPressed, [=]() {
-        tabPage->addPage(e->text());
-    });
-
-    w->show();
-
-#endif
-
-//#define PATH_EDIT
-#ifdef PATH_EDIT
-
-    //Peony::PathEdit *edit = new Peony::PathEdit;
-    //edit->setUri("file:///home/lanyue");
-    //edit->show();
-
-    QWidget *widget = new QWidget;
-    widget->setAttribute(Qt::WA_DeleteOnClose);
-
-    QStackedLayout *layout = new QStackedLayout(widget);
-    layout->setContentsMargins(0, 0, 0, 0);
-    layout->setSpacing(0);
-    layout->setSizeConstraint(QLayout::SetDefaultConstraint);
-    Peony::LocationBar *bar = new Peony::LocationBar;
-    Peony::PathEdit *edit = new Peony::PathEdit(widget);
-    bar->setRootUri("file://" + QStandardPaths::writableLocation(QStandardPaths::HomeLocation));
-    bar->connect(bar, &Peony::LocationBar::groupChangedRequest, bar, &Peony::LocationBar::setRootUri);
-    bar->connect(bar, &Peony::LocationBar::blankClicked, [=]() {
-        layout->setCurrentWidget(edit);
-        edit->setUri(bar->getCurentUri());
-    });
-    edit->setUri(bar->getCurentUri());
-    edit->connect(edit, &Peony::PathEdit::returnPressed, [=]() {
-        bar->setRootUri(edit->text());
-        layout->setCurrentWidget(bar);
-    });
-    edit->connect(edit, &Peony::PathEdit::editCancelled, [=]() {
-        layout->setCurrentWidget(bar);
-    });
-    layout->addWidget(bar);
-    layout->addWidget(edit);
-
-    widget->setLayout(layout);
-    widget->setFixedHeight(edit->height());
-    widget->show();
-#endif
-
-//#define TOOLBAR
-#ifdef TOOLBAR
-
-    Peony::ToolBar *toolbar = new Peony::ToolBar;
-    QMainWindow *w = new QMainWindow;
-    w->addToolBar(toolbar);
-
-    w->show();
-
-#endif
-
-//#define SIDEBAR
-#ifdef SIDEBAR
-    auto sidebar = new Peony::SideBar;
-    sidebar->show();
-#endif
-
-//#define NAVIGATION_BAR
-#ifdef NAVIGATION_BAR
-    QMainWindow *w = new QMainWindow;
-    auto nbar = new Peony::NavigationBar;
-    w->addToolBar(Qt::TopToolBarArea, nbar);
-    w->show();
-#endif
-
-//#define MENU
-#ifdef MENU
-    Peony::DirectoryView::IconView *view = new Peony::DirectoryView::IconView;
-    view->setDirectoryUri("file:///");
-    view->beginLocationChange();
-    view->setContextMenuPolicy(Qt::CustomContextMenu);
-    view->show();
-#endif
-
-//#define LIST_VIEW
-#ifdef LIST_VIEW
-    Peony::DirectoryView::ListView *listView = new Peony::DirectoryView::ListView;
-    auto model = new Peony::FileItemModel;
-    auto proxyModel = new Peony::FileItemProxyFilterSortModel;
-
-    listView->bindModel(model, proxyModel);
-    listView->setDirectoryUri("file:///");
-    listView->beginLocationChange();
-
-    listView->show();
-#endif
-
-//#define BASIC_PROPERTIES_PAGE
-#ifdef BASIC_PROPERTIES_PAGE
-    Peony::BasicPropertiesPage *p = new Peony::BasicPropertiesPage("file:///");
-    p->show();
-#endif
-
-//#define FILE_COUNT_OPERATION
-#ifdef FILE_COUNT_OPERATION
-    QStringList l;
-    l<<"file:///home";
-    auto op = new Peony::FileCountOperation(l);
-    QThreadPool::globalInstance()->start(op);
-
-    connect(op, &Peony::FileCountOperation::operationPreparedOne, [=](const QString &uri) {
-        qDebug()<<uri;
-    });
-
-    connect(op, &Peony::FileCountOperation::operationFinished, [=]() {
-        qDebug()<<"finished";
-        Peony::FileInfoManager::getInstance()->showState();
-    });
-#endif
-
-//#define FM_WINDOW
-#ifdef FM_WINDOW
-    auto window = new Peony::FMWindow("file:///");
-    window->setAttribute(Qt::WA_DeleteOnClose);
-    window->show();
-#endif
+    return args.join(' ');
 }
 
 void PeonyApplication::parseCmd(quint32 id, QByteArray msg)
@@ -526,6 +354,9 @@ void PeonyApplication::parseCmd(quint32 id, QByteArray msg)
                 });
                 window->show();
                 KWindowSystem::raiseWindow(window->winId());
+                if (KWindowSystem::activeWindow() != window->winId()) {
+                    KWindowSystem::activateWindow(window->winId());
+                }
             }
         }
 
@@ -542,6 +373,9 @@ void PeonyApplication::parseCmd(quint32 id, QByteArray msg)
             }
             window->show();
             KWindowSystem::raiseWindow(window->winId());
+            if (KWindowSystem::activeWindow() != window->winId()) {
+                KWindowSystem::activateWindow(window->winId());
+            }
         }
         if (parser.isSet(showPropertiesOption)) {
             QStringList uris = Peony::FileUtils::toDisplayUris(parser.positionalArguments());
@@ -549,32 +383,54 @@ void PeonyApplication::parseCmd(quint32 id, QByteArray msg)
                 return;
             }
 
+            qApp->setProperty("showProperties", true);
+
             Peony::PropertiesWindow *window = new Peony::PropertiesWindow(uris);
+
             window->setAttribute(Qt::WA_DeleteOnClose);
             window->show();
             KWindowSystem::raiseWindow(window->winId());
+            if (KWindowSystem::activeWindow() != window->winId()) {
+                KWindowSystem::activateWindow(window->winId());
+            }
         }
     } else {
         if (!parser.positionalArguments().isEmpty()) {
-            QStringList uris = Peony::FileUtils::toDisplayUris(parser.positionalArguments());
-            if (uris.isEmpty()) {
-                return;
-            }
-            //auto window = new Peony::FMWindow(uris.first());
-            auto window = new MainWindow(uris.first());
-            uris.removeAt(0);
+            auto arguments = parser.positionalArguments();
+            arguments.removeOne("%U");
+            arguments.removeOne("%U&");
+            QStringList uris = Peony::FileUtils::toDisplayUris(arguments);
+
             if (!uris.isEmpty()) {
-                window->addNewTabs(uris);
+                auto window = new MainWindow(uris.first());
+                uris.removeAt(0);
+                if (!uris.isEmpty()) {
+                    window->addNewTabs(uris);
+                }
+                window->setAttribute(Qt::WA_DeleteOnClose);
+                window->show();
+                KWindowSystem::raiseWindow(window->winId());
+                if (KWindowSystem::activeWindow() != window->winId()) {
+                    KWindowSystem::activateWindow(window->winId());
+                }
+            } else {
+                auto window = new MainWindow();
+                window->setAttribute(Qt::WA_DeleteOnClose);
+                window->show();
+                KWindowSystem::raiseWindow(window->winId());
+                if (KWindowSystem::activeWindow() != window->winId()) {
+                    KWindowSystem::activateWindow(window->winId());
+                }
             }
-            window->setAttribute(Qt::WA_DeleteOnClose);
-            window->show();
-            KWindowSystem::raiseWindow(window->winId());
         } else {
             auto window = new MainWindow;
             //auto window = new Peony::FMWindow;
             window->setAttribute(Qt::WA_DeleteOnClose);
             window->show();
             KWindowSystem::raiseWindow(window->winId());
+            if (KWindowSystem::activeWindow() != window->winId()) {
+                KWindowSystem::activateWindow(window->winId());
+            }
         }
     }
 
