@@ -25,6 +25,8 @@
 
 #include <QMainWindow>
 #include "FMWindowIface.h"
+#include "file-label-box.h"
+#include <QFileSystemWatcher>
 
 class MainWindowPrivate;
 class BorderShadowEffect;
@@ -82,6 +84,9 @@ public:
     int currentViewZoomLevel();
     bool currentViewSupportZoom();
 
+    void addFocusWidgetToFocusList(QWidget *widget);
+    QWidgetList focusWidgetsList();
+
 Q_SIGNALS:
     void windowSelectionChanged();
     void locationChanged(const QString &uri);
@@ -108,6 +113,8 @@ public Q_SLOTS:
 
     void syncControlsLocation(const QString &uri);
     void updateHeaderBar();
+    void updateWindowIcon();
+    void updateSearch(const QString &uri, const QString &key="", bool updateKey=false);
     void createFolderOperation();
     void goToUri(const QString &uri, bool addHistory = false, bool force = false);
 
@@ -118,12 +125,6 @@ public Q_SLOTS:
     void refresh();
     void forceStopLoading();
 
-    //imigrate from fm-window
-    void advanceSearch();
-    void clearRecord();
-    void searchFilter(QString target_path, QString keyWord, bool search_file_name, bool search_content);
-    void filterUpdate(int type_index=0, int time_index=0, int size_index=0);
-
     void setShowHidden();
     void setUseDefaultNameSortOrder();
     void setSortFolderFirst();
@@ -136,6 +137,7 @@ public Q_SLOTS:
     //trash quick operations
     void cleanTrash();
     void recoverFromTrash();
+    bool getFilterWorking(){return m_filter_working;}
 
     void setCurrentSelectionUris(const QStringList &uris);
     void setCurrentSortOrder (Qt::SortOrder order);
@@ -157,10 +159,11 @@ protected:
 
     void validBorder();
     void initUI(const QString &uri);
-    void initAdvancePage();
 
     QRect sideBarRect();
 
+    void startMonitorThumbnailForbidStatus();
+
 private:
     BorderShadowEffect *m_effect;
 
@@ -172,9 +175,14 @@ private:
     QStackedWidget *m_side_bar_container;
     TabWidget *m_tab;
     Peony::StatusBar *m_status_bar;
+    FileLabelBox *m_label_box;
+
+    QString m_last_search_path = "";
+    QString m_last_key = "";
 
     bool m_is_draging = false;
     bool m_is_search = false;
+    bool m_filter_working = false;
     bool m_show_hidden_file;
     bool m_use_default_name_sort_order;
     bool m_folder_first;
@@ -183,6 +191,16 @@ private:
     bool m_should_save_window_size = false;
 
     QPoint m_offset;
+
+    QWidgetList m_focus_list;
+
+    bool m_shortcuts_set = false;
+
+
+    QFileSystemWatcher *m_thumbnail_watcher;
+    bool m_do_not_thumbnail = false;
+
+    const int WINDOW_MINIMUM_WIDTH = 596;
 };
 
 #endif // MAINWINDOW_H
